# -*- coding: utf-8 -*-
from __future__ import unicode_literals

# Loading default values
from defaults import *

import os

VAR_DIR=os.path.join(os.sep, 'var', 'opt', 'termidesk-vdi')
ETC_DIR=os.path.join(os.sep, 'etc', 'opt', 'termidesk-vdi')

def isAstraLinux():
    return os.path.exists('/etc/astra_version')

def getOpt(name, default):
    filename = os.path.join(ETC_DIR, name)
    value = None

    try:
       value = open(filename, 'r').read().strip()
    except:
       pass
    finally:
       return value or default

DBTYPE=getOpt('DBTYPE', None)
DBHOST=getOpt('DBHOST', '127.0.0.1')
DBPORT=getOpt('DBPORT', None)
DBNAME=getOpt('DBNAME', 'termidesk')
DBUSER=getOpt('DBUSER', 'termidesk')
DBPASS=getOpt('DBPASS', 'ksedimret')

# Override or redefine app settings here
DJANGO_USE_X_FORWARDED_HOST = True

#Default DB. Not for production
DJANGO_DATABASES_SQLITE3 = {
    'default': {
        'ENGINE': 'django.db.backends.sqlite3',
        'NAME': os.path.join(VAR_DIR, 'db.sqlite3'),
    }
}

# Native MySQL connector example
DJANGO_DATABASES_NATIVE = {
    'default': {
        'ENGINE': 'django.db.backends.mysql',
        'OPTIONS': {
            'init_command': 'SET SESSION TRANSACTION ISOLATION LEVEL READ COMMITTED;',
            'sql_mode': 'traditional',
        },
        'NAME': DBNAME,
        'USER': DBUSER,
        'PASSWORD': DBPASS,
        'HOST': DBHOST,
        'PORT': DBPORT or '3306',
    }
}

# Pure python MySQL connector example
DJANGO_DATABASES_PYTHON = {
    'default': {
        'ENGINE': 'mysql.connector.django',
        'OPTIONS': {
                'sql_mode': 'TRADITIONAL',
                'charset': 'utf8',
                'collation': 'utf8_general_ci',
        },
        'NAME': DBNAME,
        'USER': DBUSER,
        'PASSWORD': DBPASS,
        'HOST': DBHOST,
        'PORT': DBPORT or '3306',
    }
}

# Postgres Pro connector example
DJANGO_DATABASES_POSTGRES = {
    'default': {
        'ENGINE': 'django.db.backends.postgresql_psycopg2',

        'NAME': DBNAME,
        'USER': DBUSER,
        'PASSWORD': DBPASS,
        'HOST': DBHOST,
        'PORT': DBPORT or '5432',
    }
}

#DJANGO_DATABASES = DJANGO_DATABASES_SQLITE3
#DJANGO_DATABASES = DJANGO_DATABASES_NATIVE
#DJANGO_DATABASES = DJANGO_DATABASES_PYTHON
#DJANGO_DATABASES = DJANGO_DATABASES_POSTGRES

if (isAstraLinux() and not DBTYPE): # Default DB for AstraLinux is POSTGRES Pro
   DJANGO_DATABASES = DJANGO_DATABASES_POSTGRES
elif not DBTYPE:
   DJANGO_DATABASES = DJANGO_DATABASES_SQLITE3
elif DBTYPE == 'NATIVE':
   DJANGO_DATABASES = DJANGO_DATABASES_NATIVE
elif DBTYPE == 'MYSQL':
   DJANGO_DATABASES = DJANGO_DATABASES_PYTHON
elif DBTYPE == 'POSTGRES':
   DJANGO_DATABASES = DJANGO_DATABASES_POSTGRES
elif DBTYPE == 'SQLITE3':
   DJANGO_DATABASES = DJANGO_DATABASES_SQLITE3
else:
   DJANGO_DATABASES = DJANGO_DATABASES_SQLITE3

DJANGO_SECRET_KEY = getOpt('DJANGO_SECRET_KEY', '1234567890_DEMO_KEY_0987654321')

# DEMO RSA KEY
DEMO_CRYPTO_RSA_KEY = ('-----BEGIN RSA PRIVATE KEY-----\n'
                'MIIEogIBAAKCAQEAtn3yrmif63EMcWjk1vc9RRZPA+Hn2ItHaAnNik5e3+ISTOHE'
                '/UeJpiGjpVdaD+/qMAtlklnXQWvSzZ9m1SESK6TZrQoJm0UNomPKvQ6cvy5T+17T'
                'EVSGJcMGTGKIiTOeGSw9MRqM/kEyHUyLd/IDPksfaYQA1flRikWdGvLrb7Zm5r9j'
                '7wdLZ7+4yrxAwqMNtv2x02X8KUFgDzqYRTuDvSPyIMJWriV7j+DxJugOYWBPJIuG'
                '3gtyD/KJqs+CKbrOX7K/nViLLWSnstz1FPfuy+y8T32dOYuln4tMPJ4O+qEzZkYJ'
                'AtRb19N8hZBLLjiJOQ3rXmJR9AN0/hQ0Iq2vsQIDAQABAoIBAE63gy/CB4E6UUC2'
                'G0eye+ZKGik1j5kzcsioudU3uurdjEFHfX43FmPnzLvsMvf+58hzkguP3y7kAJkb'
                'cfLrAfh7cj2Wv9AO+DOc0f28yNYaeLVMEMU/7WFqf1QBiJ2N+1smXvrIVhryKljD'
                'BMHnTYjYRKNyAh5KHecD4iGWuQGFM/RjxV/r1hYkBt/+2i/G09UgzplhhwsA4Lo+'
                '4zEFL0wzDcQ7tkX2q9Lhaj1u2/QG9LY5a2B9eDNnhV336pNTdTwEhOQqvd679Xgj'
                'TYuIApPtNs1G8jQZ5GRUZPN6r9EthUEWj87m92gZZxTJ8XoH0sqb1R41FhUEXv73'
                'EU8PteUCgYEA7uuLZofe8f4Cs6eXl6adAT8mQ8pSeDGEjX1IlacerL4ApRzOqmoX'
                'EtEOejefO7aHS0FBMiuhARqXZ9mlm2cNGWIwWGEz1dw4dP0wyOWnzcjJ1irROlkx'
                'LwnTrS0motlG5Z2VSvcybf5zlB4GPg10lDEb1Lz4AZFmVr3I06juBQsCgYEAw4m3'
                's0rpFcHHQxjk+mhBdWq2u0oNBMOtGqBdopcU96haOZQ3Y1U6CHxXRtTU11BmDa9F'
                't0ny5c6pr0YuToLe5LE0/E5k7pvyyooNdBb+NWy6wAN+uOXElZcPOaLO/WWBCndc'
                'hhpsO+/qmL0Ea7CBn+bucP1P8NOuWfG+TWAoG7MCgYAQ17IADFv/GzT9jTb2jdxL'
                'ljQQW1bs+jCp+McBJcLX0p0hBqLbCJeP0AUBQKKNBxUKjRMXglPbTBCYVZODHQSj'
                'YXSfBlstHFUuihrCTs5Bh4ITAvm070y0UDEH6ELs//wre6xmmH6JmoJzUpqGDVTG'
                'jZ+0o42oLqPUQZTCtwnweQKBgFtGbfnDfgop6lnnxPser2+f4KyMZIdUz/kd4peC'
                '7sasT3GRPkmf/vb3E8Z8kt3vKbQ5nNFyM3ASiCLJH9SGQoV+Mr2T2omHQk5JIv6N'
                'vRwzJPl8qCqnFpy9Zt4AoZ6nQxUfopD2xI817sxdbzLVsaxyn9seY7KHHVve/HYh'
                '7JcBAoGAZQefpj5qzufyPS2YMsXb36i3VYx2xbrmd7DFnkXNqeO+g69CcMawQsrb'
                'hB6yTKHWYts+A2aWuGg2Mdkuh/RO762kp2U10EQU5nI1XkP+nWI0eP42PG4Pp1BB'
                'wA+y45ogLFP/hExwnxy8nMr9kK+mgEBQI8XTWPsjBzXCLq/SXEM='
                '\n-----END RSA PRIVATE KEY-----')

CRYPTO_RSA_KEY = getOpt('CRYPTO_RSA_KEY', DEMO_CRYPTO_RSA_KEY)
