# -*- coding: utf-8 -*-
from __future__ import unicode_literals
import os

BASE_DIR = os.path.abspath(os.path.dirname(__file__))
DB_DIR = os.path.join(BASE_DIR)

APP_COOKIE_NAME = 'termidesk'
APP_CUSTOMIZE_WORKPLACE_HELP_URL_LABEL = "URL поддержки"
APP_CUSTOMIZE_WORKPLACE_HELP_URL_TOOLTIP = "URL для связи с поддержкой"

LICENSE_STORAGE_FOLDER = os.path.join(BASE_DIR, 'private', 'license')
KERBEROS_TOKEN_STORAGE_FOLDER = os.path.join(BASE_DIR, 'private', 'kerberos', 'tokens')

#Django related settings
DJANGO_MANAGE_SCRIPT = os.path.join(BASE_DIR, 'manage.py')
DJANGO_DEBUG = False
DJANGO_TEMPLATE_DEBUG = False
DJANGO_ALLOWED_HOSTS = ['*']
DJANGO_TIME_ZONE = 'Europe/Moscow'
DJANGO_LOG_LEVEL = 'INFO'
DJANGO_DATABASES = {
    'default': {
        'ENGINE': 'django.db.backends.sqlite3',
        'NAME': os.path.join(DB_DIR, 'db.sqlite3'),
    }
}

DJANGO_COMPRESS_ENABLED = False

DJANGO_CACHES = {
    'default': {
        'BACKEND': 'django.core.cache.backends.db.DatabaseCache',
        'LOCATION': 'uds_response_cache',
        'OPTIONS': {
            'MAX_ENTRIES': 5000,
            'CULL_FREQUENCY': 3,  #  0 = Entire cache will be erased once MAX_ENTRIES is reached, this is faster on DB. if other value, will remove 1/this number items fromm cache
        }
    },
    'memory': {
        'BACKEND': 'django.core.cache.backends.memcached.MemcachedCache',
        'LOCATION': '127.0.0.1:11211',
    }
}

DJANGO_CSRF_TRUSTED_ORIGINS = []

# When behind SSL proxy use:
# DJANGO_SECURE_PROXY_SSL_HEADER = ('HTTP_X_FORWARDED_PROTO', 'https')
# DJANGO_USE_X_FORWARDED_HOST = True 
DJANGO_SECURE_PROXY_SSL_HEADER = None
DJANGO_USE_X_FORWARDED_HOST = False 

# Приватный и публичный ключи для работы websocket proxy должны быть
# сгенерированы и размещены по эти путям 
WSPROXY_PRIV_KEY_FILE = os.path.join(BASE_DIR, 'private', 'wsproxy', 'id_rsa')
WSPROXY_PUB_KEY_FILE = os.path.join(BASE_DIR, 'private', 'wsproxy', 'id_rsa.pub')

# Эти переменные необходимо обязательно объявить в конфиге
# DJANGO_SECRET_KEY = '< Define django secret key here >'
# CRYPTO_RSA_KEY = '-----BEGIN RSA PRIVATE KEY-----\n<put rsa private key here>\n-----END RSA PRIVATE KEY-----'