# -*- encoding: utf-8 -*-
"""
This module contains useful helpers to improve interaction between "Termidesk" and " Celery"
"""


def autodiscover_jobs(celery_app):
    """
    Construct the task with the celery's beat_schedule format from all 'Job' subclasses.
    Its must called when django-app 'uds' is fully initialized,
    because 'Job' subclasses depends on django models.
    Try to call when app is uninitialized rises an Exception.
    """
    tasks_for_scheduler = {}
    from uds.core.jobs.Job import Job as jobs_parent_class
    for job_subclass in jobs_parent_class.__subclasses__():
        if not getattr(job_subclass, 'celery_compatible', False) is False:
            continue
        # From each subclass takes `friendly_name` as a job's name,
        # `celery_name` as registered name of task for 'celery',
        # `frecuency` as the time between tasks executions.
        tasks_for_scheduler.update({
            job_subclass.friendly_name: {
                    'task': job_subclass.celery_name,
                    'schedule': job_subclass.frecuency,
                },
        })
    return tasks_for_scheduler
