from threading import Thread

from django.core.mail.message import EmailMultiAlternatives


def get_config_value(key, section):
    """
    Получение значения системного параметра по ключу и по названию секции.
    Дублирование функции из src/tdsklog/handlers:_get_syslog_param.
    """
    from uds.models.Config import Config

    try:
        return Config.objects.get(
            section=section, key=key
        ).value
    except Config.DoesNotExist:
        return None


class EmailThread(Thread):
    def __init__(self, subject, message, server_mail, admins, connection, html_message=None,
                 fail_silently=False):
        self.subject = subject
        self.message = message
        self.server_mail = server_mail
        self.admins = admins
        self.connection = connection
        self.html_message = html_message
        self.fail_silently = fail_silently
        Thread.__init__(self)

    def run(self):
        mail = EmailMultiAlternatives(self.subject, self.message, self.server_mail,
                                      self.admins, connection=self.connection)

        if self.html_message:
            mail.attach_alternative(self.html_message, 'text/html')

        mail.send(fail_silently=self.fail_silently)
