# -*- coding: utf-8 -*-

'''
@author: Dmitry Dvoeglazov
'''

from __future__ import unicode_literals
import logging

from django.apps import AppConfig

from version import __version__
import sys


class TermideskAppConfig(AppConfig):
    '''
    Termidesk django app config
    '''
    name = 'termidesk'
    label = 'termidesk'
    verbose_name = 'Termidesk'

    def ready(self):
        logger = logging.getLogger(__name__)
        logger.debug('Termidesk app ready')
        
        from . import services
        from . import transports
        from . import auths
        from . import rest
        from . import osmanagers
        from . import policies
        from . import converters

        from . import patch
        
        patch.patch_themes()
        patch.patch_default_images()

        import termidesk.sys_audit_patch
        from termidesk.audit.handlers import FileHandler, SyslogAuditHandler, DatabaseHandler
        hook = FileHandler()
        sys.addaudithook(hook)

        hook_syslog = SyslogAuditHandler()
        sys.addaudithook(hook_syslog)

        hook_db = DatabaseHandler()
        sys.addaudithook(hook_db)
        
        # Конфигурация медиатора событий для сервиса
        from termidesk.notifications.mediator import Mediator
        from termidesk.notifications.handlers.sender import NotificationsSender
        from termidesk.core.util.singleton import SingletonMeta
        mediator = Mediator(notifications_sender = NotificationsSender())

        # Первичная инициализация сервиса медиатора
        from termidesk.notifications import MediatorService
        assert MediatorService not in SingletonMeta._instances
        MediatorService(mediator=mediator)
        assert MediatorService in SingletonMeta._instances


default_app_config = 'termidesk.TermideskAppConfig'
