from django.core.handlers.wsgi import WSGIRequest

from termidesk.rest.handlers import READ_ACTION, set_crud_event
from uds.models import Provider, Authenticator, User, Group, ServicePool

""" Фиксация перехода на детальную только для указанных классов. """
DETAIL_CLASSES = {
    'provider_id': Provider,
    'domain_id': Authenticator,
    'workplace_id': ServicePool,
}

DETAIL_SUBCLASS = {
    'domain_id': {
        'user_id': User,
        'group_id': Group,
    },
}


def __get_uuid_and_class_from_kwargs(kwargs):
    """ Получение идентификатора и класса.

    От этой функции можно будет избавиться при переходе на python3.6,
    переделав ключи DETAIL_CLASSES в виде ключей кортежей:

    DETAIL_CLASSES = {
        ('provider_id',): Provider,
        ('domain_id',): Authenticator,
        ('domain_id', 'user_id',): User,
        ('domain_id', 'group_id',): Group,
    }
    """
    if len(kwargs) == 2:
        first, second = kwargs.keys()
        if first in DETAIL_SUBCLASS and second in DETAIL_SUBCLASS[first]:
            uuid = kwargs.get(second)
            class_object = DETAIL_SUBCLASS[first][second]
            return uuid, class_object

        if second in DETAIL_SUBCLASS and first in DETAIL_SUBCLASS[second]:
            uuid = kwargs.get(first)
            class_object = DETAIL_SUBCLASS[second][first]
            return uuid, class_object

        return None, None

    name_object_param, *_ = kwargs.keys()
    class_object = DETAIL_CLASSES.get(name_object_param)
    return kwargs.get(name_object_param), class_object


def set_detail_event_in_audit(func):
    """ Фиксация событий посещения детальной. """

    def set_event_detail_action(*args, **kwargs):
        result = func(*args, **kwargs)

        uuid, class_object = __get_uuid_and_class_from_kwargs(kwargs)

        request, *_ = args

        if class_object is None or uuid is None or not isinstance(request, WSGIRequest):
            return result

        entity = class_object.objects.get(uuid=uuid)

        if hasattr(entity, 'data_type'):
            subtype = entity.data_type
        elif 'get_data_type' in dir(entity):
            subtype = entity.get_data_type()
        else:
            subtype = ''

        set_crud_event(
            request.user.manager.name,
            request.user.name,
            request.ip,
            entity.__class__.__name__,
            entity.uuid,
            subtype,
            entity.name,
            READ_ACTION
        )
        return result

    return set_event_detail_action
