# -*- encoding: utf-8 -*-

'''
Created on 6 июл. 2021 г.

@author: dvd
'''
from __future__ import unicode_literals

from rest_framework import serializers

class ServiceOwnerDetail(serializers.Serializer):
    '''
    Read-only DRF сериалайзер для подготовки данных о владельце рабочего места (сервиса)
    '''


    def to_representation(self, instance):
        # instance - экземпляр uds.models.User
        
        authenticator = instance.getManager()
        db_auth = authenticator.dbAuthenticator()

        realm = self._get_auth_realm(authenticator)

        return {
            'username': instance.name,
            'auth_id': db_auth.pk,
            'auth_uuid': db_auth.uuid,
            'auth_smallname': db_auth.small_name,
            'auth_realm':realm,
        }


    def _get_auth_realm(self, authenticator):
        # Получаем значение realm аутентификатора
        # Пока действительно только для ALD и FreeIPA аутентификаторов
        realm_field = getattr(authenticator, 'realm', {'value': ''})
        realm_value = getattr(realm_field, 'value', '')
        return realm_value


class ServiceInfo(serializers.Serializer):
    '''
    Read-only DRF сериалайзер для подготовки данных о рабочем месте (сервисе)
    '''


    def to_representation(self, instance):
        # instance - экземпляр uds.models.UserService
        
        user = None
        assigned = instance.user is not None
        
        if assigned:
            user = ServiceOwnerDetail(instance.user).data
        
        return {
            'name': instance.getName(),
            'assigned': assigned,
            'user': user,
        }
