import logging

from django.http import JsonResponse
from rest_framework.decorators import api_view, permission_classes
from rest_framework.generics import get_object_or_404
from rest_framework.response import Response
from rest_framework.views import APIView
from termidesk.api.permissions import AccessByServicePoolPermission
from uds.models import UserService
from .serializers.service import ServiceInfo

logger = logging.getLogger(__name__)

@api_view(['GET'])
@permission_classes([AccessByServicePoolPermission])
def settings(request, uuid_actor):
    user_service = get_object_or_404(UserService, uuid=uuid_actor)

    return Response({'debug': user_service.deployed_service.debug_mode})

class ServiceInfoView(APIView):
    """
    Получение информации о рабочем месте (сервисе)
    """

    serializer_class = ServiceInfo
    permission_classes = [AccessByServicePoolPermission]
    
    def get(self, request, uuid_actor):
        user_service = get_object_or_404(UserService, uuid=uuid_actor)
        
        service_info = ServiceInfo(user_service)
        
        return JsonResponse(service_info.data)