import datetime
import logging

from rest_framework.authtoken.models import Token
from rest_framework.authtoken.views import ObtainAuthToken
from rest_framework.response import Response
from termidesk.api.authentications import TOKEN_LIFETIME_IN_HOURS
from ..serializers.authtoken import AuthTokenSerializer

logger = logging.getLogger(__name__)


class TermideskRestAuthToken(ObtainAuthToken):
    """
       post:
       Аутентификация пользователя на базе ID аутентификатора, логина и пароля.
    """
    serializer_class = AuthTokenSerializer

    def post(self, request, *args, **kwargs):
        serializer = self.serializer_class(data=request.data,
                                           context={'request': request})

        serializer.is_valid(raise_exception=True)
        user = serializer.validated_data['user']
        try:
            token = Token.objects.get(user=user)
            token.delete()
        except Token.DoesNotExist:
            pass

        token = Token.objects.create(user=user)
        expires_at = token.created + datetime.timedelta(hours=TOKEN_LIFETIME_IN_HOURS)
        return Response({
            'token': token.key,
            'expires_at': expires_at
        })
