from datetime import datetime, timedelta

from rest_framework.authentication import TokenAuthentication
from rest_framework.exceptions import AuthenticationFailed

TOKEN_LIFETIME_IN_HOURS = 24


class ExpiringTokenAuthentication(TokenAuthentication):
    keyword = 'Bearer'

    @staticmethod
    def is_expired_token(time_of_creation):
        """ Проверка устаревания токена по времени. """
        obsolescence_time = (datetime.utcnow() - timedelta(hours=TOKEN_LIFETIME_IN_HOURS))
        return time_of_creation < obsolescence_time

    def authenticate(self, request):
        result = super().authenticate(request)
        if result is None:
            raise AuthenticationFailed('Invalid token format')

        return result

    def authenticate_credentials(self, key):
        model = self.get_model()
        try:
            token = model.objects.select_related('user').get(key=key)
        except model.DoesNotExist:
            raise AuthenticationFailed('Invalid token')

        if not token.user.is_active:
            raise AuthenticationFailed('User inactive or deleted')

        if self.is_expired_token(token.created):
            raise AuthenticationFailed('Token has expired')

        return token.user, token
