# -*- encoding: utf-8 -*-

import logging

from django.utils.translation import ugettext as _
from rest_framework import serializers
from rest_framework.validators import UniqueValidator
from uds.models.Provider import Provider

logger = logging.getLogger(__name__)


class ProviderSerializer(serializers.ModelSerializer):
    name = serializers.CharField(
        required=True,
        validators=[
            UniqueValidator(queryset=Provider.objects.all(),
                            message=_('Element already exists (duplicate key error)'))
        ]
    )
    type = serializers.SerializerMethodField()
    host = serializers.SerializerMethodField()
    maintenance = serializers.CharField(source='maintenance_mode')

    class Meta:
        model = Provider
        fields = ['uuid', 'name', 'type', 'host', 'maintenance']

    def get_type(self, instance):
        if not isinstance(instance, Provider):
            return ''

        return instance.getType().typeType

    def get_host(self, instance):
        if not isinstance(instance, Provider):
            return ''

        return instance.getInstance().host.value
