# -*- encoding: utf-8 -*-

import logging

from django.utils.translation import ugettext as _
from rest_framework import serializers
from rest_framework.validators import UniqueValidator
from termidesk.api.external.rubackup.draft.serializers.fields.uppercharfield import UpperCaseSerializerField
from uds.models.UserService import UserService

logger = logging.getLogger(__name__)


class UserServiceSerializer(serializers.ModelSerializer):
    name = serializers.CharField(
        required=True,
        source='friendly_name',
        validators=[
            UniqueValidator(queryset=UserService.objects.all(),
                            message=_('Element already exists (duplicate key error)'))
        ],
        help_text='Новое название ВМ'
    )
    workplace_id = serializers.CharField(
        source='deployed_service.uuid',
        help_text='Идентификатор фонда рабочих мест'
    )
    vm_id = serializers.SerializerMethodField(
        help_text=('Новый идентификатор ВМ c точки зрения платформы '
                   'виртуализации')
    )
    authenticator_id = serializers.SerializerMethodField()
    user_id = serializers.SerializerMethodField()
    allow_backup = serializers.CharField(
        source='deployed_service.backup',
        help_text='Разрешить резервное копирование'
    )
    unique_id = UpperCaseSerializerField(
        max_length=50,
        help_text=('Новый уникальный ID ВМ с точки зрения Термидеск '
                   '(обычно мак-адрес ВМ)')
    )

    class Meta:
        model = UserService
        fields = ['uuid', 'name', 'workplace_id',
                  'unique_id', 'vm_id', 'authenticator_id',
                  'user_id', 'allow_backup']
        extra_kwargs = {
            'uuid': {
                'help_text': 'UUID заменяемой ВМ'
            },
        }

    def get_vm_id(self, instance):
        if not isinstance(instance, UserService):
            return ''

        return instance.getInstance()._vmid

    def get_authenticator_id(self, instance):
        if not isinstance(instance, UserService) or instance.user is None:
            return ''

        return instance.user.manager.uuid

    def get_user_id(self, instance):
        if not isinstance(instance, UserService) or instance.user is None:
            return ''

        return instance.user.uuid
