# -*- encoding: utf-8 -*-

import logging

from django.utils.translation import ugettext as _
from rest_framework import serializers
from rest_framework.validators import UniqueValidator
from uds.models.ServicesPool import DeployedService
from uds.models.ServicesPoolGroup import ServicesPoolGroup

logger = logging.getLogger(__name__)


class WorkplaceSerializer(serializers.ModelSerializer):
    name = serializers.CharField(
        required=True,
        validators=[
            UniqueValidator(queryset=DeployedService.objects.all(),
                            message=_('Element already exists (duplicate key error)'))
        ]
    )
    group = serializers.SerializerMethodField()
    provider_id = serializers.CharField(source='service.provider.uuid')

    class Meta:
        model = DeployedService
        fields = ['uuid', 'name', 'group', 'provider_id']

    def get_group(self, instance):
        if not isinstance(instance, DeployedService):
            return ''

        if instance.servicesPoolGroup is None:
            return ServicesPoolGroup.default().name

        return instance.servicesPoolGroup.name
