# -*- encoding: utf-8 -*-

import logging

from rest_framework.generics import get_object_or_404
from rest_framework.schemas.openapi import AutoSchema

from termidesk.api.external.rubackup.draft.helpers import get_usable_user_services
from termidesk.api.external.rubackup.draft.serializers.userservice import UserServiceSerializer
from termidesk.api.external.rubackup.draft.views.common_viewset import CommonViewSet
from uds.core.util.State import State
from uds.models import UserService, Authenticator

logger = logging.getLogger(__name__)


class UsersWorkplaceViewSet(CommonViewSet):
    """
       list:
       Получить список назначенных ВРМ для указанного пользователя.
    """
    serializer_class = UserServiceSerializer
    http_method_names = ['get']

    schema = AutoSchema()

    def get_queryset(self):

        # Получаем объект-аутентификатор по uuid из запроса
        authenticator_uuid = self.kwargs['auth_uuid']
        authenticator = get_object_or_404(Authenticator, uuid=authenticator_uuid)
        # В целях безопасности проверяем, что пользователь `user_uuid`
        # есть в домене аутентификации `auth_uuid`
        user_uuid = self.kwargs['user_uuid']
        user = get_object_or_404(authenticator.users, uuid=user_uuid, state=State.ACTIVE)

        # Получение списка ВМ, назначенных указанному пользователю
        user_services = UserService.objects.filter(user__uuid=user.uuid)

        return get_usable_user_services(user_services)
