# -*- encoding: utf-8 -*-

from rest_framework.permissions import IsAuthenticated
from rest_framework.schemas.openapi import AutoSchema
from rest_framework.viewsets import ModelViewSet
from termidesk.api.authentications import ExpiringTokenAuthentication
from termidesk.api.decorators import ApiPermission
from termidesk.api.external.rubackup.draft.paginator import (
    ListResultsPagination
)
from termidesk.models.UserPermissionApi import RUBACKUP


class CommonViewSet(ModelViewSet):
    # Для всех ресурсов возвращающих список необходимо использовать постраничный вывод информации
    pagination_class = ListResultsPagination

    authentication_classes = [ExpiringTokenAuthentication]
    permission_classes = [IsAuthenticated, ApiPermission(RUBACKUP)]

    schema = AutoSchema()

    def get_serializer_context(self):
        return {
            'request': self.request,
            'format': self.format_kwarg,
            'view': self
        }

    def get_serializer(self, *args, **kwargs):
        kwargs['context'] = self.get_serializer_context()
        return self.serializer_class(*args, **kwargs)
