import logging

from django.shortcuts import get_object_or_404
from rest_framework.permissions import IsAuthenticated
from rest_framework.response import Response
from rest_framework.viewsets import ModelViewSet
from termidesk.api.authentications import ExpiringTokenAuthentication
from termidesk.api.decorators import ApiPermission
from termidesk.api.external.rubackup.draft.serializers.userservice import UserServiceSerializer
from termidesk.models.UserPermissionApi import RUBACKUP
from uds.core.managers.userservice.opchecker import UserServiceOpChecker
from uds.core.util.State import State
from uds.models.UserService import UserService
from uds.models.UserServiceProperty import UserServiceProperty

logger = logging.getLogger(__name__)


class UserServiceViewSet(ModelViewSet):
    authentication_classes = [ExpiringTokenAuthentication]
    permission_classes = [IsAuthenticated, ApiPermission(RUBACKUP)]
    http_method_names = ['patch']
    serializer_class = UserServiceSerializer

    def partial_update(self, request, *args, **kwargs):
        '''Замена экземпляра рабочего места на другую ВМ'''
        user_service = get_object_or_404(UserService, uuid=self.request.data['uuid'])
        serializer = UserServiceSerializer(user_service, data=self.request.data, partial=True)
        serializer.is_valid(True)
        serializer.save()

        # Установка данных внутри instance и фиксация очереди на запуск замененной ВМ
        instance = user_service.getInstance()
        # нужно передавать поля из запроса
        # некоторые поля из сериализатора read_onle и не будут заменены, если передавать данные сериализатора
        instance.replace(self.request.data)
        instance.setupQueueForReplacement()

        # удаление старых значений дополнительных полей
        UserServiceProperty.objects.filter(user_service_id=user_service.id).delete()

        user_service.setOsState(State.PREPARING)

        # Обновление data параметра
        user_service.data = instance.serialize()

        user_service.setState(State.PREPARING)
        user_service.save()

        # Запуск фонового процесса для обработки/инициализации ВМ
        UserServiceOpChecker.makeUnique(user_service, instance, State.RUNNING)

        return Response(serializer.data)
