from rest_framework.response import Response
from rest_framework.schemas.openapi import SchemaGenerator
from rest_framework.views import APIView
from termidesk.api.permissions import IsAuthAdmin


class OpenApiSchemaView(APIView):
    schema = None  # exclude swagger path from the API documentation
    permission_classes = [IsAuthAdmin]

    def get(self, request):
        generator = SchemaGenerator(title='Документация Termidesk API',
                                    url="/api",
                                    urlconf='termidesk.api.urls')
        schema = generator.get_schema()

        # Добавление информации о механизмах аутентификации
        schema['components']['securitySchemes'] = {
            'bearerAuth': {
                'type': 'http',
                'scheme': 'bearer',
                'description': ('Для аутентифкации в модулях раздела **external**.  '
                                'Получить токен можно в модуле **auth**.')
            },
            'legacyTokenAuth': {
                'type': 'apiKey',
                'in': 'header',
                'name': 'X-Auth-Token',
                'description': ('Альтернативный способ аутентифкации в модулях раздела **webui**.   \n'
                                'Представляет собой идентификатор HTTP сессии пользователя.   \n'
                                'Может быть получен через /rest/auth/login.')
            }
        }

        for path in schema['paths']:
            if path.startswith("/api/external"):
                for op in schema['paths'][path]:
                    schema['paths'][path][op]['security'] = [
                        {
                            'bearerAuth': []
                        },
                    ]

            if path.startswith("/api/webui"):
                for op in schema['paths'][path]:
                    schema['paths'][path][op]['security'] = [
                        {
                            'legacyTokenAuth': []
                        },
                    ]

        return Response(schema)
