import logging

from django.contrib.auth.decorators import permission_required
from rest_framework.decorators import api_view, authentication_classes, permission_classes
from rest_framework.permissions import IsAuthenticated
from rest_framework.response import Response
from rest_framework.views import APIView
from termidesk.api.authentications import ExpiringTokenAuthentication
from termidesk.api.decorators import ApiPermission, extra_permission_classes
from termidesk.models.UserPermissionApi import TEXT_READ, TEXT_WRITE

logger = logging.getLogger(__name__)


@api_view(['GET'])
@authentication_classes([ExpiringTokenAuthentication])
@permission_classes([IsAuthenticated])
@permission_required(TEXT_READ, raise_exception=True)
def example_function_view(request, format=None):
    content = {
        'status': 'This is example_function_view'
    }
    return Response(content)


class Test(APIView):
    """
    View to list all logs.
    """
    authentication_classes = [ExpiringTokenAuthentication]
    permission_classes = [IsAuthenticated, ApiPermission(TEXT_READ)]

    @extra_permission_classes((TEXT_READ,))
    def get(self, request, format=None):
        return Response('This is the GET method')

    @extra_permission_classes((TEXT_WRITE,))
    def post(self, request, format=None):
        return Response('This is the POST method')
