from django.conf.urls import url
from django.urls import include
from termidesk.api.agent import urls as agent_urls
from termidesk.api.auth import urls as auth_urls
from termidesk.api.discover import urls as discover_urls
from termidesk.api.external import urls as external_urls
from termidesk.api.test import urls as test_urls
from termidesk.api.permissions import NAME_DOCUMENTATION
from termidesk.api.swagger_schema import OpenApiSchemaView
from termidesk.api.webui import urls as webui_urls
from termidesk.api.wsproxy import urls as wsproxy_urls
from django.views.generic import TemplateView

import config

docs_path = r'^{}/'.format(NAME_DOCUMENTATION)

app_name = 'api'

urlpatterns = [
    url(r'^agent/', include(agent_urls, namespace='agent')),
    url(r'^webui/', include(webui_urls, namespace='webui')),
    url(r'^auth/', include(auth_urls, namespace='auth')),
    url(r'^external/', include(external_urls, namespace='external')),
    url(r'^wsproxy/', include(wsproxy_urls, namespace='wsproxy')),
    url(r'^discover/', include(discover_urls, namespace='discover')),
    url(r'^schema/openapi', OpenApiSchemaView.as_view(), name='schema-openapi'),

    url(docs_path, TemplateView.as_view(
        template_name='termidesk/api/swagger-ui.html',
        extra_context={'schema_url': 'api:schema-openapi'}
    ), name='swagger-ui'),

]

if config.DJANGO_DEBUG:
    urlpatterns.append(url(r'^test/', include(test_urls, namespace='test')))