'''
Created on 10 февр. 2022 г.

@author: dvd
'''
from django.utils.translation import ugettext_lazy as _
from uds.core.ui import gui as GUI


class GuiHelper(object):
    """
    Коллекция вспомогательных функций для формирования списка полей
     для фронтенда.
    """

    @staticmethod
    def add_field(gui, field):
        """
        Add a field to a "gui" description.
        This method checks that every required field element is in there.
        If not, defaults are assigned
        :param gui: List of "gui" items where the field will be added
        :param field: Field to be added (dictionary)
        """
        v = {
            'name': field.get('name', ''),
            'value': '',
            'gui': {
                'required': field.get('required', False),
                'defvalue': field.get('value', ''),
                'value': field.get('value', ''),
                'minValue': field.get('minValue', '987654321'),
                'label': field.get('label', ''),
                'length': field.get('length', 128),
                'multiline': field.get('multiline', 0),
                'tooltip': field.get('tooltip', ''),
                'rdonly': field.get('rdonly', False),
                'type': field.get('type', GUI.InputField.TEXT_TYPE),
                'order': field.get('order', 0),
                'values': field.get('values', [])
            }
        }
        if 'tab' in field:
            v['gui']['tab'] = field['tab']
        gui.append(v)
        return gui

    @staticmethod
    def add_default_fields(gui, fields):
        """
        Adds default fields (based in a list) to a "gui" description
        :param gui: Gui list where the "default" fields will be added
        :param fields: List of fields names requested to be added.
                       Valid values are 'name', 'comments', 'priority' and 'small_name'
        """
        if 'tags' in fields:
            GuiHelper.add_field(gui, {
                'name': 'tags',
                'label': _('Теги'),
                'type': 'taglist',
                'tooltip': _('Теги для данного объекта'),
                'order': 0 - 101,
            })

        if 'name' in fields:
            GuiHelper.add_field(gui, {
                'name': 'name',
                'required': True,
                'label': _('Название'),
                'length': 128,
                'tooltip': _('Имя объекта'),
                'order': 0 - 100,
            })

        if 'comments' in fields:
            GuiHelper.add_field(gui, {
                'name': 'comments',
                'label': _('Комментарий'),
                'tooltip': _('Комментарий для объекта'),
                'length': 256,
                'order': 0 - 99,
            })

        if 'priority' in fields:
            GuiHelper.add_field(gui, {
                'name': 'priority',
                'type': 'numeric',
                'label': _('Приоритет'),
                'tooltip': _('Приоритет для данного объекта (чем меньше число, тем выше приоритет)'),
                'required': True,
                'value': 1,
                'length': 4,
                'order': 0 - 97,
            })

        if 'small_name' in fields:
            GuiHelper.add_field(gui, {
                'name': 'small_name',
                'type': 'text',
                'label': _('Метка'),
                'tooltip': _('Метка (короткое имя) для данного объекта'),
                'required': True,
                'length': 128,
                'order': 0 - 96,
            })

        return gui
