# -*- encoding: utf-8 -*-

import logging

from django.contrib.auth.models import Permission
from termidesk.api.webui.serializers.acl.entity import EntitySerializer
from django.contrib.contenttypes.models import ContentType
from termidesk.models.UserPermission import (
    DEPLOYED_SERVICE_CHANGE, DEPLOYED_SERVICE_DELETE, DEPLOYED_SERVICE_VIEW,
    DS_PUBLICATION_MANAGE, DS_USER_MANAGE, DS_USER_SERVICE_MANAGE, DS_GROUP_MANAGE, DS_TRANSPORT_MANAGE)
from uds.core.ui.UserInterface import gui
from uds.models.ServicesPool import DeployedService

logger = logging.getLogger(__name__)


class WorkplaceEntitySerializer(EntitySerializer):
    # наименование группы объектов, которое будет отображаться в списке
    title = "Фонд рабочих мест"

    # модель для работы с данными
    model = DeployedService

    @staticmethod
    def get_gui_objects():
        """ Получить GUI представление всех доступных фондов. """
        return (gui.choiceItem(ds.uuid, ds.name)
                for ds in WorkplaceEntitySerializer.model.objects.order_by('name').all())

    @staticmethod
    def get_gui_allow_permissions():
        return (gui.choiceItem(permission.id, permission.name)
                for permission in WorkplaceEntitySerializer.get_allow_permissions())

    @staticmethod
    def get_allow_permissions():
        content_type = ContentType.objects.get_for_model(DeployedService)
        return Permission.objects.filter(
            codename__in=[DEPLOYED_SERVICE_VIEW, DEPLOYED_SERVICE_CHANGE, DEPLOYED_SERVICE_DELETE,
                          DS_PUBLICATION_MANAGE, DS_USER_MANAGE, DS_USER_SERVICE_MANAGE,
                          DS_GROUP_MANAGE, DS_TRANSPORT_MANAGE],
            content_type_id=content_type.id
        ).order_by('name').all()
