"""
Модуль содержит реализацию сериализатора событий аудита из локальной БД
"""
# -*- encoding: utf-8 -*-

import logging

from rest_framework import serializers
from termidesk.models.AuditEvent import AuditEvent

logger = logging.getLogger(__name__)


class AuditEventsSerializer(serializers.ModelSerializer):
    """Cериализатор событий аудита из локальной БД"""

    timestamp = serializers.DateTimeField(required=False)
    event = serializers.CharField(required=False)
    description = serializers.SerializerMethodField()

    class Meta:
        model = AuditEvent
        fields = ['timestamp', 'event', 'description', ]

    def get_description(self, instance):
        """Получение описания события"""
        if not isinstance(instance, self.Meta.model):
            return None

        from termidesk.audit.renderers import AuditEventTextRenderer
        return AuditEventTextRenderer().render(instance)
