# -*- encoding: utf-8 -*-

from rest_framework import serializers


# Aggregate Card Structure

class Notifications(serializers.Serializer):
    name = serializers.CharField(required=True, max_length=128)
    label = serializers.CharField(required=True, max_length=128)
    count = serializers.IntegerField(required=True, min_value=0)
    icon = serializers.CharField(required=True, max_length=128)
    href = serializers.CharField(required=True, max_length=128,
                                 allow_blank=True)


class AggregateCard(serializers.Serializer):
    label = serializers.CharField(required=True, max_length=128)
    count = serializers.IntegerField(required=True, min_value=0)
    url = serializers.CharField(required=True, max_length=128)
    icon = serializers.CharField(required=True, max_length=128)
    notifications = Notifications(required=True, many=True)


# Charts Structure

class Description(serializers.Serializer):
    line1 = serializers.CharField(required=True, max_length=128)
    line2 = serializers.CharField(required=True, max_length=128)


class Chart(serializers.Serializer):
    type = serializers.CharField(required=True, max_length=128)
    units = serializers.CharField(required=True, max_length=128,
                                  allow_blank=True)
    title = serializers.CharField(required=True, max_length=128)
    count = serializers.IntegerField(required=True, min_value=0)
    data = serializers.ListField(allow_empty=True)


class Charts(serializers.Serializer):
    id = serializers.CharField(required=True, max_length=128)
    type = serializers.CharField(required=True, max_length=128)
    title = serializers.CharField(required=True, max_length=128)
    count = serializers.IntegerField(required=True, min_value=0)
    description = Description()
    chart = Chart()


# Dashboard

class DashboardSerializer(serializers.Serializer):
    aggregate_card = AggregateCard(many=True)
    charts = Charts(many=True)
    utilization_bar = serializers.DictField(allow_empty=True)
