# -*- encoding: utf-8 -*-

import logging

from django.contrib.auth.models import Group
from rest_framework import serializers
from rest_framework.validators import UniqueValidator
from termidesk.models.UserPermission import get_user_permissions

logger = logging.getLogger(__name__)


class GroupSerializer(serializers.ModelSerializer):
    name = serializers.CharField(
        required=True,
        label='Название',
        help_text='Название роли',
        validators=[
            UniqueValidator(
                queryset=Group.objects.all(),
                message='Роль с таким именем уже существует.'
            )
        ],
    )

    class Meta:
        model = Group
        fields = ['id', 'name', 'permissions']

    def to_representation(self, instance):
        ret = super().to_representation(instance)
        ret['permissions'] = [str(permission) for permission in ret['permissions']]

        return ret

    def validate(self, attrs):
        user_permissions = [permission.id for permission in get_user_permissions()]

        for permission in attrs['permissions']:
            if permission.id not in user_permissions:
                raise serializers.ValidationError({
                    'permissions': (
                        'Указанный идентификатор \'{}\' не является идентификатором пользовательских разрешений. '
                        'Допустимы только {}'.format(permission.id, user_permissions)
                    )
                })

        return super().validate(attrs)
