import logging

from rest_framework.exceptions import APIException
from rest_framework import serializers
from uds.models.Image import Image as ImageModel

logger = logging.getLogger(__name__)


class ImageSerializer(serializers.ModelSerializer):
    """ Расширенный сериализатор для работы с детальной параметов гостевых ОС. """
    id = serializers.CharField(source='uuid', required=False, read_only=True)
    data = serializers.CharField(source='data_param', required=True)

    class Meta:
        model = ImageModel
        fields = ['id', 'name', 'data']

    def validate(self, attrs):
        logger.debug('Before {0}'.format(attrs))

        return super().validate(attrs)

    def create(self, validated_data):
        name = validated_data.get('name')
        image = ImageModel(name=name)

        return self.validate_object_and_save(image)

    def update(self, instance: ImageModel, validated_data: dict):
        instance.name = validated_data.get('name', instance.name)

        return self.validate_object_and_save(instance)

    def validate_object_and_save(self, image: ImageModel):
        try:
            image.data = ImageModel.prepareForDb(ImageModel.decode64(self.initial_data.get('data')))
            image.save()

            # Updates the thumbnail and re-saves it
            logger.debug('After save: item = {}'.format(image))
            image.updateThumbnail()
            image.save()
        except Exception as error:
            raise APIException(
                'An error has occurred at creating an image: {0}.'. format(error)
            )

        return image


class ImageOverviewSerializer(serializers.ModelSerializer):
    id = serializers.CharField(source='uuid', required=False, read_only=True)
    size = serializers.SerializerMethodField()

    class Meta:
        model = ImageModel
        fields = ['id', 'name', 'size', 'thumb']

    def get_size(self, instance):
        if not isinstance(instance, ImageModel):
            return ''
        return '{}x{}, {} байт'.format(
            instance.width, instance.height, len(instance.data), len(instance.thumb)
        )
