import logging

from rest_framework import serializers
from termidesk.models.PolicyGlobal import PolicyGlobal
from termidesk.core.policies.utils import registry, get_policy_class_by_type

logger = logging.getLogger(__name__)


class PolicySerializer(serializers.Serializer):
    name = serializers.CharField(required=False, max_length=128, label="Название", read_only=True)
    data_type = serializers.CharField(required=False, label="Тип объекта", read_only=True)
    value = serializers.CharField(required=True, label="Значение")
    view_value = serializers.CharField(read_only=True)
    description = serializers.CharField(label="Описание", read_only=True)

    class Meta:
        fields = ["name", "data_type", "value", "view_value", "description"]

    def validate(self, attrs):
        code_policy = get_policy_class_by_type(self.initial_data.get("data_type"))
        code_policy.check_value(attrs.get("value"))

        return super().validate(attrs)

    def create(self, validated_data):
        data_type = self.initial_data.get("data_type")
        policy_type = registry().lookup(data_type)

        policy = PolicyGlobal(name=policy_type.typeName, data_type=data_type)

        policy_instance = policy.getInstance({"value": validated_data.get("value")})
        policy.data = policy_instance.serialize()
        policy.save()

        return policy

    def update(self, policy, validated_data):
        policy_type = policy.getInstance({"value": validated_data.get("value")})

        policy.data = policy_type.serialize()
        policy.save()

        return policy
