from rest_framework import serializers
from uds.models.Group import Group


class GroupListSerializer(serializers.ModelSerializer):
    """ Сериализатор получения групп фонда рабочих мест. """
    id = serializers.UUIDField(source='uuid', required=False, read_only=True)
    auth_id = serializers.UUIDField(source='manager.uuid')
    auth_name = serializers.CharField(source='manager.name')
    type = serializers.SerializerMethodField()

    class Meta:
        model = Group
        fields = ['id', 'auth_id', 'name', 'comments', 'state', 'type', 'auth_name']

    def get_type(self, instance):
        if not isinstance(instance, Group):
            return Group.DATA_TYPE_GROUP
        return instance.is_meta and Group.DATA_TYPE_META or Group.DATA_TYPE_GROUP


class GroupServicePoolSerializer(serializers.Serializer):
    """ Сериализатор для добавления групп в фонд рабочих мест. """
    domain = serializers.UUIDField()
    id = serializers.UUIDField()
    tags = serializers.ListField()

    class Meta:
        fields = ['domain', 'id', 'tags']
