from rest_framework import serializers
from uds.core.util.State import State
from uds.models.ServicesPoolPublication import ServicePoolPublication


class PublicationListSerializer(serializers.ModelSerializer):
    """ Сериализатор получения публикаций фонда рабочих мест. """
    id = serializers.UUIDField(source='uuid', required=False, read_only=True)
    reason = serializers.SerializerMethodField()
    publish_date = serializers.SerializerMethodField()

    class Meta:
        model = ServicePoolPublication
        fields = ['id', 'revision', 'publish_date', 'state', 'reason', 'state_date']

    def get_reason(self, instance):
        if not isinstance(instance, ServicePoolPublication):
            return ''

        return (State.isErrored(instance.state)
                and instance.getInstance().reasonOfError()
                or instance.reason
                or '')

    def get_publish_date(self, instance):
        return (
            int(instance.publish_date.timestamp()) if isinstance(instance, ServicePoolPublication) else None
        )


class PublicationSerializer(serializers.Serializer):
    """ Сериализатор для осуществления публикации фонда рабочих мест. """
    changelog = serializers.CharField()

    class Meta:
        fields = ['changelog']
