# -*- encoding: utf-8 -*-
import logging

from django.utils.translation import ugettext as _
from rest_framework import serializers
from rest_framework.validators import UniqueValidator
from uds.models.ServicesPoolGroup import ServicesPoolGroup

logger = logging.getLogger(__name__)


class ServicePoolGroupSerializer(serializers.ModelSerializer):
    id = serializers.CharField(source='uuid', required=False)
    name = serializers.CharField(
        required=True,
        validators=[
            UniqueValidator(
                queryset=ServicesPoolGroup.objects.all(),
                message=_('Element already exists (duplicate key error)')
            )
        ],
        label='Название',
        help_text='Название группы',
    )
    comments = serializers.CharField(
        required=False,
        label='Комментарий',
        allow_blank=True,
        help_text='Комментарий группы',
    )
    priority = serializers.IntegerField()
    image_id = serializers.SerializerMethodField()

    class Meta:
        model = ServicesPoolGroup
        fields = ['id', 'name', 'comments', 'priority', 'image_id']

    def create(self, validated_data):
        group_name = validated_data.get('name')
        group_comments = validated_data.get('comments')
        group_priority = validated_data.get('priority')
        group = ServicesPoolGroup(
            name=group_name, comments=group_comments, priority=group_priority
        )
        group.save()
        return group

    def update(self, instance, validated_data):
        instance.name = validated_data['name']
        instance.comments = validated_data['comments']
        instance.priority = validated_data['priority']
        # instance.image_id = validated_data['image_id']
        instance.save()
        return instance

    def get_image_id(self, instance):
        if not isinstance(instance, ServicesPoolGroup):
            return 0
        return instance.image_id

    def validate(self, attrs):
        data = self.context.get('request').data
        logger.debug('Before {0}'.format(attrs))
        attrs['name'] = data['name']

        if isinstance(data['priority'], int):
            attrs['priority'] = data['priority']
        else:
            attrs['priority'] = int(data['priority'])

        try:
            attrs['comments'] = data['comments']
            # attrs['image_id'] = data['image_id']
        except Exception as e:
            raise serializers.ValidationError('Invalid group: ' + str(e))

        return super().validate(attrs)
