# -*- encoding: utf-8 -*-

from django.conf.urls import url
from django.urls import path
from termidesk.api.webui.views import Index
from termidesk.api.webui.views.acl import AccessControlList
from termidesk.api.webui.views.authenticators import Authenticators, AuthenticatorSearch
from termidesk.api.webui.views.auth_groups import AuthGroupManagers
from termidesk.api.webui.views.auth_users import AuthUserManagers
from termidesk.api.webui.views.dashboard import Dashboard
from termidesk.api.webui.views.policies import Policies
from termidesk.api.webui.views.tconfig import TConfig
from termidesk.api.webui.views.gallery import Images
from termidesk.api.webui.views.gui_callback import GuiCallback
from termidesk.api.webui.views.monitoring import Monitoring
from termidesk.api.webui.views.networks import Networks
from termidesk.api.webui.views.networks_gui import NetworksGui
from termidesk.api.webui.views.spgroups import ServicesPoolGroup
from termidesk.api.webui.views.osmanagers import OSManagers
from termidesk.api.webui.views.rbac import Rbac
from termidesk.api.webui.views.services_pools import ServicesPools
from termidesk.api.webui.views.servicespool.assigneduserservice import AssignedUserService
from termidesk.api.webui.views.servicespool.cacheduserservice import CachedUserService
from termidesk.api.webui.views.spsessions import SpSessions
from termidesk.api.webui.views.audit_events import AuditEventsView
from termidesk.api.webui.views.transports import Transports, TransportsByType, TransportsByUUID
from termidesk.api.webui.views.servicespool.users import UsersOverviewServicePool, UsersServicePool
from termidesk.api.webui.views.servicespool.groups import GroupsOverviewServicePool, GroupsServicePool
from termidesk.api.webui.views.servicespool.transports import (TransportsServicePool,
                                                               TransportsOverviewServicePool)
from termidesk.api.webui.views.servicespool.publications import (PublishServicePool,
                                                                 PublicationsServicePool,
                                                                 PublicationsOverviewServicePool)
from termidesk.api.webui.views.servicespool.policies import PoliciesDeployedServices
from termidesk.api.webui.views.policies_gui import PoliciesGui

app_name = 'webui'
service_pool_groups_detail_action = ServicesPoolGroup.as_view(
    {'get': 'retrieve', 'put': 'update', 'delete': 'delete', }
)
network_detail_action = Networks.as_view(
    {'get': 'get_network', 'put': 'update_network', 'delete': 'delete_network', }
)
osmanager_detail_action = OSManagers.as_view({'get': 'retrieve', 'put': 'update', 'delete': 'delete', })
auth_group_detail_action = AuthGroupManagers.as_view({'get': 'retrieve', 'put': 'update', 'delete': 'delete'})
auth_user_detail_action = AuthUserManagers.as_view({'get': 'retrieve', 'put': 'update', 'delete': 'delete'})

transport_detail_action = TransportsByUUID.as_view(
    {'get': 'get_transport', 'put': 'update_transport', 'delete': 'delete_transport', }
)

domain_detail_action = Authenticators.as_view({'get': 'retrieve', 'put': 'update', 'delete': 'delete',} )

image_detail_action = Images.as_view({'get': 'retrieve', 'put': 'update', 'delete': 'delete'} )

servicespools_detail_action = ServicesPools.as_view({'get': 'retrieve', 'put': 'update', 'delete': 'delete', })

rbac_detail_action = Rbac.as_view({'get': 'retrieve', 'put': 'update', 'delete': 'delete', })

acl_detail_action = AccessControlList.as_view({'get': 'retrieve', 'put': 'update', 'delete': 'delete', })

urlpatterns = [
    url(r'^$', Index.as_view(), name='index'),

    # Системные настройки
    url(r'^tconfig/overview$', TConfig.as_view({'get': 'get'}), name="tconfig_overview"),
    url(r'^tconfig', TConfig.as_view({'get': 'get', 'put': 'put'}), name="tconfig"),

    # Страница "Обзор"
    url(r'^dashboard/overview$', Dashboard.as_view(), name="dashboard"),

    # Мониторинг
    url(r'^monitoring/overview$', Monitoring.as_view({'get': 'list',}), name="monitoring"),
    url(r'^monitoring', Monitoring.as_view({'get': 'list',}), name="monitoring"),

    # Настройки -> Группы рабочих мест
    url(r'^spgroups$', ServicesPoolGroup.as_view({'put': 'create', }), name="servicespoolgroups"),
    url(r'^spgroups/gui$', ServicesPoolGroup.as_view({'get': 'gui', }), name="servicespoolgroups_gui"),
    url(r'^spgroups/overview$', ServicesPoolGroup.as_view({'get': 'overview', }), name="servicespoolgroups_overview"),
    # шаблон `r'^servicespoolgroup/(?P<uuid>.+)$'` должен располагаться самым последним,
    # иначе он подхватывает на себя `networks/gui` и `networks/overview`
    url(r'^spgroups/(?P<uuid>.+)$', service_pool_groups_detail_action, name="servicespoolgroups_detail"),

    # Компоненты -> Сети
    url(r'^networks$', Networks.as_view({'put': 'create_network', }), name="networks"),
    url(r'^networks/gui$', NetworksGui.as_view(), name="networks_gui"),
    url(r'^networks/overview$', Networks.as_view({'get': 'networks_overview', }), name="networks_overview"),
    # шаблон `r'^networks/(?P<uuid>.+)$'` должен располагаться самым последним,
    # иначе он подхватывает на себя `networks/gui` и `networks/overview`
    url(r'^networks/(?P<uuid>.+)$', network_detail_action, name="networks_detail"),

    url(r'^osmanagers$', OSManagers.as_view({'put': 'create', 'get': 'list'}), name="osmanagers"),
    url(r'^osmanagers/gui/(?P<type>.+)$', OSManagers.as_view({'get': 'gui', }), name="osmanagers_gui"),
    url(r'^osmanagers/overview$', OSManagers.as_view({'get': 'overview', }), name="osmanagers_overview"),
    url(r'^osmanagers/types$', OSManagers.as_view({'get': 'get_types', }), name="types_osmanagers"),
    url(r'^osmanagers/(?P<uuid>.+)$', osmanager_detail_action, name="detail"),

    # Мониторинг -> Аудит
    # Получение типов событий аудита
    url(r'^audit/events/types', AuditEventsView.as_view({'get': 'get_audit_events_types', }),
        name="audit_events_types"),
    # Просмотр событий аудита из локальной БД
    url(r'^audit/events', AuditEventsView.as_view({'get': 'get_audit_events', }), name="audit_events"),

    # Компоненты -> Протоколы доставки
    url(r'^transports$', Transports.as_view({'put': 'create_transport', }), name="transports"),
    url(r'^transports/gui/(?P<transport_type>.+)$', TransportsByType.as_view({'get': 'transports_gui', }),
        name="transports_gui"),
    url(r'^transports/test/(?P<transport_type>.+)$', TransportsByType.as_view({'post': 'transports_test', }),
        name="transports_test"),
    url(r'^transports/overview$', Transports.as_view({'get': 'transports_overview', }),
        name="transports_overview"),
    url(r'^transports/types$', Transports.as_view({'get': 'transports_types', }),
        name="transports_types"),
    # шаблон `r'^transports/(?P<uuid>.+)$'` должен располагаться самым последним,
    # иначе он подхватывает на себя `transports/gui` и `transports/overview`
    url(r'^transports/(?P<uuid>.+)$', transport_detail_action, name="transports_detail"),

    # Домены аутентификации
    url(r'^authenticators$', Authenticators.as_view({'put': 'create', 'get': 'list'}), name="authenticators"),
    url(r'^authenticators/gui/(?P<type>.+)$', Authenticators.as_view({'get': 'gui', }), name="authenticator_gui"),
    url(r'^authenticators/overview$', Authenticators.as_view({'get': 'overview', }),
        name="authenticator_overview"),
    url(r'^authenticators/types$', Authenticators.as_view({'get': 'get_types', }), name="authenticators_types"),
    url(r'^authenticators/test/(?P<type>.+)$', Authenticators.as_view({'post': 'test', }), name="authenticator_test"),
    url(r'^authenticators/(?P<uuid>.+)/search$', AuthenticatorSearch.as_view({'get': 'list'}), name="auth_search"),

    # Группы доменов аутентификации
    url(r'^authenticators/(?P<auth_uuid>.+)/groups$',
        AuthGroupManagers.as_view({'put': 'create', 'get': 'list'}), name="auth_groups"),
    url(r'^authenticators/(?P<auth_uuid>.+)/groups/gui/(?P<group_type>.+)$',
        AuthGroupManagers.as_view({'get': 'gui', }), name="auth_groups_gui"),
    url(r'^authenticators/(?P<auth_uuid>.+)/groups/overview$',
        AuthGroupManagers.as_view({'get': 'list', }), name="auth_groups_overview"),
    url(r'^authenticators/(?P<auth_uuid>.+)/groups/types$',
        AuthGroupManagers.as_view({'get': 'get_types', }), name="types_auth_groups"),
    url(r'^authenticators/(?P<auth_uuid>.+)/groups/(?P<uuid>.+)/users$',
        AuthGroupManagers.as_view({'get': 'get_users', }), name="auth_group_users"),
    url(r'^authenticators/(?P<auth_uuid>.+)/groups/(?P<uuid>.+)/servicesPools$',
        AuthGroupManagers.as_view({'get': 'get_services_pools', }), name="auth_group_servicesPools"),
    url(r'^authenticators/(?P<auth_uuid>.+)/groups/(?P<uuid>.+)$',
        auth_group_detail_action, name="detail_auth_groups"),

    # Пользователи доменов аутентификации
    url(r'^authenticators/(?P<auth_uuid>.+)/users$',
        AuthUserManagers.as_view({'put': 'create', 'get': 'list'}), name="auth_users"),
    url(r'^authenticators/(?P<auth_uuid>.+)/users/gui$',
        AuthUserManagers.as_view({'get': 'gui', }), name="auth_users_gui"),
    url(r'^authenticators/(?P<auth_uuid>.+)/users/gui/$',
        AuthUserManagers.as_view({'get': 'gui', }), name="auth_users_gui"),
    url(r'^authenticators/(?P<auth_uuid>.+)/users/overview$',
        AuthUserManagers.as_view({'get': 'list', }), name="auth_users_overview"),
    url(r'^authenticators/(?P<auth_uuid>.+)/users/types$',
        AuthUserManagers.as_view({'get': 'get_types', }), name="types_auth_users"),
    url(r'^authenticators/(?P<auth_uuid>.+)/users/(?P<uuid>.+)/userServices$',
        AuthUserManagers.as_view({'get': 'get_user_services', }), name="user_services"),
    url(r'^authenticators/(?P<auth_uuid>.+)/users/(?P<uuid>.+)/servicesPools$',
        AuthUserManagers.as_view({'get': 'get_services_pools', }), name="auth_user_servicesPools"),
    url(r'^authenticators/(?P<auth_uuid>.+)/users/(?P<uuid>.+)/log$',
        AuthUserManagers.as_view({'get': 'get_logs', }), name="auth_user_logs"),
    url(r'^authenticators/(?P<auth_uuid>.+)/users/(?P<uuid>.+)$',
        auth_user_detail_action, name="detail_auth_users"),

    url(r'^authenticators/(?P<uuid>.+)/log$', Authenticators.as_view({'get': 'get_logs', }), name="auth_logs"),
    # шаблон `r'^authenticators/(?P<uuid>.+)$'` должен располагаться самым последним,
    # иначе он подхватывает на себя `authenticators/gui` и `authenticators/overview`
    url(r'^authenticators/(?P<uuid>.+)$', domain_detail_action, name="authenticator_detail"),

    # Галерея
    url(r'^gallery/images$', Images.as_view({'put': 'create', 'get': 'list'}), name="images"),
    url(r'^gallery/images/gui$', Images.as_view({'get': 'gui', }), name="images_gui"),
    url(r'^gallery/images/overview$', Images.as_view({'get': 'overview', }), name="images_overview"),
    url(r'^gallery/images/(?P<uuid>.+)$', image_detail_action, name="images_detail"),

    # Фонд рабочих мест
    url(r'^servicespools$', ServicesPools.as_view({'put': 'create', 'get': 'list'}), name="servicespools"),
    url(r'^servicespools/gui$', ServicesPools.as_view({'get': 'gui', }), name="servicespools_gui"),
    url(r'^servicespools/overview$', ServicesPools.as_view({'get': 'overview', }),
        name="servicespools_overview"),
    url(r'^servicespools/types$', ServicesPools.as_view({'get': 'get_types', }), name="servicespools_types"),
    # Кэшированные рабочие места
    url(r'^servicespools/(?P<uuid>.+)/cache/overview$',
        CachedUserService.as_view({'get': 'get_cached'}), name="cached_overview"),
    url(r'^servicespools/(?P<uuid>.+)/cache/(?P<service_uuid>.+)/log$',
        CachedUserService.as_view({'get': 'get_cached_log'}), name="cached_log"),
    url(r'^servicespools/(?P<uuid>.+)/cache/(?P<service_uuid>.+)$',
        CachedUserService.as_view({'delete': 'delete_cached'}), name="delete_cached"),
    # Назначенные рабочие места
    url(r'^servicespools/(?P<uuid>.+)/services/overview$',
        AssignedUserService.as_view({'get': 'get_assigned'}), name="assigned_overview"),
    url(r'^servicespools/(?P<uuid>.+)/services/(?P<service_uuid>.+)/log$',
        AssignedUserService.as_view({'get': 'get_assigned_log'}), name="assigned_log"),
    url(r'^servicespools/(?P<uuid>.+)/services/(?P<service_uuid>.+)$',
        AssignedUserService.as_view({'delete': 'delete_assigned'}), name="delete_assigned"),
    # Пользователи рабочих мест
    path('servicespools/<servicespool_uuid>/users/overview',
        UsersOverviewServicePool.as_view({'get': 'list'}), name="servicespool_user_overview"),
    path('servicespools/<uuid:servicespool_uuid>/users/gui',
        UsersServicePool.as_view({'get': 'gui'}), name="servicespool_user_gui"),
    path('servicespools/<uuid:servicespool_uuid>/users',
        UsersServicePool.as_view({'put': 'add'}), name="servicespool_user_add"),
    path('servicespools/<uuid:servicespool_uuid>/users/<uuid:uuid>',
        UsersServicePool.as_view({'delete': 'delete'}), name="servicespool_user_delete"),
    # Группы рабочих мест
    path('servicespools/<uuid:servicespool_uuid>/groups/overview',
        GroupsOverviewServicePool.as_view({'get': 'list'}), name="servicespool_group_overview"),
    path('servicespools/<uuid:servicespool_uuid>/groups/gui',
        GroupsServicePool.as_view({'get': 'gui'}), name="servicespool_group_gui"),
    path('servicespools/<uuid:servicespool_uuid>/groups',
        GroupsServicePool.as_view({'put': 'add'}), name="servicespool_group_add"),
    path('servicespools/<uuid:servicespool_uuid>/groups/<uuid:uuid>',
        GroupsServicePool.as_view({'delete': 'delete'}), name="servicespool_group_delete"),
    # Протоколы доставки рабочих мест
    path('servicespools/<uuid:servicespool_uuid>/transports/overview',
        TransportsOverviewServicePool.as_view({'get': 'list'}), name="servicespool_transport_overview"),
    path('servicespools/<uuid:servicespool_uuid>/transports/gui',
        TransportsServicePool.as_view({'get': 'gui'}), name="servicespool_transport_gui"),
    path('servicespools/<uuid:servicespool_uuid>/transports',
        TransportsServicePool.as_view({'put': 'add'}), name="servicespool_transport_add"),
    path('servicespools/<uuid:servicespool_uuid>/transports/<uuid:uuid>',
        TransportsServicePool.as_view({'delete': 'delete'}), name="servicespool_transport_delete"),
    # Публикация рабочих мест
    path('servicespools/<uuid:servicespool_uuid>/publications/overview',
        PublicationsOverviewServicePool.as_view({'get': 'list'}), name="servicespool_publication_overview"),
    path('servicespools/<uuid:servicespool_uuid>/publications/gui',
        PublicationsServicePool.as_view({'get': 'gui'}), name="servicespool_publication_gui"),
    path('servicespools/<uuid:servicespool_uuid>/publications/publish',
        PublishServicePool.as_view({'get': 'publish'}), name="servicespool_publication_publish"),
    path('servicespools/<uuid:servicespool_uuid>/publications/<uuid:uuid>/cancel',
        PublicationsServicePool.as_view({'get': 'cancel'}), name="servicespool_publication_cancel$"),

    # Фонды рабочих мест -> Политики фондов рабочих мест
    path("servicespools/<uuid:servicespool_uuid>/policies/overview",
         PoliciesDeployedServices.as_view({"get": "list", }),
         name="policies_deployed_service_overview", ),
    path("servicespools/<uuid:servicespool_uuid>/policies/<slug:data_type>",
         PoliciesDeployedServices.as_view({"put": "update_by_type", "get": "get_by_type"}),
         name="policies_deployed_service_detail", ),
    path(
        "servicespools/<uuid:servicespool_uuid>/policies/gui/<slug:data_type>",
        PoliciesGui.as_view(), name="policies_deployed_service_gui"),

    # Остальные запросы
    url(r'^servicespools/(?P<uuid>.+)/log$', ServicesPools.as_view({'get': 'get_logs'}),
        name="servicepool_log"),
    url(r'^servicespools/(?P<uuid>.+)$', servicespools_detail_action, name="servicespools_detail"),

    # Вызов callback из различных интерфейсов
    path('gui/callback/<slug:callback>', GuiCallback.as_view({'get': 'get'}), name="gui_callback"),

    # Настройки -> Управление ролями
    url(r'^rbac$', Rbac.as_view({'put': 'create', 'get': 'list'}), name="rbac"),
    url(r'^rbac/gui$', Rbac.as_view({'get': 'gui', }), name="rbac_gui"),
    url(r'^rbac/overview$', Rbac.as_view({'get': 'overview', }), name="rbac_overview"),
    url(r'^rbac/(?P<id>.+)$', rbac_detail_action, name="rbac_detail"),

    # Рабочие места -> Сессии
    url(r'^spsessions/overview$', SpSessions.as_view({'get': 'overview'}), name="spsessions"),
    url(r'^spsessions/(?P<uuid>.+)/logoff$', SpSessions.as_view({'get': 'logoff'}), name="spsession_logoff"),

    # Настройки -> Управление ACL
    url(r'^acl$', AccessControlList.as_view({'put': 'create'}), name="acl"),
    url(r'^acl/gui/(?P<data_type>.+)$$', AccessControlList.as_view({'get': 'gui', }), name="acl_gui"),
    url(r'^acl/overview$', AccessControlList.as_view({'get': 'overview', }), name="acl_overview"),
    url(r'^acl/types$', AccessControlList.as_view({'get': 'get_types', }), name="types_acl"),
    url(r'^acl/(?P<id>.+)$', acl_detail_action, name="acl_detail"),

    # Настройки -> Глобальные политики
    path("policies/overview", Policies.as_view({"get": "list", }), name="policies_overview", ),
    path("policies/<slug:data_type>",
         Policies.as_view({"put": "update_by_type", "get": "get_by_type"}),
         name="policy_detail", ),
    path("policies/gui/<slug:data_type>", Policies.as_view({"get": "gui", }), name="policies_gui", ),
]
