import logging

from rest_framework.exceptions import APIException
from rest_framework.response import Response
from rest_framework.schemas.openapi import AutoSchema
from rest_framework.viewsets import ViewSet
from uds.core.ui.UserInterface import gui

logger = logging.getLogger(__name__)


class CallbackSchema(AutoSchema):
    """ Класс для помощи в построении запроса через swagger. """

    def get_operation(self, path, method):
        """
        В список parameters необходимо добавить возможный параметр,
        который может понадобиться для построения запроса через swagger.
        """
        operation = super().get_operation(path, method)
        operation['parameters'].append({
            "name": "domain",
            "in": "query",
            "required": False,
            "description": "Домен аутентификации",
            'schema': {'type': 'string'}
        })
        return operation


class GuiCallback(ViewSet):
    """
    get:
        Доступ к gui callback функциям.
    """
    schema = CallbackSchema()

    def get(self, request, callback):
        if callback not in gui.callbacks:
            raise APIException('callback {0} not found'.format(callback))

        return Response(gui.callbacks[callback](request.query_params))
