import logging

from rest_framework.viewsets import ModelViewSet

from termidesk.api.decorators import has_role_permission
from termidesk.api.permissions import AccessPermission
from termidesk.api.webui.serializers.monitoring import MonitoringSerializer
from termidesk.models.UserPermission import LOG_VIEW
from uds.models.Log import Log

logger = logging.getLogger(__name__)

SEARCH = 'search'


class Monitoring(ModelViewSet):
    """
    View to list all logs.
    """
    model = Log
    permission_classes = [AccessPermission]
    serializer_class = MonitoringSerializer

    @has_role_permission(LOG_VIEW)
    def get_queryset(self):
        queryset = self.model.objects.order_by('-created')

        search = self.request.query_params.get(SEARCH)
        if search not in ['', None]:
            queryset = queryset.filter(data__icontains=search)

        return queryset[0:1000]
