import logging

from rest_framework import generics
from termidesk.api.permissions import AccessPermission, EnabledPoliciesRequiredPermission
from termidesk.api.webui.schemas import GuiFieldsSchema
from termidesk.api.webui.serializers.gui import GuiFieldsSerializer
from termidesk.core.policies.utils import get_policy_class_by_type

logger = logging.getLogger(__name__)


class PoliciesGui(generics.ListAPIView):
    """Спецификация полей GUI для политики конкретного типа."""
    permission_classes = [AccessPermission, EnabledPoliciesRequiredPermission]
    serializer_class = GuiFieldsSerializer
    schema = GuiFieldsSchema(operation_id_base='WebuiPoliciesGuiFields')

    def get_queryset(self):
        policy_type = self.kwargs.get("data_type", "")
        policy = get_policy_class_by_type(policy_type)
        gui = policy.guiDescription()
        return sorted(gui, key=lambda f: f['gui']['order'])
