import logging

from rest_framework.exceptions import APIException
from rest_framework.response import Response
from rest_framework.schemas.openapi import AutoSchema
from rest_framework.viewsets import ViewSet
from termidesk.api.wsproxy.v1.serializers import TokenSerializer
from termidesk.core.util import wsptoken

logger = logging.getLogger(__name__)


PATH_TO_RSA_PUB = 'private/wsproxy/id_rsa.pub'


class Verify(ViewSet):
    """
        post:
        Валидация токена вебсокет прокси для подключения на сервер Термидеск.
    """

    schema = AutoSchema()

    def post(self, request, *args, **kwargs):
        token = kwargs.get('token')

        with open(PATH_TO_RSA_PUB) as f:
            public_key = f.read()

        params = wsptoken.TokenDecoder(public_key).decode(token)
        if params is None:
            message = "Invalid token {}".format(token)
            logger.error(message)
            raise APIException(message)

        serializer = TokenSerializer(data=params)
        if serializer.is_valid() is False:
            logger.error('The token {} did not pass validation'.format(token))

        return Response(serializer.validated_data)
