# -*- coding: utf-8 -*-

'''
@author: Dmitry Dvoeglazov
'''
from pkg_resources import iter_entry_points


def __init__():
    '''
    Импортирует дочерние модули аутентификации и затем регистрирует их в реестре
    '''
    import os.path
    import pkgutil
    import sys
    import logging
    from importlib import import_module
    from termidesk.core.auths.Authenticator import BaseAuthenticator2Fa
    from uds.core import auths

    logger = logging.getLogger(__name__)

    logger.debug("Searching for auth plugins...")
    for entry_point in iter_entry_points('termidesk.authenticators'):
        logger.debug("Found auth plugin: {}".format(entry_point.name))
        plugin_class = entry_point.load()
        logger.debug("Loaded plugin: {}".format(plugin_class))
        logger.debug("Plugin location: {}".format(sys.modules[plugin_class.__module__].__file__))
        auths.factory().insert(plugin_class)
        logger.debug('Registered {} class with auth factory'.format(str(plugin_class)))

    # Динамически импортируем реализации реализации провайдеров аутентификации
    # из дочерних пакетов
    # При импорте пакеты должны регистрировать сервис провайдеров
    # в общем реестре (Authenticator)
    pkgpath = os.path.dirname(sys.modules[__name__].__file__)
    for _, name, _ in pkgutil.iter_modules([pkgpath]):
        import_module('.{}'.format(name), __package__)
        logger.debug("Imported {} module from {}".format(name, __package__))

        base_auth = auths.Authenticator
        common_subclasses = base_auth.__subclasses__() + BaseAuthenticator2Fa.__subclasses__()
        for cls in common_subclasses:  # pylint: disable=maybe-no-member
            if not str(cls.__module__).startswith('{}.'.format(__package__)):
                continue
            auths.factory().insert(cls)
            logger.info('Registered {} class with auth factory'.format(str(cls)))


__init__()
del __init__
