# -*- coding: utf-8 -*-

from __future__ import unicode_literals

import codecs
import os
from abc import ABCMeta, abstractmethod

from django.http import HttpResponseBadRequest
from django.middleware.csrf import get_token
from uds.core.auths import Authenticator

TOTP_METHOD = 'totp'
STATIC_METHOD = 'static'

AUTH_METHODS = {
    TOTP_METHOD: {
        'name': 'TOTP токен',
        'viewname': TOTP_METHOD
    },
    STATIC_METHOD: {
        'name': 'Резервный код',
        'viewname': STATIC_METHOD
    },
}


class BaseAuthenticator2Fa(Authenticator):
    __metaclass__ = ABCMeta

    def getHtml(self, request):
        current_path = os.path.dirname(__file__) + '/templates/template.html'

        with codecs.open(current_path, "r", "utf-8") as file:
            data = file.read()

        csrf_token = get_token(request)
        options = ""
        for method_key, method_value in self.get_auth_methods().items():
            options += '<option class="form-control" value="{}">{}</option>\n'.format(
                method_key, method_value['name']
            )
        return data.format(csrf_token=csrf_token, id_auth=self._dbAuth.uuid, options_by_type=options)

    def custom_method(self, request, method):
        view = self.get_custom_view()

        if not hasattr(view, method):
            return HttpResponseBadRequest()

        view_method = getattr(view, method)
        response = view_method(request)
        return response

    @abstractmethod
    def get_custom_view(self):
        """ Получение класса, который содержит кастомные методы обработки представления."""
        return

    @abstractmethod
    def get_auth_methods(self):
        """ Получение способов двухфакторной аутентификации."""
        return {}
