from django.http import HttpResponseRedirect
from django.urls import reverse
from django_otp import devices_for_user
from django_otp.plugins.otp_static.models import StaticDevice
from django_otp.plugins.otp_totp.models import TOTPDevice
from termidesk.core.auths.Authenticator import AUTH_METHODS
from uds.models.User import User


def get_totp_device_by_user(user, confirmed=None):
    """ Получение TOTP устройства для пользователя. """
    devices = devices_for_user(user, confirmed=confirmed)
    for device in devices:
        if isinstance(device, TOTPDevice):
            return device
    return None


def get_redirect_for_2fa_method(auth_uuid: str, name: str):
    """ Получение страницы редиректа для второго этапа конкретного вида двухфакторной аутентификации. """
    method_name = AUTH_METHODS.get(name)
    if method_name is None:
        raise ValueError('Переданный метод не существует.')

    return HttpResponseRedirect(
        reverse('customAuthMethod', kwargs={"idAuth": auth_uuid, "method": method_name['viewname']})
    )


def is_exist_static_device_by_token_for_user(user: User, token: str):
    """
    Проверка существования связанного валидного статического устройства
    с пользователем по токену.
    """
    devices = devices_for_user(user, confirmed=None)

    if devices is None:
        return False

    for device in devices:
        if isinstance(device, StaticDevice) and device.verify_token(token):
            if not device.confirmed:
                device.confirmed = True
                device.save()
            return True

    return False
