import logging

from django.shortcuts import render
from termidesk.core.auths.helpers import is_exist_static_device_by_token_for_user
from termidesk.core.auths.auth_2fa import check_access_on_second_step, get_user_from_session, \
    set_login_session_data
from termidesk.core.auths.login_manager import LoginAttemptsManager
from termidesk.core.auths.exceptions import UserLoginAttemptsExceeded
from termidesk.core.auths.views import TEMPLATE_FOLDER
from termidesk.web.mods import chooseSuccessRedirectForUser
from uds.core.auths.auth import authLogLogin

logger = logging.getLogger(__name__)


class StaticViewMixin:
    @check_access_on_second_step
    def static(self, request):
        """ Обработка статического вида двухфакторной аутентификации. """
        error = ''
        try:
            if request.method == 'POST':
                user = get_user_from_session(request)

                login_attempts = LoginAttemptsManager(user.manager, user.name)
                login_attempts.validate(request, user)

                token = request.POST.get('token')
                if token is None:
                    error = 'Токен является обязательным параметром.'
                    logger.exception(error)
                    raise ValueError(error)

                if is_exist_static_device_by_token_for_user(user, token) is False:
                    error = 'Токен не прошел валидацию.'
                    logger.exception(error)
                    login_attempts.increase()
                    raise ValueError(error)

                response = chooseSuccessRedirectForUser(user)
                login_attempts.clear()

                set_login_session_data(request, user)

                authLogLogin(request, user.manager, user.name)
                return response

        except (ValueError, UserLoginAttemptsExceeded) as err:
            error = err

        return render(request, TEMPLATE_FOLDER + 'static_code.html', {'error': error, })
