import logging

from django.shortcuts import render
from termidesk.core.auths.helpers import get_totp_device_by_user
from termidesk.core.auths.auth_2fa import check_access_on_second_step, get_user_from_session, \
    set_login_session_data
from termidesk.core.auths.exceptions import UserLoginAttemptsExceeded
from termidesk.core.auths.login_manager import LoginAttemptsManager
from termidesk.core.auths.views import TEMPLATE_FOLDER
from termidesk.web.mods import chooseSuccessRedirectForUser
from uds.core.auths.auth import authLogLogin

logger = logging.getLogger(__name__)


class TOTPViewMixin:
    @check_access_on_second_step
    def totp(self, request):
        """ Обработка TOTP вида двухфакторной аутентификации. """
        error = ''
        user = get_user_from_session(request)
        device = get_totp_device_by_user(user)

        try:
            login_attempts = LoginAttemptsManager(user.manager, user.name)
            login_attempts.validate(request, user)
        except UserLoginAttemptsExceeded as error:
            return render(request,
                          TEMPLATE_FOLDER + 'totp_code.html',
                          {'is_new_device': False, 'device': device, 'error': error,
                           'auth_uuid': self._auth.uuid})

        if request.method == 'POST':
            token = request.POST.get('token')
            if token is None:
                error = 'Токен является обязательным параметром.'
                logger.exception(error)
                raise ValueError(error)

            if device is not None and device.verify_token(token):
                if not device.confirmed:
                    device.confirmed = True
                    device.save()

                response = chooseSuccessRedirectForUser(user)
                login_attempts.clear()

                set_login_session_data(request, user)

                authLogLogin(request, user.manager, user.name)
                return response
            else:
                error = 'Токен не прошёл валидацию.'
                login_attempts.increase()

        if device is None:
            device = user.totpdevice_set.create(confirmed=False)
            is_new_device = True
        else:
            is_new_device = False

        return render(
            request,
            TEMPLATE_FOLDER + 'totp_code.html',
            {'is_new_device': is_new_device, 'device': device, 'error': error, 'auth_uuid': self._auth.uuid}
        )
