from termidesk.core.policies.BasePolicy import BasePolicy
from termidesk.models.PolicyGlobal import PolicyGlobal
from termidesk.models.PolicyDeployedService import PolicyDeployedService
from termidesk.core.util.singleton import SingletonMeta
from uds.core.Environment import Environment
from uds.core.util.Config import GlobalConfig
from uds.models.ServicesPool import DeployedService


class PolicyManager(metaclass=SingletonMeta):

    @staticmethod
    def is_policies_enabled():
        return GlobalConfig.EXPERIMENTAL_POLICIES_ENABLED.getBool(True)

    def get_global_policy(self, policy_type: BasePolicy):
        """
        Получение объекта глобальной политики по типу политики.

        :return: BasePolicy
        """
        try:
            model = PolicyGlobal.objects.get(data_type=policy_type.typeType)
            return model.getInstance()

        except PolicyGlobal.DoesNotExist:
            return policy_type(Environment.getGlobalEnv(), values={'value': policy_type.value.defValue})

    def get_deployed_service_policy(self, policy_type: BasePolicy, deployed_service: DeployedService):
        """
        Получение объекта политики фонда рабочих мест по типу политики и объекту фонда рабочих мест.

        :return: BasePolicy
        """
        try:
            model = PolicyDeployedService.get_policy(policy_type.typeType, deployed_service.id)
            return model.getInstance()
        except PolicyDeployedService.DoesNotExist:
            return self.get_global_policy(policy_type)
