import json
import logging
from abc import ABCMeta, abstractmethod

from termidesk.core.policies.utils import PolicyDTO
from uds.core import Module
from uds.core.ui.UserInterface import gui

logger = logging.getLogger()


class BasePolicy(Module):
    __metaclass__ = ABCMeta

    typeName = "Base PolicyManager"
    typeType = "BasePolicy"
    typeDescription = "Base Policy"

    # Допустимые значения в виде словаря,
    # ключи - все допустимые значения,
    # значения - описание для отображения в интерфейсе.
    ALLOW_VALUES = {}

    _value = ""

    description = gui.InfoField(
        label="Описание",
        required=False,
        rdonly=True,
        multiline=4,
        order=1
    )

    value = gui.InputField(
        label="Значение",
        required=True,
        defvalue=0,
        order=2
    )

    JSON_DATA_VERSION_1 = 1

    def __init__(self, environment, values):
        super().__init__(environment, values)
        if values is not None:
            self.set_value(values.get("value"))
        else:
            self.set_value(self.value.defValue)

    def marshal(self):
        data = {
            'version': self.JSON_DATA_VERSION_1,
            'value': self._value,
        }

        return json.dumps(data)

    def unmarshal(self, str_):
        if not isinstance(str_, str):
            str_ = str_.decode("utf-8")
        data = json.loads(str_)
        if data['version'] == self.JSON_DATA_VERSION_1:
            self.set_value(data.get('value'))
            logger.debug("Value: {value}".format(value=data['value']))
        else:
            raise Exception("Unsupported serialized data version {}".format(data['version']))

    def set_value(self, value):
        self._value = value

    def get_value(self):
        return self._value

    def valuesDict(self):
        value = self.get_value()
        return PolicyDTO(self.typeName, self.typeDescription, self.typeType, value,
                         self.get_view_value(value)).get_values()

    @classmethod
    @abstractmethod
    def get_view_value(cls, value):
        """Получение текстового представления значения, для отображения в интерфейсе."""
        return cls.ALLOW_VALUES.get(value)

    @classmethod
    @abstractmethod
    def check_value(cls, value):
        """Проверка переданного значения."""
        if cls.ALLOW_VALUES.get(value) is None:
            raise ValueError('Передано не допустимое значение "value"')
