import logging

from threading import Lock

logger = logging.getLogger(__name__)


class PolicyRegistry(object):
    """
    This class holds the register of all known policy modules.

    It provides a way to register and recover policies.
    """

    _instance = None
    _lock = Lock()

    def __init__(self):
        """
        Initializes internal dictionary for service policies registration.
        """
        self._policies = {}

    @classmethod
    def instance(cls):
        """
        Returns the instance that keeps the register of service policies.
        """
        with cls._lock:
            if PolicyRegistry._instance is None:
                PolicyRegistry._instance = PolicyRegistry()
        return PolicyRegistry._instance

    def policies(self):
        """
        Returns the list of policies already registered.
        """
        return self._policies

    def insert(self, type_):
        """
        Inserts type_ as a service policy.
        """
        type_name = type_.type().lower()
        if type_name in self._policies:
            logger.debug("{0} already registered as Policy".format(type_))
            return

        logger.debug("Adding policy {0} as {1}".format(type_.type(), type_))
        self._policies[type_name] = type_

    def lookup(self, type_name: str):
        """
        Tries to locate a server policy and by its name, and, if
        not found, returns None.
        """
        if type_name is None:
            return None

        return self._policies.get(type_name.lower(), None)
