from uuid import UUID
from termidesk.core.policies.PolicyRegistry import PolicyRegistry
from termidesk.models.PolicyDeployedService import PolicyDeployedService
from termidesk.models.PolicyGlobal import PolicyGlobal


def registry():
    """
    Returns instance for register/access to policy
    """
    return PolicyRegistry.instance()


def get_policy_class_by_type(type_name: str):
    """Получение класса политики по именованию типа.
    При отсутствии необходимой политики отдает ошибку."""
    policy = registry().lookup(type_name)
    if policy is None:
        raise ValueError(
            'Переданного типа политики "{type_name}" не существует'.format(type_name=type_name)
        )
    return policy


def get_policy_values_by_type(policy_type: str, deployed_service_id=None):
    """
    Получение доступных аттрибутов и значений политики в виде словаря.

    Object instance -> Dict of primitive datatypes.
    """
    code_policy = get_policy_class_by_type(policy_type)

    result = None
    if deployed_service_id is not None:
        result = __get_deployed_service_policies(policy_type, deployed_service_id)

    if result is None:
        result = __get_policy_global(policy_type)

    if result is None:
        value = code_policy.value.defValue
        result = PolicyDTO(
            code_policy.typeName,
            code_policy.typeDescription,
            code_policy.typeType,
            value,
            code_policy.get_view_value(value)
        ).get_values()

    return result


def __get_deployed_service_policies(policy_type: str, deployed_service_id: UUID):
    """ Получение форматирвоанного представления основных значений политик фонда рм."""
    try:
        model = PolicyDeployedService.objects.get(
            data_type=policy_type, deployed_service_id=deployed_service_id
        )
        return model.getInstance().valuesDict()
    except PolicyDeployedService.DoesNotExist:
        return None


def __get_policy_global(policy_type: str):
    """ Получение форматирвоанного представления основных значений глобальных политик."""
    try:
        model = PolicyGlobal.objects.get(data_type=policy_type)
        return model.getInstance().valuesDict()
    except PolicyGlobal.DoesNotExist:
        return None


class PolicyDTO:
    """
    Контейнер для хранения структуры полей политики.

    Этот класс в будущем можно переделать на dataclass(>=python3.7).
    """

    __value = None

    __name = None
    __data_type = None
    __view_value = None

    def __init__(self, name, description, data_type, value, view_value):
        self.__name = name
        self.__description = description
        self.__data_type = data_type
        self.__value = value
        self.__view_value = view_value

    def get_values(self):
        return {
            "name": self.__name,
            "description": self.__description,
            "data_type": self.__data_type,
            "value": self.__value,
            "view_value": self.__view_value,
        }
