from django.contrib.contenttypes.models import ContentType
from guardian.shortcuts import get_group_obj_perms_model, _handle_pk_field, groupby, _get_queryset, \
    get_content_type
from guardian.exceptions import MixedContentTypeError, WrongAppError


# FIXME: Функцию `get_objects_for_groups` необходимо упростить:
#  разбить на несколько функций или переделать в класс
# TSRV-473: `noqa` - отключает для функции 'get_objects_for_groups' проверку ошибки `C901`,
# которая генерируется во время проверки `python -m flake8 src/termidesk/core --no-show-source`
def get_objects_for_groups(groups, perms, klass=None, any_perm=False):  # noqa: C901
    """
    Returns queryset of objects for which a given ``groups`` has *all*
    permissions present at ``perms``.

    Copied from method guardian.shortcuts.get_objects_for_group
    without processing code of param "accept_global_perms".
    """
    if isinstance(perms, str):
        perms = [perms]
    ctype = None
    app_label = None
    codenames = set()

    # Compute codenames set and ctype if possible
    for perm in perms:
        if '.' in perm:
            new_app_label, codename = perm.split('.', 1)
            if app_label is not None and app_label != new_app_label:
                raise MixedContentTypeError("Given perms must have same app "
                                            "label (%s != %s)" % (app_label, new_app_label))
            else:
                app_label = new_app_label
        else:
            codename = perm
        codenames.add(codename)
        if app_label is not None:
            new_ctype = ContentType.objects.get(app_label=app_label,
                                                permission__codename=codename)
            if ctype is not None and ctype != new_ctype:
                raise MixedContentTypeError("ContentType was once computed "
                                            "to be %s and another one %s" % (ctype, new_ctype))
            else:
                ctype = new_ctype

    # Compute queryset and ctype if still missing
    if ctype is None and klass is not None:
        queryset = _get_queryset(klass)
        ctype = get_content_type(queryset.model)
    elif ctype is not None and klass is None:
        queryset = _get_queryset(ctype.model_class())
    elif klass is None:
        raise WrongAppError("Cannot determine content type")
    else:
        queryset = _get_queryset(klass)
        if ctype.model_class() != queryset.model:
            raise MixedContentTypeError("Content type for given perms and "
                                        "klass differs")

    # Now we should extract list of pk values for which we would filter
    # queryset
    group_model = get_group_obj_perms_model(queryset.model)
    # Измененный блок для поиска по множеству групп
    groups_obj_perms_queryset = (group_model.objects
                                 .filter(group__in=[group.id for group in groups])
                                 .filter(permission__content_type=ctype))
    if len(codenames):
        groups_obj_perms_queryset = groups_obj_perms_queryset.filter(
            permission__codename__in=codenames)
    if group_model.objects.is_generic():
        fields = ['object_pk', 'permission__codename']
    else:
        fields = ['content_object__pk', 'permission__codename']
    if not any_perm and len(codenames):
        groups_obj_perms = groups_obj_perms_queryset.values_list(*fields)
        data = list(groups_obj_perms)

        # sorting/grouping by pk (first item in a resulting tuple)
        def sort_by_pk(t):
            return t[0]

        data = sorted(data, key=sort_by_pk)
        pk_list = []
        for pk, group in groupby(data, sort_by_pk):
            obj_codenames = {e[1] for e in group}
            if any_perm or codenames.issubset(obj_codenames):
                pk_list.append(pk)
        objects = queryset.filter(pk__in=pk_list)
        return objects

    field_pk = fields[0]
    values = groups_obj_perms_queryset

    handle_pk_field = _handle_pk_field(queryset)
    if handle_pk_field is not None:
        values = values.annotate(obj_pk=handle_pk_field(expression=field_pk))
        field_pk = 'obj_pk'

    values = values.values_list(field_pk, flat=True)
    return queryset.filter(pk__in=values)
