# -*- coding: utf-8 -*-
'''
Created on Nov 18, 2019

@author: dvd
'''
from __future__ import unicode_literals

from django.core.files.storage import FileSystemStorage
import pexpect
import logging

import config
import subprocess

logger = logging.getLogger(__name__)


def get_kerberos_token_storage():
    # 2to3: Mode '0600' changed to '0o600'
    storage = KerberosTokenStorage(location=config.KERBEROS_TOKEN_STORAGE_FOLDER,
                                   file_permissions_mode=0o600)
    return storage


def kinit(user, password):
    kinit = '/usr/bin/kinit'
    ccache_filename = get_ccache_path_for_user(user)

    # Убираем возможные переносы каретки в пароле для подстраховки
    password = password.replace('\n', '')
    password = password.replace('\r', '')

    try:
        child = pexpect.spawn(kinit, ['-f', '-c', ccache_filename, user], env={'LC_ALL': 'en_US.UTF-8'})
        child.expect('Password for {}:'.format(user))
        child.sendline(password)
        result = child.expect(['kinit: Password incorrect while getting initial credentials', pexpect.EOF])
        child.close()
    except Exception as err:
        child.close()
        logger.error("kinit Error authenticating. Reason: %s", err)
        return None

    if result == 0:
        logger.info("kinit Authentication failed for user %s", user)
        return None
    else:
        return ccache_filename.format(user)

    # kinit_args = [ kinit, '-f', '-c', ccache_filename, user ]
    # kinit = Popen(kinit_args, stdin=PIPE, stdout=PIPE, stderr=PIPE)
    # kinit.stdin.write('%s\n' % password)
    # kinit.wait()
    # return ccache_filename.format(user)


def verify_ticket(user):
    ccache = get_ccache_path_for_user(user)

    try:
        result = subprocess.call(['/usr/bin/klist', '-s', '-c', ccache])
        if result == 0:
            return True
    except Exception as e:
        logger.exception(e)

    return False


def get_ccache_path_for_user(user):
    ccache_filename = '/tmp/krb5cc_termidesk_{}'.format(user)
    return ccache_filename


class KerberosTokenStorage(FileSystemStorage):

    def _save(self, name, content):
        self.delete(name)
        return super(KerberosTokenStorage, self)._save(name, content)

    def get_available_name(self, name, max_length=None):
        return name
