# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from termidesk.management.commands.common.subcommands.subcommand import Subcommand
from termidesk.management.commands.common.subcommands.mixins.create import CreateMixin
from abc import ABCMeta, abstractmethod


class CreateWithoutType(Subcommand, CreateMixin):
    __metaclass__ = ABCMeta
    # Имя сервиса в родительном падеже, для вывода сообщений
    name_of_service = ''

    # Базовые аргументы для модели
    BASE_ARGS = []

    SUBCOMMAND = 'create'

    def handle_subcommand(self, options, stdout, stderr):
        self.validate_base_data(options)

        loud_work = not options['quiet']

        try:
            main_args = {arg: options[arg] for arg in self.BASE_ARGS
                         if arg in options}

            self.create_service(main_args)
            if loud_work:
                self.show_success(stdout, self.name_of_service)
        except Exception as error:
            self.show_error(stdout, error, self.name_of_service)

    def add_arguments_subcommand(self, parser):
        parser.add_argument(
            '--quiet', action='store_true', dest='quiet', default=False,
            help='Выводить только сообщения об ошибках',
        )

    @abstractmethod
    def create_service(self, main_args):
        """
        Базовая логика по созданию сервиса. Подклассы должны обязательно
        содержать этот метод.
        :param main_args: Основные аргументы для модели сервиса
        :return:
        """

    @abstractmethod
    def validate_base_data(self, data):
        """
        Валидация базовых данных. Подклассы должны обязательно
        содержать этот метод.
        :param data: Базовые данные для проверки
        :return:
        """
