# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from termidesk.management.commands.common.subcommands.subcommand import Subcommand
from abc import ABCMeta, abstractmethod
import json


class ListSubcommand(Subcommand):
    __metaclass__ = ABCMeta

    JSON_FORMATTING = 'json'
    TYPES_FORMATTING = (JSON_FORMATTING,)

    SUBCOMMAND = 'list'

    def handle_subcommand(self, options, stdout, stderr):
        if options['output']:
            return self.show_formatting_items(
                options['output'],
                stdout,
                stderr
            )

        if self.has_elements():
            return self.show_elements(stdout, stderr)

        stdout.write(
            self.style.WARNING('Записей не найдено')
        )

    def add_arguments_subcommand(self, parser):
        parser.add_argument(
            '--output', choices=self.TYPES_FORMATTING, required=False,
            help='Вывод данных в формате для машинной обработки',
            default=False
        )

    def show_formatting_items(self, type_formatting, stdout, stderr):
        """ Вывод форматированного представления элементов. """
        if type_formatting != self.JSON_FORMATTING:
            stderr.write(self.style.ERROR(
                'Переданный тип форматировани {} не поддерживается'.format(
                    type_formatting
                )
            ))

        stdout.write(
            json.dumps(list(self.get_table_records()))
        )

    @staticmethod
    @abstractmethod
    def has_elements():
        """ Наличие элементиов для показа в списке. """

    @staticmethod
    @abstractmethod
    def get_table_records():
        """ Получение элементов необходимой структуры. """

    @abstractmethod
    def show_elements(self, stdout, stderr):
        """ Показ элементов сервиса. """
