# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from termidesk.management.commands.common.subcommands.subcommand import Subcommand
from abc import ABCMeta, abstractmethod
import json


class RemoveSubcommand(Subcommand):
    __metaclass__ = ABCMeta

    JSON_FORMATTING = 'json'
    TYPES_FORMATTING = (JSON_FORMATTING,)

    SUBCOMMAND = 'remove'

    def handle_subcommand(self, options, stdout, stderr):

        if options['output']:
            return self.show_formatting_items(
                options['output'],
                options['uuid'],
                stdout,
                stderr,
            )

        if (self.validate_base_data(options['uuid']) and
                self.remove_service(options['uuid'], stdout, stderr)):
            stdout.write(self.style.SUCCESS(
                'Удаление прошло успешно'
            ))
        else:
            stdout.write(
                self.style.WARNING('Записей не найдено')
            )

    def add_arguments_subcommand(self, parser):
        parser.add_argument(
            '--output', choices=self.TYPES_FORMATTING, required=False,
            help='Вывод данных в формате для машинной обработки',
            default=False
        )

        parser.add_argument(
            '--silent', default=False, action='store_const',
            help='Опция для выполнения команды из скриптов',
            const=True
        )

    def show_formatting_items(self, type_formatting, uuid, stdout, stderr):
        """ Вывод форматированного представления элементов. """
        if (self.validate_base_data(uuid) and
                self.remove_service(uuid, stdout, stderr)):
            stdout.write(json.dumps(["OK"]))
        else:
            stdout.write(json.dumps(["ERROR"]))

    @staticmethod
    @abstractmethod
    def validate_base_data():
        """ Проверка существования сервиса """

    @abstractmethod
    def remove_service(data, stdout, stderr):
        """ Удаление сервиса """
