from termidesk.core.auths.Authenticator import BaseAuthenticator2Fa
from uds.models.Authenticator import Authenticator
from uds.models.User import User


def check_and_get_auth(auth_uuid: str):
    """
    Проверка существования домена аутентификации
    и его принадлежности к типу двухфакторной аутентификации.
    """
    try:
        auth = Authenticator.objects.get(uuid=auth_uuid)
    except Authenticator.DoesNotExist:
        raise ValueError('Не найден домен аутентификации по переданному uuid: "{}"'.format(auth_uuid))

    if not isinstance(auth.getInstance(), BaseAuthenticator2Fa):
        raise ValueError('Указанный вами домен аутентификации "{}" '
                         'не поддерживает двухфакторную аутентификацию.'.format(auth))

    return auth


def check_and_get_user(auth: Authenticator, username: str):
    """ Проверка существования пользователя и его принадлежности к домену аутентификации. """
    try:
        user = auth.users.get(name=username)
    except User.DoesNotExist:
        raise ValueError(
            'Пользователь с именем "{}" не найден в домене аутентификации "{}"'.format(username, auth)
        )

    return user
