import sys

from django.conf import settings
from django.core.management import BaseCommand, CommandError
from django.db import connections


class Command(BaseCommand):
    help = "Delete tables from DB"

    def add_arguments(self, parser):
        super(Command, self).add_arguments(parser)
        parser.add_argument(
            '--noinput', '--no-input', action='store_false',
            dest='interactive',
            help='Tells Django to NOT prompt the user for input of any kind.',
        )
        parser.add_argument(
            '-R', '--router', action='store', dest='router', default='default',
            help='Use this router-database instead of the one defined in settings.py'
        )
        parser.add_argument(
            '-S', '--schema', action='store', dest='schema', default='public',
            help='Drop this schema instead of "public"'
        )

    def handle(self, *args, **options):
        router = options['router']
        dbinfo = settings.DATABASES.get(router)
        if dbinfo is None:
            raise CommandError("Unknown database router %s" % router)

        database_name = dbinfo['NAME']

        if options['interactive']:
            confirm = input(self.style.WARNING(
                ("You have requested to remove all tables in the \"{}\" database.\n"
                 "Are you sure you want to do this?\n"
                 "Type 'yes' to continue, or 'no' to cancel: ").format(database_name)
            ))
        else:
            confirm = 'yes'

        if confirm != 'yes':
            return self.style.WARNING("Removal stopped.")

        try:
            with connections[router].cursor() as cursor:
                schema = options['schema']
                command = "select 'drop table \"' || tablename || '\" cascade;' from pg_tables where schemaname='%s'" % schema
                cursor.execute(command)
                all_tables = cursor.rowcount
                count_drop_tables = 0
                for dropping_command in cursor.fetchall():
                    cursor.execute(dropping_command[0])
                    count_drop_tables += 1

        except Exception as error:
            self.stderr.write(str(error))
            sys.exit(1)

        return self.style.SUCCESS(
            'Deleted {} tables out of {}.'.format(count_drop_tables, all_tables)
        )
