# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from uds.models import Authenticator
import collections

from termidesk.management.commands.common.subcommands.list import ListSubcommand

class ListCommand(ListSubcommand):

    def add_subparser(self, subparsers):
        list_parser = subparsers.add_parser(
            self.SUBCOMMAND,
            help="Show list of authentication domains"
        )
        self.add_arguments_subcommand(list_parser)

    @staticmethod
    def has_elements():
        return Authenticator.objects.exists()

    @staticmethod
    def get_table_records():
        """
        Получение доменов аутентификации необходимой структуры.
        """
        domains = Authenticator.objects.all()
        for domain in domains:
            type_ = domain.getType()

            yield collections.OrderedDict([
                ('id', domain.uuid),
                ('priority', str(domain.priority)),
                ('name', domain.name),
                ('type', domain.data_type),
                ('users', str(domain.users.all().count())),
                ('comment', domain.comments),
            ])

    def show_elements(self, stdout, stderr):
        pattern = "{0:40}   {1:9}   {2:35}   {3:25}   {4:12}   {5:1}"

        stdout.write(
            self.style.SUCCESS("Список доменов аутентификации:")
        )

        stdout.write(
            self.style.SUCCESS(
                pattern.format(
                    'ID',
                    'Приоритет',
                    'Название',
                    'Тип',
                    'Пользователи',
                    'Комментарии',
                )
            )
        )

        for domain in self.get_table_records():
            stdout.write(
                self.style.WARNING(
                    pattern.format(*(domain[key] for key in domain))
                )
            )

        from termidesk.rest.handlers import raise_cli_crud_event
        from termidesk.rest.handlers import READ_ACTION
        raise_cli_crud_event(
            entity=Authenticator.__name__,
            uuid='',
            subtype='',
            name='',
            action=READ_ACTION,
            username=None  # В качестве имени пользователя будет использоваться
                           # имя системного пользователя, запустившего cli-команду
        )
