# -*- coding: utf-8 -*-
from __future__ import unicode_literals


from uds.models import Authenticator
from django.db.utils import OperationalError
from termidesk.management.commands.common.subcommands.remove import RemoveSubcommand

class RemoveCommand(RemoveSubcommand):

    def add_subparser(self, subparsers):
        remove_parser = subparsers.add_parser(
            self.SUBCOMMAND,
            help="Удаление домена аутентификации"
        )
        self.add_arguments_subcommand(remove_parser)

        remove_parser.add_argument(
            '--uuid', type=str,# required=True,
            help="Id объекта для удаления"
        )

    @staticmethod
    def validate_base_data(data):
        """ Проверка существования домена """
        try:
            Authenticator.objects.get(uuid=data)
            return True
        except Authenticator.DoesNotExist:
            return False

    def remove_service(self, data, stdout, stderr):
        """ Удаление домена """
        try:
            domain = Authenticator.objects.get(uuid=data)
            # Так как событие возникает после удаления,
            # то необходимо заранее сохранить сведения об удаляемом объекте
            domain_type = domain.data_type
            domain_name = domain.name
            domain_uuid = domain.uuid
            domain.delete()

            from termidesk.rest.handlers import raise_cli_crud_event
            from termidesk.rest.handlers import DELETE_ACTION

            raise_cli_crud_event(
                entity=Authenticator.__name__,
                uuid=domain_uuid,
                subtype=domain_type,
                name=domain_name,
                action=DELETE_ACTION,
                username=None  # В качестве имени пользователя будет использоваться
                # имя системного пользователя, запустившего cli-команду
            )
            return True

        except OperationalError:
            stderr.write(self.style.ERROR(
                'Домен не был удалён'
            ))
            return False
