# -*- coding: utf-8 -*-
from __future__ import unicode_literals

import collections

from termidesk.management.commands.common.subcommands.list import ListSubcommand
from uds.core.util.Config import Config, GlobalConfig
from uds.models.Config import Config as ConfigModel


class ListCommand(ListSubcommand):

    def add_arguments_subcommand(self, parser):
        """ Убрать метод, когда будет необходимость вывода json формата. """
        pass

    def add_subparser(self, subparsers):
        list_parser = subparsers.add_parser(
            self.SUBCOMMAND,
            help="Показать список конфигурационных параметров и их значения"
        )
        self.add_arguments_subcommand(list_parser)

    def handle_subcommand(self, options, stdout, stderr):
        if self.has_elements():
            return self.show_elements(stdout, stderr)

        stdout.write(
            self.style.WARNING('Записей не найдено')
        )

    @staticmethod
    def has_elements():
        return ConfigModel.objects.exists()

    @staticmethod
    def get_table_records():
        """
        Получение доменов аутентификации необходимой структуры.
        """
        GlobalConfig.initialize()  # Ensures DB contains all values
        for cfg in ConfigModel.objects.all().order_by('section', 'key'):
            if cfg.crypt is True:
                param = Config.section(cfg.section).valueCrypt(cfg.key)
            else:
                param = Config.section(cfg.section).value(cfg.key)

            yield collections.OrderedDict([
                ('name_section', param._section.name()),
                ('name_param', param._key),
                ('value', ListCommand.__get_value(param)),
            ])

    def show_elements(self, stdout, stderr):
        pattern = "{0:20}   {1:40}   {2:40}"

        stdout.write(
            self.style.SUCCESS("Список системных настроек:")
        )

        stdout.write(
            self.style.SUCCESS(
                pattern.format(
                    'Секция',
                    'Параметр',
                    'Значение',
                )
            )
        )

        for domain in self.get_table_records():
            stdout.write(
                self.style.WARNING(
                    pattern.format(*(domain[key] for key in domain))
                )
            )

        from termidesk.rest.handlers import raise_cli_crud_event
        from termidesk.rest.handlers import READ_ACTION
        raise_cli_crud_event(
            entity=ConfigModel.__name__,
            uuid='',
            subtype='',
            name='',
            action=READ_ACTION,
            username=None  # В качестве имени пользователя будет использоваться
                           # имя системного пользователя, запустившего cli-команду
        )

    @staticmethod
    def __get_value(config: Config):
        """
        Получение значения, при условии что данные не конфиденциальны.
        Если передается пароль - значение меняется на звездочки.
        """
        if config.isCrypted():
            from termidesk.management import SENSITIVE_DATA_MASK
            return SENSITIVE_DATA_MASK
        return config.get()
