# -*- coding: utf-8 -*-
from __future__ import unicode_literals

import sys

from termidesk.management.commands.common.subcommands.subcommand import Subcommand
from termidesk.management import raise_cli_system_config_changed_event
from uds.core.util.Config import Config, GlobalConfig
from uds.models.Config import Config as ConfigModel


class SetCommand(Subcommand):
    SUBCOMMAND = 'set'

    def add_subparser(self, subparsers):
        set_parser = subparsers.add_parser(
            self.SUBCOMMAND,
            help="Создать конфигурационный параметр"
        )
        self.add_arguments_subcommand(set_parser)

    def add_arguments_subcommand(self, parser):
        GlobalConfig.initialize()

        parser.add_argument('--section', choices=self.get_section(), required=True, help='Секция')
        parser.add_argument('--key', required=True, help='Параметр')
        parser.add_argument('--value', required=True, help='Значение')

    def handle_subcommand(self, options, stdout, stderr):
        try:
            full_field_name = '"{0}"."{1}"'.format(options['section'], options['key'])
            param = ConfigModel.objects.get(section=options['section'], key=options['key'])
        except ConfigModel.DoesNotExist:
            stderr.write(
                self.style.ERROR('Записи с такими параметрами {0} не существует'.format(full_field_name))
            )
            sys.exit(1)

        try:
            choices_params = Config.section(options['section']).value(options['key']).getParams()
            self.check_value_by_type(full_field_name, param.field_type, options['value'], choices_params)
        except ValueError as error:
            stderr.write(self.style.ERROR(str(error)))
            sys.exit(1)

        if Config.update(param.section, param.key, options['value']) is False:
            stderr.write(self.style.ERROR("Во время сохранения произошла ошибка"))
            sys.exit(1)

        is_sensitive = ConfigModel.objects.get(section=param.section, key=param.key).crypt

        raise_cli_system_config_changed_event(param.section, param.key, options['value'], is_sensitive)

        stdout.write(self.style.SUCCESS("Запись успешно изменена"))

    def check_value_by_type(self, full_field_name: str, field_type: int, value, choices_params=None):
        """ Проверка переданного значения на соответствие типу. """
        if field_type not in Config.FULL_TYPES:
            raise ValueError(
                ('Не пройдена проверка на соответствие значение указанному типу. '
                 'Данный параметр имеет недопустимый тип "{0}"').format(
                    field_type)
            )

        if field_type == Config.BOOLEAN_FIELD:
            if value not in ('0', '1'):
                raise ValueError(
                    ('Переданное значение "{0}" не соответствует логическому типу. '
                     'Доступны значения "0" или "1"').format(value)
                )
            return True

        if field_type == Config.NUMERIC_FIELD:
            try:
                value = int(value)
            except ValueError:
                raise ValueError(
                    ('Значение {0} не может быть приведено к числовому представлению. '
                     'Изменяемый параметр {1} имеет числовой тип').format(value, full_field_name)
                )

        if field_type == Config.CHOICE_FIELD:
            if value not in choices_params:
                raise ValueError(
                    ('Значение {0} не допустимо. '
                     'Вы можете заменить значения параметра {1} только на допустимые значения: {2}').format(
                        value, full_field_name, choices_params
                    )
                )

    @staticmethod
    def get_section():
        return [param['section'] for param in ConfigModel.objects.values('section').distinct()]
