# -*- coding: utf-8 -*-
from __future__ import unicode_literals

import collections
from uds.core.util.State import State
from uds.models import DeployedService
from uds.models.ServicesPoolGroup import DEFAULT_GROUP_NAME

from termidesk.management.commands.common.subcommands.list import (
    ListSubcommand
)


class ListCommand(ListSubcommand):

    def add_subparser(self, subparsers):
        list_parser = subparsers.add_parser(
            self.SUBCOMMAND,
            help="Show items of a service"
        )
        self.add_arguments_subcommand(list_parser)

    @staticmethod
    def has_elements():
        return DeployedService.objects.exists()

    @staticmethod
    def get_table_records():
        """
        Получение необходимой структуры.
        """
        deployedServices = DeployedService.objects.all()
        for service in deployedServices:
            state = str(State.dictionary()[service.state])
            workspaces = str(len(service.cachedUserServices()))
            prepare = str(service.userServices.filter(
                state=State.PREPARING).count())
            protocolChoice = "Да" if service.show_transports else "Нет"
            group = service.servicesPoolGroup.name if \
                service.servicesPoolGroup else DEFAULT_GROUP_NAME
            yield collections.OrderedDict([
                ('id', service.uuid),
                ('name', service.name),
                ('status', state),
                ('workspaces', workspaces),
                ('prepare', prepare),
                ('protocolChoice', protocolChoice),
                ('workspaceGroup', group),
                ('template', service.service.name),
            ])

    def show_elements(self, stdout, stderr):
        pattern = "{0:50}   {1:30}   {2:14}   {3:14}   {4:10}  {5:15}   {6:19}   {7:13}"

        stdout.write(
            self.style.SUCCESS("Список фондов рабочих мест:")
        )

        stdout.write(
            self.style.SUCCESS(
                pattern.format(
                    'ID',
                    'Название',
                    'Статус',
                    'Рабочие места',
                    'Готовятся',
                    'Выбор протокола',
                    'Группа рабочих мест',
                    'Шаблон'
                )
            )
        )

        for service in self.get_table_records():
            stdout.write(
                self.style.WARNING(
                    pattern.format(*(service[key] for key in service))
                )
            )

        from termidesk.rest.handlers import raise_cli_crud_event
        from termidesk.rest.handlers import READ_ACTION
        raise_cli_crud_event(
            entity=DeployedService.__name__,
            uuid='',
            subtype='',
            name='',
            action=READ_ACTION,
            username=None  # В качестве имени пользователя будет использоваться
                           # имя системного пользователя, запустившего cli-команду
        )
