# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.core.management.base import (BaseCommand,
                                         CommandError,
                                         CommandParser)
from uds.models import Provider
from termidesk.management.commands.subcommands.prov.tpl.create import (
    CreateCommand
)
from termidesk.management.commands.subcommands.prov.tpl.list import (
    ListCommand
)
from termidesk.management.commands.subcommands.prov.tpl.remove import (
    RemoveCommand
)


class IdCommand(BaseCommand):
    SUBCOMMAND = 'id'
    SUBPARSERS_DEST = 'id_subcommands'

    def get_item_by_uid(self, uid):
        try:
            provider = Provider.objects.get(uuid=uid)

            self.tpl_command = TplCommand(provider)
            self.tpl_command.add_subparser(self.subparsers)
        except Provider.DoesNotExist:
            raise CommandError('Not found provider by uid={}'.format(uid))

    def add_subparser(self, parent_subparsers):
        """
        Добавление вложенного парсера.
        :param parent_subparsers:
        :return:
        """
        self.id_parser = parent_subparsers.add_parser(
            self.SUBCOMMAND,
            help="Show items of a service",
        )

        self.id_parser.add_argument(
            '{id}', type=self.get_item_by_uid,
            nargs=1, help='Передайте уникальный код поставщика ресурсов')

        class SubParser(CommandParser):
            def __init__(self, **kwargs):
                super(SubParser, self).__init__(**kwargs)

        self.subparsers = self.id_parser.add_subparsers(
            title="subcommands",
            dest=self.SUBPARSERS_DEST,
            parser_class=SubParser
        )

    def handle_subcommand(self, options, stdout, stderr):
        self.tpl_command.handle_subcommand(options, stdout, stderr)


class TplCommand(BaseCommand):
    SUBCOMMAND = 'tpl'
    SUBPARSERS_DEST = 'tpl_subcommands'

    def __init__(self, provider):
        super(TplCommand, self).__init__()
        self.provider = provider

    def add_subparser(self, parent_subparsers):
        tpl_parser = parent_subparsers.add_parser(
            self.SUBCOMMAND,
            help="Create service"
        )

        class SubParser(CommandParser):
            def __init__(self, **kwargs):
                super(SubParser, self).__init__(**kwargs)

        subparsers = tpl_parser.add_subparsers(
            title="subcommands",
            dest=self.SUBPARSERS_DEST,
            parser_class=SubParser
        )

        self.create_command = CreateCommand(self.style, self.provider)
        self.create_command.add_subparser(subparsers)

        self.list_command = ListCommand(self.style)
        self.list_command.add_subparser(subparsers)

        self.remove_command = RemoveCommand(self.style)
        self.remove_command.add_subparser(subparsers)

    def handle_subcommand(self, options, stdout, stderr):

        if options['tpl_subcommands'] == self.list_command.SUBCOMMAND:
            return self.list_command.handle_subcommand(options, stdout, stderr)

        if options['tpl_subcommands'] == self.remove_command.SUBCOMMAND:
            return self.remove_command.handle_subcommand(
                options,
                stdout,
                stderr
            )

        if options['tpl_subcommands'] == self.create_command.SUBCOMMAND:
            return self.create_command.handle_subcommand(options, stdout, stderr)
