# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from uds.models import Provider, UserService
from uds.core.util.State import State
import collections

from termidesk.management.commands.common.subcommands.list import ListSubcommand


class ListCommand(ListSubcommand):

    def add_subparser(self, subparsers):
        list_parser = subparsers.add_parser(
            self.SUBCOMMAND,
            help="Show items of a service"
        )
        self.add_arguments_subcommand(list_parser)

    @staticmethod
    def has_elements():
        return Provider.objects.exists()

    @staticmethod
    def get_table_records():
        """
        Получение провайдеров необходимой структуры.
        """
        providers = Provider.objects.all()
        for provider in providers:
            type_ = provider.getType()
            maintenance_mode = ('Включено' if provider.maintenance_mode == 1
                                else 'Выключено')
            services_count = provider.services.count()
            user_services_count = UserService.objects.filter(
                deployed_service__service__provider=provider
            ).exclude(state__in=(State.REMOVED, State.ERROR)).count()

            yield collections.OrderedDict([
                ('id', provider.uuid),
                ('name', provider.name),
                ('maintenance_mode', maintenance_mode),
                ('type', type_.name()),
                ('services_count', services_count),
                ('user_services_count', user_services_count),
            ])

    def show_elements(self, stdout, stderr):
        pattern = "{0:50}   {1:30}   {2:15}   {3:20}   {4:7}   {5:13}"

        stdout.write(
            self.style.SUCCESS("Список поставщиков ресурсов:")
        )

        stdout.write(
            self.style.SUCCESS(
                pattern.format(
                    'ID',
                    'Название',
                    'Техобслуживание',
                    'Тип',
                    'Шаблоны',
                    'Рабочие места'
                )
            )
        )

        for provider in self.get_table_records():
            stdout.write(
                self.style.WARNING(
                    pattern.format(*(provider[key] for key in provider))
                )
            )


        from termidesk.rest.handlers import raise_cli_crud_event
        from termidesk.rest.handlers import READ_ACTION
        raise_cli_crud_event(
            entity=Provider.__name__,
            uuid='',
            subtype='',
            name='',
            action=READ_ACTION,
            username=None  # В качестве имени пользователя будет использоваться
                           # имя системного пользователя, запустившего cli-команду
        )