# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.core.management.base import CommandError
from uds.models import Service
from django.db import transaction
from argparse import ArgumentError

from termidesk.management.commands.common.subcommands.create import (
    CreateSubcommand
)


class CreateCommand(CreateSubcommand):
    name_of_service = 'шаблона рабочих мест'

    SUBCOMMAND = 'create'

    BASE_ARGS = (
        'name', 'comments',
    )

    def __init__(self, style, provider):
        try:
            super(CreateCommand, self).__init__(style)
            self.provider = provider
            self.types = [service.typeType
                          for service in provider.getInstance().offers]
        except Exception:
            raise ArgumentError(self, 'Не был передан провайдер')

    def add_subparser(self, subparsers):
        create_parser = subparsers.add_parser(
            self.SUBCOMMAND,
            help="Create service"
        )

        self.add_arguments_subcommand(create_parser)

        create_parser.add_argument(
            '--name', type=str, required=True,
            help="Имя объекта"
        )

        create_parser.add_argument(
            '--comments', type=str,
            help="Комментарий для объекта",
            default=''
        )

    def handle_subcommand(self, options, stdout, stderr):
        super(CreateCommand, self).handle_subcommand(options, stdout, stderr)

    def validate_base_data(self, data):
        """ Проверка существования шаблона рабочих мест по имени. """
        try:
            name = data['name']
            Service.objects.get(name=name)
            error = ('Шаблон рабочих мест с таким именем {} '
                     'уже существует').format(name)
            raise CommandError(error)
        except Service.DoesNotExist:
            pass

    @transaction.atomic()
    def create_service(self, service_type, main_args, params):
        service = Service.objects.create(
            provider_id=self.provider.id,
            name=main_args['name'],
            comments=main_args['comments'],
            data_type=service_type,
        )
        service.data = service.getInstance(params).serialize()
        service.save()

        from termidesk.rest.handlers import raise_cli_crud_event
        from termidesk.rest.handlers import CREATE_ACTION

        raise_cli_crud_event(
            entity=service.__class__.__name__,
            uuid=service.uuid,
            subtype=service.data_type,
            name=service.name,
            action=CREATE_ACTION,
            username=None  # В качестве имени пользователя будет использоваться
                           # имя системного пользователя, запустившего cli-команду
        )

    def get_service_factory(self):
        return None

    def get_lookup_service_by_type(self, service_type):
        return self.provider.getType().getServiceByType(service_type)
