# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from uds.models import Service, UserService, DeployedService
import collections

from termidesk.management.commands.common.subcommands.list import (
    ListSubcommand
)


class ListCommand(ListSubcommand):
    SUBCOMMAND = 'list'

    def add_subparser(self, subparsers):
        list_parser = subparsers.add_parser(
            self.SUBCOMMAND,
            help="List service"
        )

        self.add_arguments_subcommand(list_parser)

    @staticmethod
    def has_elements():
        return Service.objects.exists()

    @staticmethod
    def get_table_records():
        services = Service.objects.all()
        for service in services:
            workspaces = 0
            fonds = 0
            for i in DeployedService.objects.filter(service_id=service.id):
                workspaces += UserService.objects.filter(deployed_service_id=i.id).count()
                fonds += 1

            yield collections.OrderedDict([
                ('id', service.uuid),
                ('name', service.name),
                ('comments', service.comments),
                ('type', service.data_type),
                ('fonds', fonds),
                ('workspaces', workspaces),
            ])

    def show_elements(self, stdout, stderr):
        pattern = "{0:40}   {1:30.30}   {2:35.35}   {3:20}   {4:1}   {5:7}"

        stdout.write(
            self.style.SUCCESS("Список шаблонов рабочих мест:")
        )

        stdout.write(
            self.style.SUCCESS(
                pattern.format(
                    'ID',
                    'Название',
                    'Комментарий',
                    'Тип',
                    'Шаблоны',
                    'Рабочие места'
                )
            )
        )

        for service in self.get_table_records():
            stdout.write(
                self.style.WARNING(
                    pattern.format(*(service[key] for key in service))
                )
            )

        from termidesk.rest.handlers import raise_cli_crud_event
        from termidesk.rest.handlers import READ_ACTION
        raise_cli_crud_event(
            entity=Service.__name__,
            uuid='',
            subtype='',
            name='',
            action=READ_ACTION,
            username=None  # В качестве имени пользователя будет использоваться
                           # имя системного пользователя, запустившего cli-команду
        )
