# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db.utils import OperationalError
from uds.models import Service
from django.core.management.base import CommandError

from termidesk.management.commands.common.subcommands.remove import (
    RemoveSubcommand
)


class RemoveCommand(RemoveSubcommand):

    def add_subparser(self, subparsers):
        remove_parser = subparsers.add_parser(
            self.SUBCOMMAND,
            help="Remove service"
        )

        self.add_arguments_subcommand(remove_parser)

        remove_parser.add_argument(
            '--uuid', type=str, required=True,
            help="Id объекта для удаления"
        )

    @staticmethod
    def validate_base_data(data):
        """ Проверка существования шаблона """
        try:
            Service.objects.get(uuid=data)
            return True
        except Service.DoesNotExist:
            return False

    def remove_service(self, data, stdout, stderr):
        """ Удаление шаблона """
        try:
            service = Service.objects.get(uuid=data)
            # Так как событие возникает после удаления,
            # то необходимо заранее сохранить сведения об удаляемом объекте
            service_type = service.data_type
            service_name = service.name
            service_uuid = service.uuid
            service.delete()

            from termidesk.rest.handlers import raise_cli_crud_event
            from termidesk.rest.handlers import DELETE_ACTION

            raise_cli_crud_event(
                entity=Service.__name__,
                uuid=service_uuid,
                subtype=service_type,
                name=service_name,
                action=DELETE_ACTION,
                username=None  # В качестве имени пользователя будет использоваться
                # имя системного пользователя, запустившего cli-команду
            )
            return True
        except OperationalError:
            stderr.write(self.style.ERROR(
                'Шаблон не был удалён'
            ))
            return False

    def confirmation(self, data, stderr):
        """ Подтверждение удаления """
        yes = ['y', 'Y', 'yes', 'YES', 'Yes']

        stderr.write(self.style.WARNING(
            'Удалить шаблон {}?  y/N:'.format(data)
        ))
        choise = input()
        if choise in yes:
            return True
        else:
            raise CommandError('Шаблон не был удалён')

    def handle_subcommand(self, options, stdout, stderr):

        if options['silent']:
            if self.validate_base_data(options['uuid']):
                self.remove_service(options['uuid'], stdout, stderr)
            return 0

        if options['output']:
            return self.show_formatting_items(
                options['output'],
                options['uuid'],
                stdout,
                stderr,
            )

        self.confirmation(options['uuid'], stderr)
        if (self.validate_base_data(options['uuid']) and
                self.remove_service(options['uuid'], stdout, stderr)):
            stdout.write(self.style.SUCCESS(
                'Шаблон {} удален'.format(options['uuid'])
            ))
            return 0
        else:
            stdout.write(
                self.style.WARNING(
                    'Шаблон {} не найден'.format(options['uuid'])
                )
            )
            return 0
