"""Модуль содержит логику для консольной команды получения списка протоколов доставки"""
# -*- coding: utf-8 -*-
from __future__ import unicode_literals

import collections
from uds.models import Transport


from termidesk.management.commands.common.subcommands.list import ListSubcommand


class ListCommand(ListSubcommand):
    """Отображение списка протоколов доставки"""

    def add_subparser(self, subparsers):
        list_parser = subparsers.add_parser(
            self.SUBCOMMAND,
            help="Показать список протоколов лдоставки"
        )
        self.add_arguments_subcommand(list_parser)

    @staticmethod
    def has_elements():
        return Transport.objects.exists()

    @staticmethod
    def get_table_records():
        """
        Получение провайдеров необходимой структуры.
        """
        transports = Transport.objects.all()
        for transport in transports:
            type_ = transport.getType()
            deployed_services_count = transport.deployedServices.count()
            in_use = 'Да' if deployed_services_count > 0 else 'Нет'

            yield collections.OrderedDict([
                ('id', transport.uuid),
                ('name', transport.name),
                ('type', type_.name()),
                ('in_use', in_use),
                ('comment', transport.comments),
            ])

    def show_elements(self, stdout, stderr):
        pattern = "{0:37}   {1:25.25}   {2:40.40}   {3:<12}   {4:30.30}"

        stdout.write(
            self.style.SUCCESS("Список поставщиков ресурсов:")
        )

        stdout.write(
            self.style.SUCCESS(
                pattern.format(
                    'ID',
                    'Название',
                    'Тип',
                    'Используется',
                    'Комментарии'
                )
            )
        )

        for transport in self.get_table_records():
            stdout.write(
                self.style.WARNING(
                    pattern.format(*(transport[key] for key in transport))
                )
            )

        from termidesk.rest.handlers import raise_cli_crud_event
        from termidesk.rest.handlers import READ_ACTION
        raise_cli_crud_event(
            entity=Transport.__name__,
            uuid='',
            subtype='',
            name='',
            action=READ_ACTION,
            username=None  # В качестве имени пользователя будет использоваться
                           # имя системного пользователя, запустившего cli-команду
        )
