"""Модуль содержит логику удаления протокола доставки"""
# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from uds.models import Transport
from django.db.utils import OperationalError
from termidesk.management.commands.common.subcommands.remove import RemoveSubcommand


class RemoveCommand(RemoveSubcommand):

    def add_subparser(self, subparsers):
        remove_parser = subparsers.add_parser(
            self.SUBCOMMAND,
            help="Удаление протокола доставки"
        )
        self.add_arguments_subcommand(remove_parser)

        remove_parser.add_argument(
            '--uuid', type=str,
            help="Id объекта для удаления"
        )

    @staticmethod
    def validate_base_data(data):
        """ Проверка существования протокола доставки """
        try:
            Transport.objects.get(uuid=data)
            return True
        except Transport.DoesNotExist:
            return False

    def remove_service(self, data, stdout, stderr):
        """ Удаление протокола доставки """
        try:
            transport = Transport.objects.get(uuid=data)
            # Так как событие возникает после удаления,
            # то необходимо заранее сохранить сведения об удаляемом объекте
            transport_type = transport.data_type
            transport_name = transport.name
            transport_uuid = transport.uuid
            transport.delete()

            from termidesk.rest.handlers import raise_cli_crud_event
            from termidesk.rest.handlers import DELETE_ACTION

            raise_cli_crud_event(
                entity=Transport.__name__,
                uuid=transport_uuid,
                subtype=transport_type,
                name=transport_name,
                action=DELETE_ACTION,
                username=None  # В качестве имени пользователя будет использоваться
                # имя системного пользователя, запустившего cli-команду
            )
            stdout.write(self.style.SUCCESS(
                'Протокол %s был удалён' % data
            ))
            return True
        except OperationalError:
            stderr.write(self.style.ERROR(
                'Протокол %s не был удалён' % data
            ))
            return False
