# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.conf import settings
from django.core.management.base import BaseCommand
from django.utils import timezone
from termidesk.management.commands.common.argtypes import positive_int_type


class Command(BaseCommand):
    help = "Порционная очистка сессии"

    DEFAULTH_LENGTH_CHUNK = 1000

    def add_arguments(self, parser):
        parser.add_argument(
            '--chunk', type=positive_int_type,
            help="Количество сессий для удаления. Значение по-умолчанию: {}.".format(
                self.DEFAULTH_LENGTH_CHUNK
            ),
            default=self.DEFAULTH_LENGTH_CHUNK
        )

    def handle(self, **options):
        chunk_length = options['chunk']
        try:
            from django.contrib.sessions.models import Session
            object_sessions = Session.objects.filter(
                expire_date__lt=timezone.now()
            ).values_list('pk', flat=True)[:chunk_length]

            del_element = Session.objects.filter(
                pk__in=(object_sessions)
            ).delete()[0]
        except NotImplementedError:
            self.stderr.write("Session engine '%s' doesn't support clearing "
                              "expired sessions.\n" % settings.SESSION_ENGINE)

        if del_element:
            self.stdout.write(
                self.style.SUCCESS(
                    'Количество удаленных сессий: {}'.format(del_element))
            )
        else:
            self.stdout.write(self.style.WARNING('Нет элементов для удаления'))
