from django.utils.encoding import force_str
from django_otp.plugins.otp_static.management.commands.addstatictoken import Command as StaticDeviceCommand
from django_otp.plugins.otp_static.models import StaticDevice, StaticToken
from termidesk.management.commands.common.validate_2fa import check_and_get_auth, check_and_get_user
from uds.models.User import User


class Command(StaticDeviceCommand):
    help = "Удаление TOTP устройства пользователя."

    def add_arguments(self, parser):
        super().add_arguments(parser)

        parser.add_argument(
            '--auth_uuid', type=str, required=True,
            help="UUID домена аутентификации"
        )

    def handle(self, *args, **options):
        auth_uuid = options.get('auth_uuid')
        user_name = options.get('username')
        try:
            auth = check_and_get_auth(auth_uuid)
            user = check_and_get_user(auth, user_name)
        except ValueError as error:
            self.stderr.write(error)
            return

        statictoken = self.__add_static_token_for_user(user, options.get('token'))
        self.stdout.write(force_str(statictoken.token))

    def __add_static_token_for_user(self, user: User, token):
        """ Создание статического токена для пользователя. """
        device = next(StaticDevice.objects.filter(user=user).iterator(), None)
        if device is None:
            device = StaticDevice.objects.create(user=user, name='Backup Code')

        if token is None:
            token = StaticToken.random_token()

        return device.token_set.create(token=token)
