from django.core.management.base import BaseCommand
from termidesk.core.auths.helpers import get_totp_device_by_user
from termidesk.management.commands.common.validate_2fa import check_and_get_auth, check_and_get_user


class Command(BaseCommand):
    help = "Удаление TOTP устройства пользователя."

    def add_arguments(self, parser):
        parser.add_argument(
            '--auth_uuid', type=str, required=True,
            help="UUID домена аутентификации"
        )

        parser.add_argument(
            'username', type=str,
            help=("Имя пользователя")
        )

    def handle(self, **options):
        auth_uuid = options.get('auth_uuid')
        user_name = options.get('username')
        try:
            auth = check_and_get_auth(auth_uuid)
            user = check_and_get_user(auth, user_name)
        except ValueError as error:
            self.stderr.write(error)
            return

        device = get_totp_device_by_user(user)
        if device is None:
            self.stderr.write('К указанному пользователю "{}" домена аутентификации "{}" '
                              'не привязано ни одно TOTP устройство. '.format(user, auth))
            return

        device.delete()

        self.stdout.write('TOTP устройство для пользователя "{}" успешно удалено'.format(user))
