# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.core.management.base import CommandError
from django.db import transaction
from uds.models import ServicesPoolGroup
from termidesk.management.commands.common.common_command import CommonCommand
from termidesk.management.commands.common.subcommands.create_without_type import CreateWithoutType
from termidesk.management.commands.common.argtypes import \
    positive_int_type


class Command(CommonCommand):
    help = '''Создание группы рабочих мест.'''

    create_command = None

    def add_arguments(self, parser):
        super(Command, self).add_arguments(parser)
        self.create_command = CreateCommand(self.style)
        self.create_command.add_subparser(self.subparsers)

    def handle(self, *args, **options):
        subcommand = options.get('subcommand')

        if subcommand == self.create_command.SUBCOMMAND:
            return self.create_command.handle_subcommand(
                options,
                self.stdout,
                self.stderr
            )

        self.stdout.write(
            self.style.ERROR(
                'Не удалось обработать команду '.format(subcommand)
            )
        )


class CreateCommand(CreateWithoutType):
    name_of_service = 'группы рабочих мест'

    BASE_ARGS = (
        'name', 'comments', 'priority'
    )

    _factory = None

    def add_subparser(self, subparsers):
        create_parser = subparsers.add_parser(
            self.SUBCOMMAND,
            help="Create service"
        )

        self.add_arguments_subcommand(create_parser)

        create_parser.add_argument(
            '--name', type=str, required=True,
            help="Имя объекта"
        )

        create_parser.add_argument(
            '--comments', type=str,
            help="Комментарий", default=''
        )

        create_parser.add_argument(
            '--priority', type=positive_int_type,
            help="Приоритет", default=1,

        )

    @transaction.atomic()
    def create_service(self, main_args):
        created_group = ServicesPoolGroup.objects.create(**main_args)

        from termidesk.rest.handlers import raise_cli_crud_event
        from termidesk.rest.handlers import CREATE_ACTION

        raise_cli_crud_event(
            entity=created_group.__class__.__name__,
            uuid=created_group.uuid,
            subtype='',
            name=created_group.name,
            action=CREATE_ACTION,
            username=None  # В качестве имени пользователя будет использоваться
                           # имя системного пользователя, запустившего cli-команду
        )
        return created_group

    def validate_base_data(self, data):
        """ Проверка существования сети по имени. """
        try:
            ServicesPoolGroup.objects.get(name=data['name'])
            error = ('Группа с таким именем {} '
                     'уже существует').format(data['name'])
            raise CommandError(error)
        except ServicesPoolGroup.DoesNotExist:
            pass
