"""Модуль содержит реализацию консольной команды управления лицензиями `tdsk_license`"""
# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.core.management import CommandError

from termidesk.management.commands.common.common_command import CommonCommand
from termidesk.management.commands.subcommands.license.show import ShowCommand
from termidesk.management.commands.subcommands.license.install import InstallCommand


class Command(CommonCommand):
    """Основной класс консольной команды `tdsk_license`"""
    help = "License management"

    install_command = None
    show_command = None

    def add_arguments(self, parser):
        """Добавление подкоманд"""
        super().add_arguments(parser)

        self.install_command = InstallCommand(self.style)
        self.install_command.add_subparser(self.subparsers)

        self.show_command = ShowCommand(self.style)
        self.show_command.add_subparser(self.subparsers)

    def handle(self, *args, **options):  # pylint: disable=unused-argument
        """Обработка аргументов консольной команды"""
        subcommand = options.get('subcommand')

        if subcommand == self.install_command.subcommand:
            try:
                return self.install_command.handle_subcommand(
                    options,
                    self.stdout,
                    self.stderr
                )
            except CommandError as command_error:
                if "Не указан файл лицензии" in str(command_error):
                    self.print_help('manage.py', 'tdsk_license')

                raise

        if subcommand == self.show_command.subcommand:
            return self.show_command.handle_subcommand(
                options,
                self.stdout,
                self.stderr
            )

        self.stdout.write(self.style.ERROR('Не удалось обработать команду {}'.format(subcommand)))
        return None
