# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.core.management.base import CommandError
from django.db import transaction
from uds.models import Network
from uds.core.util import net
import argparse
from termidesk.management.commands.common.common_command import CommonCommand
from termidesk.management.commands.common.subcommands.create_without_type import CreateWithoutType


class Command(CommonCommand):
    help = '''Создание сети.'''

    create_command = None

    def add_arguments(self, parser):
        super(Command, self).add_arguments(parser)
        self.create_command = CreateCommand(self.style)
        self.create_command.add_subparser(self.subparsers)

    def handle(self, *args, **options):
        subcommand = options.get('subcommand')

        if subcommand == self.create_command.SUBCOMMAND:
            return self.create_command.handle_subcommand(
                options,
                self.stdout,
                self.stderr
            )

        self.stdout.write(
            self.style.ERROR(
                'Не удалось обработать команду '.format(subcommand)
            )
        )


def net_type(value):
    try:
        net.networksFromString(value)
        return value
    except Exception:
        raise argparse.ArgumentTypeError(
            "Invalid address range: {}".format(value)
        )


class CreateCommand(CreateWithoutType):
    name_of_service = 'сети'

    BASE_ARGS = (
        'name', 'netRange'
    )

    _factory = None

    def add_subparser(self, subparsers):
        create_parser = subparsers.add_parser(
            self.SUBCOMMAND,
            help="Create service"
        )

        self.add_arguments_subcommand(create_parser)

        create_parser.add_argument(
            '--name', type=str, required=True,
            help="Имя объекта"
        )

        create_parser.add_argument(
            '--netRange', type=net_type, required=True,
            help=("Диапазон адресов. Допустимы различные форматы, "
                  "например: A.B.C.*, A.B.C.D/N, A.B.C.D - E.F.G.D"),
        )

    @transaction.atomic()
    def create_service(self, main_args):
        created_network = Network.create(**main_args)

        from termidesk.rest.handlers import raise_cli_crud_event
        from termidesk.rest.handlers import CREATE_ACTION

        raise_cli_crud_event(
            entity=created_network.__class__.__name__,
            uuid=created_network.uuid,
            subtype='',
            name=created_network.name,
            action=CREATE_ACTION,
            username=None  # В качестве имени пользователя будет использоваться
                           # имя системного пользователя, запустившего cli-команду
        )
        return created_network

    def validate_base_data(self, data):
        """ Проверка существования сети по имени. """
        try:
            Network.objects.get(name=data['name'])
            error = ('Сеть с таким именем {} '
                     'уже существует').format(data['name'])
            raise CommandError(error)
        except Network.DoesNotExist:
            pass
