# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.core.management.base import CommandError
from .common.common_command import CommonCommand
from termidesk.management.commands.common.subcommands.create import CreateSubcommand
from django.db import transaction
from uds.models import OSManager
from uds.core import osmanagers


class Command(CommonCommand):
    help = '''Создает менеджера гостевых ОС.'''

    create_command = None

    def add_arguments(self, parser):
        super(Command, self).add_arguments(parser)
        self.create_command = CreateCommand(self.style)
        self.create_command.add_subparser(self.subparsers)

    def handle(self, *args, **options):
        subcommand = options.get('subcommand')

        if subcommand == self.create_command.SUBCOMMAND:
            return self.create_command.handle_subcommand(
                options,
                self.stdout,
                self.stderr
            )

        self.stdout.write(
            self.style.ERROR(
                'Не удалось обработать команду '.format(subcommand)
            )
        )


class CreateCommand(CreateSubcommand):
    name_of_service = 'менеджера гостевых ОС'

    types = [auth.typeType
             for auth in list(osmanagers.factory().providers().values())]

    BASE_ARGS = ('name', 'comments')

    _factory = None

    def add_subparser(self, subparsers):
        create_parser = subparsers.add_parser(
            CreateSubcommand.SUBCOMMAND,
            help="Create service"
        )

        self.add_arguments_subcommand(create_parser)

        create_parser.add_argument(
            '--name', type=str, required=True,
            help="Имя объекта"
        )

        create_parser.add_argument(
            '--comments', type=str, help="Комментарий", default=''
        )

    @transaction.atomic()
    def create_service(self, auth_type, main_args, params):
        item = OSManager.objects.create(**main_args)
        item.data_type = auth_type
        item.data = item.getInstance(params).serialize()
        item.save()

        from termidesk.rest.handlers import raise_cli_crud_event
        from termidesk.rest.handlers import CREATE_ACTION

        raise_cli_crud_event(
            entity=item.__class__.__name__,
            uuid=item.uuid,
            subtype=item.data_type,
            name=item.name,
            action=CREATE_ACTION,
            username=None  # В качестве имени пользователя будет использоваться
                           # имя системного пользователя, запустившего cli-команду
        )

    def get_service_factory(self):
        if self._factory is None:
            self._factory = osmanagers.factory()
        return self._factory

    def validate_base_data(self, data):
        """ Проверка существования параметров гостевой ОС по имени. """
        try:
            OSManager.objects.get(name=data['name'])
            error = ('Менеджер гостевых ОС с таким именем {} '
                     'уже существует').format(data['name'])
            raise CommandError(error)
        except OSManager.DoesNotExist:
            pass
