# -*- coding: utf-8 -*-
from __future__ import unicode_literals


from .common.common_command import CommonCommand
from django.core.management.base import CommandError
from termidesk.management.commands.subcommands.prov.create import CreateCommand
from termidesk.management.commands.subcommands.prov.list import ListCommand
from termidesk.management.commands.subcommands.prov.id_tpl import IdCommand
from uds.models import Provider


class Command(CommonCommand):
    help = '''Работа с поставщиком ресурсов'''

    create_command = None
    list_command = None

    @staticmethod
    def get_item_by_uid(uid):
        """ Получение сервиса по uid. """
        try:
            Provider.objects.get(uuid=uid)
        except Provider.DoesNotExist:
            raise CommandError('Not found provider by uid={}'.format(uid))

    def add_arguments(self, parser):
        super(Command, self).add_arguments(parser)
        self.create_command = CreateCommand(self.style)
        self.create_command.add_subparser(self.subparsers)

        self.list_command = ListCommand(self.style)
        self.list_command.add_subparser(self.subparsers)

        self.id_command = IdCommand(self.style)
        self.id_command.add_subparser(self.subparsers)

    def handle(self, *args, **options):
        subcommand = options.get('subcommand')

        if subcommand == self.create_command.SUBCOMMAND:
            return self.create_command.handle_subcommand(
                options,
                self.stdout,
                self.stderr
            )

        if subcommand == self.list_command.SUBCOMMAND:
            return self.list_command.handle_subcommand(
                options,
                self.stdout,
                self.stderr
            )

        if subcommand == self.id_command.SUBCOMMAND:
            return self.id_command.handle_subcommand(
                options,
                self.stdout,
                self.stderr
            )

        self.stdout.write(
            self.style.ERROR(
                'Не удалось обработать команду '.format(subcommand)
            )
        )
