import json
from collections import namedtuple

from django.core.management.base import BaseCommand
from version import VERSION, __version__

JSON_FORMATTING = 'json'
TYPES_FORMATTING = (JSON_FORMATTING,)


class Command(BaseCommand):
    help = "Получение версии Термидеск"

    def add_arguments(self, parser):
        parser.add_argument(
            '--output', choices=TYPES_FORMATTING, required=False,
            help='Вывод данных в определенном формате',
            default=False
        )

    def handle(self, **options):
        if options['output']:
            return self.show_formatting_items(options['output'])

        self.stdout.write(__version__)

    def show_formatting_items(self, type_formatting):
        """ Вывод форматированного представления элементов. """
        if type_formatting != JSON_FORMATTING:
            self.stderr.write(self.style.ERROR(
                'Переданный тип форматировани {} не поддерживается'.format(
                    type_formatting
                )
            ))

        extended_info = VersionExtended(*(value for value in VERSION))
        self.stdout.write(
            json.dumps({'version': __version__, 'version_extended': extended_info._asdict()})
        )


class VersionExtended(
    namedtuple('VersionExtendedParams', ['major', 'minor', 'patch', 'build', 'type', 'revision'])):
    '''
    Расширенная информация о версии.
    Данные:
        :param major: мажорная версия
        :param minor: минорная версия
        :param patch: патч-версия
        :param build: версия сборки
        :param type: тип
        :param revision: количество доработок
    '''
    pass
