from django.contrib.contenttypes.models import ContentType
from django.db import migrations

PERMISSIONS = [
    'UserPermission.models.create_DeployedService',
    'UserPermission.models.change_DeployedService',
    'UserPermission.models.delete_DeployedService',
    'UserPermission.models.view_DeployedService',
    'UserPermission.models.manage_DeployedService_Publication',
    'UserPermission.models.manage_DeployedService_UserService',
    'UserPermission.models.manage_DeployedService_Transport',
    'UserPermission.models.manage_DeployedService_User',
    'UserPermission.models.manage_DeployedService_Group',
]


def change_content_type_migrations(apps, schema_editor):
    Permission = apps.get_model('auth', 'Permission')

    DeployedService = apps.get_model('uds', 'DeployedService')
    UserPermission = apps.get_model('termidesk', 'UserPermission')

    content_type = ContentType.objects.get_for_model(DeployedService)
    content_type_user_permission = ContentType.objects.get_for_model(UserPermission)

    Permission.objects.filter(
        codename__in=PERMISSIONS, content_type_id=content_type_user_permission.id
    ).update(content_type=content_type)


def reverse_func(apps, schema_editor):
    Permission = apps.get_model('auth', 'Permission')
    UserPermission = apps.get_model('termidesk', 'UserPermission')
    content_type = ContentType.objects.get_for_model(UserPermission)
    Permission.objects.filter(
        codename__in=PERMISSIONS
    ).update(content_type_id=content_type.id)


class Migration(migrations.Migration):
    dependencies = [
        ('termidesk', '0019_manual_remove_manage_superadmins'),
    ]

    run_before = [
        ('uds', '0045_add_deployed_service_permissions'),
    ]

    operations = [
        migrations.RunPython(change_content_type_migrations, reverse_code=reverse_func),
        migrations.AlterModelOptions(
            name='userpermission',
            options={
                'default_permissions': (),
                'managed': False,
                'permissions': (
                    ('UserPermission.models.create_ServicesPoolGroup', 'Создание групп рабочих мест'),
                    ('UserPermission.models.change_ServicesPoolGroup', 'Редактирование групп рабочих мест'),
                    ('UserPermission.models.delete_ServicesPoolGroup', 'Удаление групп рабочих мест'),
                    ('UserPermission.models.view_ServicesPoolGroup', 'Просмотр групп рабочих мест'),
                    ('UserPermission.models.create_Authenticator', 'Создание доменов аутентификации'),
                    ('UserPermission.models.change_Authenticator', 'Редактирование доменов аутентификации'),
                    ('UserPermission.models.delete_Authenticator', 'Удаление доменов аутентификации'),
                    ('UserPermission.models.view_Authenticator', 'Просмотр доменов аутентификации'),
                    ('UserPermission.models.manage_Authenticator_Group', 'Управление группами домена аутентификации'),
                    ('UserPermission.models.manage_Authenticator_User',
                     'Управление пользователями домена аутентификации'),
                    ('UserPermission.models.view_Config', 'Просмотр системных параметров'),
                    ('UserPermission.models.change_Config', 'Изменение системных параметров'),
                    ('UserPermission.models.view_Log', 'Просмотр мониторинга'),
                    ('UserPermission.management.view_UserWorkplaceSessions', 'Просмотр пользовательских сессий'),
                    ('UserPermission.management.manage_UserWorkplaceSessions', 'Управление пользовательскими сессиями'),
                    ('UserPermission.models.create_Provider', 'Создание поставщика ресурсов'),
                    ('UserPermission.models.change_Provider', 'Редактирование поставщика ресурсов'),
                    ('UserPermission.models.delete_Provider', 'Удаление поставщика ресурсов'),
                    ('UserPermission.models.view_Provider', 'Просмотр поставщиков ресурсов'),
                    ('UserPermission.models.manage_Provider_Service', 'Управление шаблонами рабочих мест'),
                    ('UserPermission.models.create_Image', 'Создание изображений в галерее'),
                    ('UserPermission.models.change_Image', 'Редактирование изображений в галерее'),
                    ('UserPermission.models.delete_Image', 'Удаление изображений из галереи'),
                    ('UserPermission.models.view_Image', 'Просмотр изображений в галерее'),
                    ('UserPermission.management.upload_License', 'Загрузка лицензии'),
                    ('UserPermission.management.view_License', 'Просмотр лицензии'),
                    ('UserPermission.management.manage_User_Roles', 'Управление ролями'),
                    ('UserPermission.models.create_OSManager', 'Создание параметров гостевых ОС'),
                    ('UserPermission.models.change_OSManager', 'Редактирование параметров гостевых ОС'),
                    ('UserPermission.models.delete_OSManager', 'Удаление параметров гостевых ОС'),
                    ('UserPermission.models.view_OSManager', 'Просмотр параметров гостевых ОС'),
                    ('UserPermission.models.create_Transport', 'Создание протоколов доставки'),
                    ('UserPermission.models.change_Transport', 'Редактирование протоколов доставки'),
                    ('UserPermission.models.delete_Transport', 'Удаление протоколов доставки'),
                    ('UserPermission.models.view_Transport', 'Просмотр протоколов доставки'),
                    ('UserPermission.models.create_Network', 'Создание сетей'),
                    ('UserPermission.models.change_Network', 'Редактирование сетей'),
                    ('UserPermission.models.delete_Network', 'Удаление сетей'),
                    ('UserPermission.models.view_Network', 'Просмотр сетей'),
                )
            },
        ),
    ]
