from django.db import models
from uds.models.ManagedObjectModel import ManagedObjectModel
from uds.models.ServicesPool import DeployedService


class PolicyDeployedService(ManagedObjectModel):
    deployed_service = models.ForeignKey(DeployedService, on_delete=models.CASCADE,
                                         related_name='policies')

    class Meta(ManagedObjectModel.Meta):
        ordering = ("name",)
        app_label = "termidesk"
        db_table = "%s_%s" % (app_label, "policy_deployed_service")

    def getType(self):
        from termidesk.core.policies.utils import registry

        return registry().lookup(self.data_type)

    def get_value(self):
        return self.getInstance().get_value()

    @staticmethod
    def get_policy(data_type: str, deployed_service_id: int):
        return PolicyDeployedService.objects.get(
            deployed_service_id=deployed_service_id,
            data_type=data_type
        )

    @staticmethod
    def is_policy_exists(data_type: str, deployed_service_id: int):
        return PolicyDeployedService.objects.filter(
            deployed_service_id=deployed_service_id,
            data_type=data_type
        ).exists()

    @staticmethod
    def get_policies_by_types(deployed_service_id):
        """ Объекты политик фонда рабочего места собрынные по типам. """
        return {policy.data_type: policy for policy in
                PolicyDeployedService.objects.filter(deployed_service_id=deployed_service_id).all()}
