from django.contrib.auth.models import Permission
from django.db import models

PREFIX_PERMISSION = 'UserPermission'
PREFIX_MODELS = 'models'
PREFIX_SECURITY = 'security'
PREFIX_MANAGEMENT = 'management'

SERVICE_POOL_GROUP_CREATE = '.'.join([PREFIX_PERMISSION, PREFIX_MODELS, 'create_ServicesPoolGroup'])
SERVICE_POOL_GROUP_CHANGE = '.'.join([PREFIX_PERMISSION, PREFIX_MODELS, 'change_ServicesPoolGroup'])
SERVICE_POOL_GROUP_DELETE = '.'.join([PREFIX_PERMISSION, PREFIX_MODELS, 'delete_ServicesPoolGroup'])
SERVICE_POOL_GROUP_VIEW = '.'.join([PREFIX_PERMISSION, PREFIX_MODELS, 'view_ServicesPoolGroup'])

AUTHENTICATOR_CREATE = '.'.join([PREFIX_PERMISSION, PREFIX_MODELS, 'create_Authenticator'])
AUTHENTICATOR_CHANGE = '.'.join([PREFIX_PERMISSION, PREFIX_MODELS, 'change_Authenticator'])
AUTHENTICATOR_DELETE = '.'.join([PREFIX_PERMISSION, PREFIX_MODELS, 'delete_Authenticator'])
AUTHENTICATOR_VIEW = '.'.join([PREFIX_PERMISSION, PREFIX_MODELS, 'view_Authenticator'])

AUTHENTICATOR_GROUP_MANAGE = '.'.join([PREFIX_PERMISSION, PREFIX_MODELS, 'manage_Authenticator_Group'])
AUTHENTICATOR_USER_MANAGE = '.'.join([PREFIX_PERMISSION, PREFIX_MODELS, 'manage_Authenticator_User'])

CONFIG_VIEW = '.'.join([PREFIX_PERMISSION, PREFIX_MODELS, 'view_Config'])
CONFIG_CHANGE = '.'.join([PREFIX_PERMISSION, PREFIX_MODELS, 'change_Config'])

LOG_VIEW = '.'.join([PREFIX_PERMISSION, PREFIX_MODELS, 'view_Log'])

USER_WORKPLACE_SESSION_VIEW = '.'.join([PREFIX_PERMISSION, PREFIX_MANAGEMENT, 'view_UserWorkplaceSessions'])
USER_WORKPLACE_SESSION_MANAGE = '.'.join([PREFIX_PERMISSION, PREFIX_MANAGEMENT, 'manage_UserWorkplaceSessions'])

PROVIDER_CREATE = '.'.join([PREFIX_PERMISSION, PREFIX_MODELS, 'create_Provider'])
PROVIDER_CHANGE = '.'.join([PREFIX_PERMISSION, PREFIX_MODELS, 'change_Provider'])
PROVIDER_DELETE = '.'.join([PREFIX_PERMISSION, PREFIX_MODELS, 'delete_Provider'])
PROVIDER_VIEW = '.'.join([PREFIX_PERMISSION, PREFIX_MODELS, 'view_Provider'])

PROVIDER_SERVICE_MANAGE = '.'.join([PREFIX_PERMISSION, PREFIX_MODELS, 'manage_Provider_Service'])

IMAGE_CREATE = '.'.join([PREFIX_PERMISSION, PREFIX_MODELS, 'create_Image'])
IMAGE_CHANGE = '.'.join([PREFIX_PERMISSION, PREFIX_MODELS, 'change_Image'])
IMAGE_DELETE = '.'.join([PREFIX_PERMISSION, PREFIX_MODELS, 'delete_Image'])
IMAGE_VIEW = '.'.join([PREFIX_PERMISSION, PREFIX_MODELS, 'view_Image'])

LICENSE_UPLOAD = '.'.join([PREFIX_PERMISSION, PREFIX_MANAGEMENT, 'upload_License'])
LICENSE_VIEW = '.'.join([PREFIX_PERMISSION, PREFIX_MANAGEMENT, 'view_License'])

USER_ROLES_MANAGE = '.'.join([PREFIX_PERMISSION, PREFIX_MANAGEMENT, 'manage_User_Roles'])

OSMANAGER_CREATE = '.'.join([PREFIX_PERMISSION, PREFIX_MODELS, 'create_OSManager'])
OSMANAGER_CHANGE = '.'.join([PREFIX_PERMISSION, PREFIX_MODELS, 'change_OSManager'])
OSMANAGER_DELETE = '.'.join([PREFIX_PERMISSION, PREFIX_MODELS, 'delete_OSManager'])
OSMANAGER_VIEW = '.'.join([PREFIX_PERMISSION, PREFIX_MODELS, 'view_OSManager'])

TRANSPORT_CREATE = '.'.join([PREFIX_PERMISSION, PREFIX_MODELS, 'create_Transport'])
TRANSPORT_CHANGE = '.'.join([PREFIX_PERMISSION, PREFIX_MODELS, 'change_Transport'])
TRANSPORT_DELETE = '.'.join([PREFIX_PERMISSION, PREFIX_MODELS, 'delete_Transport'])
TRANSPORT_VIEW = '.'.join([PREFIX_PERMISSION, PREFIX_MODELS, 'view_Transport'])

NETWORK_CREATE = '.'.join([PREFIX_PERMISSION, PREFIX_MODELS, 'create_Network'])
NETWORK_CHANGE = '.'.join([PREFIX_PERMISSION, PREFIX_MODELS, 'change_Network'])
NETWORK_DELETE = '.'.join([PREFIX_PERMISSION, PREFIX_MODELS, 'delete_Network'])
NETWORK_VIEW = '.'.join([PREFIX_PERMISSION, PREFIX_MODELS, 'view_Network'])

# Действия с фондами рабочих мест
DEPLOYED_SERVICE_CREATE = '.'.join([PREFIX_PERMISSION, PREFIX_MODELS, 'create_DeployedService'])
DEPLOYED_SERVICE_CHANGE = '.'.join([PREFIX_PERMISSION, PREFIX_MODELS, 'change_DeployedService'])
DEPLOYED_SERVICE_DELETE = '.'.join([PREFIX_PERMISSION, PREFIX_MODELS, 'delete_DeployedService'])
DEPLOYED_SERVICE_VIEW = '.'.join([PREFIX_PERMISSION, PREFIX_MODELS, 'view_DeployedService'])

# Действия внутри фондов рабочих мест

# Включает в себя действия по созданию и отмене публикаций
DS_PUBLICATION_MANAGE = '.'.join([PREFIX_PERMISSION, PREFIX_MODELS, 'manage_DeployedService_Publication'])
# Включает в себя действия по удалению машин из кеша, в том числе и назначенных машин
DS_USER_SERVICE_MANAGE = '.'.join([PREFIX_PERMISSION, PREFIX_MODELS, 'manage_DeployedService_UserService'])
DS_TRANSPORT_MANAGE = '.'.join([PREFIX_PERMISSION, PREFIX_MODELS, 'manage_DeployedService_Transport'])
DS_USER_MANAGE = '.'.join([PREFIX_PERMISSION, PREFIX_MODELS, 'manage_DeployedService_User'])
DS_GROUP_MANAGE = '.'.join([PREFIX_PERMISSION, PREFIX_MODELS, 'manage_DeployedService_Group'])

EXPERIMENTAL = []


class UserPermission(models.Model):
    """
    Класс, отвечающий за формирование пользовательских разрешений.

    !При удалении или переименовании разрешений необходимо создавать дата-миграцию,
    в которой нужно убрать устаревшие разрешения!
    """

    class Meta:
        managed = False
        default_permissions = ()

        permissions = (
            (SERVICE_POOL_GROUP_CREATE, 'Создание групп рабочих мест'),
            (SERVICE_POOL_GROUP_CHANGE, 'Редактирование групп рабочих мест'),
            (SERVICE_POOL_GROUP_DELETE, 'Удаление групп рабочих мест'),
            (SERVICE_POOL_GROUP_VIEW, 'Просмотр групп рабочих мест'),
            (AUTHENTICATOR_CREATE, 'Создание доменов аутентификации'),
            (AUTHENTICATOR_CHANGE, 'Редактирование доменов аутентификации'),
            (AUTHENTICATOR_DELETE, 'Удаление доменов аутентификации'),
            (AUTHENTICATOR_VIEW, 'Просмотр доменов аутентификации'),
            (AUTHENTICATOR_GROUP_MANAGE, 'Управление группами домена аутентификации'),
            (AUTHENTICATOR_USER_MANAGE, 'Управление пользователями домена аутентификации'),
            (CONFIG_VIEW, 'Просмотр системных параметров'),
            (CONFIG_CHANGE, 'Изменение системных параметров'),
            (LOG_VIEW, 'Просмотр мониторинга'),
            (USER_WORKPLACE_SESSION_VIEW, 'Просмотр пользовательских сессий'),
            (USER_WORKPLACE_SESSION_MANAGE, 'Управление пользовательскими сессиями'),
            (PROVIDER_CREATE, 'Создание поставщика ресурсов'),
            (PROVIDER_CHANGE, 'Редактирование поставщика ресурсов'),
            (PROVIDER_DELETE, 'Удаление поставщика ресурсов'),
            (PROVIDER_VIEW, 'Просмотр поставщиков ресурсов'),
            (PROVIDER_SERVICE_MANAGE, 'Управление шаблонами рабочих мест'),
            (IMAGE_CREATE, 'Создание изображений в галерее'),
            (IMAGE_CHANGE, 'Редактирование изображений в галерее'),
            (IMAGE_DELETE, 'Удаление изображений из галереи'),
            (IMAGE_VIEW, 'Просмотр изображений в галерее'),
            (LICENSE_UPLOAD, 'Загрузка лицензии'),
            (LICENSE_VIEW, 'Просмотр лицензии'),
            (USER_ROLES_MANAGE, 'Управление ролями'),
            (OSMANAGER_CREATE, 'Создание параметров гостевых ОС'),
            (OSMANAGER_CHANGE, 'Редактирование параметров гостевых ОС'),
            (OSMANAGER_DELETE, 'Удаление параметров гостевых ОС'),
            (OSMANAGER_VIEW, 'Просмотр параметров гостевых ОС'),
            (TRANSPORT_CREATE, 'Создание протоколов доставки'),
            (TRANSPORT_CHANGE, 'Редактирование протоколов доставки'),
            (TRANSPORT_DELETE, 'Удаление протоколов доставки'),
            (TRANSPORT_VIEW, 'Просмотр протоколов доставки'),
            (NETWORK_CREATE, 'Создание сетей'),
            (NETWORK_CHANGE, 'Редактирование сетей'),
            (NETWORK_DELETE, 'Удаление сетей'),
            (NETWORK_VIEW, 'Просмотр сетей'),
        )

    def list(self):
        pass


def get_user_permissions():
    from uds.models.ServicesPool import ServicePool
    return Permission.objects.filter(
        content_type__app_label__in=['termidesk', 'uds'],
        codename__contains='UserPermission.',
        content_type__model__in=[UserPermission._meta.model_name, ServicePool._meta.model_name],
    ).exclude(
        codename__in=[DS_USER_MANAGE, DS_GROUP_MANAGE, DS_USER_SERVICE_MANAGE, DS_TRANSPORT_MANAGE,
                      DS_PUBLICATION_MANAGE]
    ).order_by('name').all()
