from django.contrib.auth.models import Permission
from django.db import models

import config

PREFIX_PERMISSION_API = 'UserPermissionAPI'

TEXT_READ = PREFIX_PERMISSION_API + '.test.read'
TEXT_WRITE = PREFIX_PERMISSION_API + '.test.write'
RUBACKUP = PREFIX_PERMISSION_API + '.rubackup'

EXPERIMENTAL = []

class UserPermissionAPI(models.Model):
    """
    Класс, отвечающий за формирование разрешений на различные действия с api.

    !При удалении или переименовании разрешений необходимо создавать дата-миграцию,
    в которой нужно убрать устаревшие разрешения!
    """

    class Meta:
        managed = False
        default_permissions = ()

        permissions = (
            (TEXT_READ, 'Чтение эндпоинта test'),
            (TEXT_WRITE, 'Запись эндпоинта test'),
            (RUBACKUP, 'Резервное копирование (RuBackup)'),
        )


def get_api_user_permissions():
    permissions = Permission.objects.filter(content_type__app_label='termidesk',
                                     content_type__model=UserPermissionAPI._meta.model_name)

    if config.DJANGO_DEBUG is False:
        # Скрываем тестовые разрешения API в production режиме
        test_permissions = [TEXT_READ, TEXT_WRITE]
        permissions = filter(lambda x: x.codename not in test_permissions, permissions)

    permissions = map(_mark_experimental_permissions, permissions)

    return permissions


def _mark_experimental_permissions(permission):
    if permission.codename in EXPERIMENTAL:
        permission.name += " (эксперим.)"

    return permission
