from __future__ import unicode_literals

import logging

import requests
from rest_framework.generics import get_object_or_404
from rest_framework.status import HTTP_200_OK
from server.celery import app as celery
from termidesk.core.util.utils import to_str
from uds.core.jobs.DelayedTask import DelayedTask
from uds.core.util import log
from uds.models.UserService import UserService

logger = logging.getLogger(__name__)

TAG = 'logoff-us-'
SUGGESTED_TIME = 30


class LogoffUserService(DelayedTask):
    '''
    Отложенная задача, выполняющая прекращение сессии пользователя.
    '''
    celery_task_name = 'T.termidesk.notifications.delayed_task.logoff_userservice.LogoffUserService'

    @celery.task(name=celery_task_name)
    def run_in_celery(self):
        self.execute()

    def __init__(self, user_service_uuid):
        super(LogoffUserService, self).__init__()

        self._user_service_uuid = user_service_uuid

    def run(self):
        user_service = get_object_or_404(UserService, uuid=self._user_service_uuid)

        try:
            url = user_service.getCommsUrl() + '/logoff'
            response = requests.post(url, headers={'content-type': 'application/json'}, verify=False, timeout=2)
            response_content = to_str(response.content)
            logger.debug('Sent logoff to client using {}: {}'.format(url, response_content))

            if response.status_code != HTTP_200_OK or response_content != '"ok"':
                message = 'Logoff request error: {}'.format(response_content)
                log.doLog(user_service, log.ERROR, message, log.SERVICE)
                logger.error('Logoff {} request error: {}'.format(user_service.friendly_name, response_content))
                return

            message = 'Logoff request accepted'
            log.doLog(user_service, log.INFO, message, log.SERVICE)
            logger.debug('Logoff {} request accepted'.format(user_service.friendly_name))

        except Exception as error:
            message = 'Logoff {} request error: {}'.format(user_service.friendly_name, error)
            log.doLog(user_service, log.ERROR, message, log.SERVICE)
            logger.error('Logoff request error: {}'.format(error))
