from __future__ import unicode_literals

import logging

from django.core.mail import get_connection
from django.core.mail.message import EmailMessage
from server.celery import app as celery
from uds.core.jobs.DelayedTask import DelayedTask
from uds.core.managers.CryptoManager import CryptoManager

logger = logging.getLogger(__name__)


class EmailNotification(DelayedTask):
    '''
    Отложенная задача, выполняющая рассылку почтовых уведомлений.
    '''
    celery_task_name = 'T.termidesk.notifications.delayed_task.sender.EmailNotification'

    @celery.task(name=celery_task_name)
    def run_in_celery(self):
        self.execute()

    def __init__(self, subject, message, admins, server_mail, host,
                 port, username, password, timeout, use_tls, use_ssl):
        super(EmailNotification, self).__init__()

        self._subject = subject
        self._message = message
        self._admins = admins
        self._server_mail = server_mail
        self._host = host
        self._port = port
        self._username = username
        self._password = password
        self._timeout = timeout if timeout > 0 else None  # при timeout=0 письмо не отправится
        self._use_tls = use_tls
        self._use_ssl = use_ssl

    def run(self):
        password = CryptoManager.manager().decrypt(self._password)

        try:
            with get_connection(host=self._host, port=self._port, username=self._username,
                                password=password, use_tls=self._use_tls,
                                use_ssl=self._use_ssl, timeout=self._timeout) as connection:
                EmailMessage(self._subject, self._message, self._server_mail,
                             self._admins, connection=connection).send()
        except Exception as error:
            logger.error(error)
            raise
