""" Модуль содержит логику уведомлений для системы лицензирования"""
# -*- encoding: utf-8 -*-
from datetime import datetime, timezone

from termidesk.license.base import get_registered_users_max_allowed, get_max_active_workstations
from termidesk.notifications.entities.EntityEventsHelperInterface import EntityEventsHelperInterface

NOTIFICATIONS_EVENTS_LICENSE_CONNECTION_LIMIT_REACHED = 'reached_license_connections_limit'
NOTIFICATIONS_EVENTS_LICENSE_USER_LIMIT_REACHED = 'reached_license_user_limit'


class LicenseEventsHelper(EntityEventsHelperInterface):
    """ События системы лицензирования. """

    def __init__(self, mediator: object = None):
        super().__init__(mediator=mediator)

    def connections_limit_reached(self):
        """Событие при превышении допустимого лицензией количества подключений"""
        event_data = {
            'time': datetime.now(timezone.utc).isoformat(),
            'connections_limit': get_max_active_workstations(),
        }

        self.mediator.notify(self, NOTIFICATIONS_EVENTS_LICENSE_CONNECTION_LIMIT_REACHED, event_data)

    def users_limit_reached(self):
        """Событие при превышении допустимого лицензией количества пользователей"""
        event_data = {
            'time': datetime.now(timezone.utc).isoformat(),
            'users_limit': get_registered_users_max_allowed(),
        }

        self.mediator.notify(self, NOTIFICATIONS_EVENTS_LICENSE_USER_LIMIT_REACHED, event_data)
