from datetime import datetime, timezone

from termidesk.notifications.entities.EntityEventsHelperInterface import EntityEventsHelperInterface
from uds.models.Provider import Provider as ProviderModel
from uds.models.User import User

EVENT_PROVIDER_MAINTENANCE_MODE_CHANGED = 'changed_provider_maintenance_mode'


class ProviderEventsHelper(EntityEventsHelperInterface):
    """ События провайдера. """

    def __init__(self, mediator: object = None):
        super().__init__(mediator=mediator)

    def maintenance_mode_changed(self, provider: ProviderModel, user: User):
        """ Событие изменения режима техобслуживания. """
        event_data = {
            'provider_id': provider.id,
            'provider_name': provider.name,
            'maintenance_mode': provider.maintenance_mode,
            'user_id': user.id,
            'user_name': user.name,
            'time': datetime.now(timezone.utc).isoformat(),
        }

        self.mediator.notify(self, EVENT_PROVIDER_MAINTENANCE_MODE_CHANGED, event_data)
