"""Модуль содержит логику отправки событий для виртуальных рабочих мест (UserService)"""
# -*- encoding: utf-8 -*-
from datetime import datetime, timezone

from termidesk.notifications.entities.EntityEventsHelperInterface import EntityEventsHelperInterface
from uds.models.UserService import UserService as UserServiceModel

EVENT_USER_SERVICE_STATE_SET_TO_ERROR = 'set_user_service_state_to_error'


class UserServiceEventsHelper(EntityEventsHelperInterface):
    """События виртуального рабочего места"""

    def __init__(self, mediator=None):
        super().__init__(mediator=mediator)

    def state_changed_to_error(self, user_service: UserServiceModel, stack_trace):
        """Событие установки рабочего места в состояние ОШИБКА"""

        from uds.core.util import log
        # Если рабочему месту назначено имя, то записываем ошибку в лог рабочего места,
        # иначе пишем в лог фонда, так как лог рабочего места из UI доступен только по `friendly_name`
        if user_service.friendly_name:
            log.doLog(user_service, log.ERROR, 'Exception: {0}'.format(stack_trace), log.INTERNAL)
        else:
            log.doLog(
                user_service.deployed_service, log.ERROR,
                'Exception in UserService (uuid: {}, create date: {}): {}'.
                format(user_service.uuid, user_service.creation_date, stack_trace),
                log.INTERNAL
            )

        event_data = {
            # дата и время события в iso
            'time': datetime.now(timezone.utc).isoformat(),
            # uuid фонда
            'service_pool_uuid': user_service.deployed_service.uuid,
            # название фонда
            'service_pool_name': user_service.deployed_service.name,
            # uuid рабочего места
            'user_service_uuid': user_service.uuid,
            # название рабочего места
            'user_service_name': user_service.friendly_name,
            # причина ошибки
            'reason_of_error': stack_trace,
        }

        self.mediator.notify(self, EVENT_USER_SERVICE_STATE_SET_TO_ERROR, event_data)
