# -*- coding: utf-8 -*-

'''
@author: Dmitry Dvoeglazov
'''
from __future__ import unicode_literals

from pkg_resources import iter_entry_points

def __init__():
    '''
    Импортирует дочерние модули и плагины, затем регистрирует классы в реестре
    '''
    import os.path
    import pkgutil
    import sys
    import logging
    from importlib import import_module
    from uds.core import osmanagers
    
    logger = logging.getLogger(__name__)
    
    logger.debug("Searching for os manager plugins...")
    for entry_point in iter_entry_points('termidesk.osmanagers'):
        logger.debug("Found os manager plugin: {}".format(entry_point.name))
        plugin_class = entry_point.load()
        logger.debug("Loaded plugin: {}".format(plugin_class))
        logger.debug("Plugin location: {}".format(sys.modules[plugin_class.__module__].__file__))
        osmanagers.factory().insert(plugin_class)
        logger.debug('Registered {} class with os managers factory'.format(str(plugin_class)))
    
    # Динамически импортируем реализации ОС менеджеров
    # из дочерних пакетов
    # При импорте, необходимо зарегистрировать модуль ОС менеджера  
    # в общем реестре (OSManagersFactory)
    pkgpath = os.path.dirname(sys.modules[__name__].__file__)
    for _, name, _ in pkgutil.iter_modules([pkgpath]):
        import_module('.{}'.format(name), __package__)
        logger.debug("Imported {} module from {}".format(name, __package__))

    p = osmanagers.OSManager
    for cls in p.__subclasses__():
        osmanagers.factory().insert(cls)

__init__()