from rest_framework.exceptions import APIException
from termidesk.core.policies.BasePolicy import BasePolicy
from uds.core.ui.UserInterface import gui


class ProtocolSelectionPolicy(BasePolicy):
    typeName = "Выбор пользователем протокола доставки"
    typeType = "ProtocolSelectionPolicy"
    typeDescription = (
        "Разрешается ли пользователю выбирать протокол доставки "
        "из списка настроенных при подключении к рабочему месту"
    )
    ALLOW = 1
    FORBIDDEN = 0
    ALLOW_VALUES = {ALLOW: "Разрешен", FORBIDDEN: "Запрещен"}

    description = gui.TextField(
        label="Описание",
        required=False,
        rdonly=True,
        multiline=4,
        order=1
    )

    value = gui.ChoiceField(
        label="Значение",
        required=True,
        values=[gui.choiceItem(key, value) for key, value in ALLOW_VALUES.items()],
        defvalue=1,
        order=2
    )

    @classmethod
    def get_view_value(cls, value):
        """Получение текстового представления значения, для отображения в интерфейсе."""
        try:
            value = int(value)
        except ValueError:
            values = [allow_value for allow_value in cls.ALLOW_VALUES.keys()]
            raise APIException('Допустимы только значения: "{values}"'.format(values=values))
        return cls.ALLOW_VALUES.get(value)

    @classmethod
    def check_value(cls, value):
        if cls.get_view_value(value) is None:
            raise APIException('Передано не допустимое значение: "{value}"'.format(value=value))

    def is_allowed(self):
        """ Проверка разрешения на выбор протокола. """
        return self.get_value() == str(self.ALLOW)
