from rest_framework.exceptions import APIException
from termidesk.core.policies.BasePolicy import BasePolicy
from uds.core.ui.UserInterface import gui


class ServiceIdlePolicy(BasePolicy):
    typeName = "Политика простоя рабочего места"
    typeType = "ServiceIdlePolicy"
    typeDescription = (
        "Разрешенное время простоя рабочего места в секундах. \n"
        "Значение -1 означает неограниченное время простоя."
    )

    MIN_VALUE = 60
    MAX_VALUE = 86400
    UNLIMITED_TIME = -1

    ALLOW_VALUES = {UNLIMITED_TIME: "Неограниченное время простоя", MIN_VALUE: "Задано время простоя"}

    description = gui.TextField(
        label="Описание",
        required=False,
        rdonly=True,
        multiline=4,
        order=1
    )

    value = gui.NumericField(
        label="Значение (в секундах)",
        required=True,
        minValue=UNLIMITED_TIME,
        maxValue=MAX_VALUE,
        defvalue=UNLIMITED_TIME,
        order=2
    )

    @classmethod
    def get_view_value(cls, value):
        """Получение текстового представления значения, для отображения в интерфейсе."""
        try:
            value = int(value)
            if value == cls.UNLIMITED_TIME:
                return cls.ALLOW_VALUES.get(value)
            if cls.MIN_VALUE <= value <= cls.MAX_VALUE:
                minutes, seconds = divmod(value, 60)
                hours, minutes = divmod(minutes, 60)
                if hours != 0:
                    return "%dч %02dмин %02dc" % (hours, minutes, seconds)

                if minutes != 0:
                    return "%dмин %02dc" % (minutes, seconds)

                return "%02dc" % seconds
        except ValueError:
            cls.__add_raise_api_exception()

    @classmethod
    def check_value(cls, value):
        if cls.get_view_value(value) is None:
            cls.__add_raise_api_exception()

    @classmethod
    def __get_allow_params(cls):
        """Получение списка допустимых параметров для отображения. """
        return [cls.UNLIMITED_TIME, "{}-{}".format(cls.MIN_VALUE, cls.MAX_VALUE)]

    @classmethod
    def __add_raise_api_exception(cls):
        raise APIException(
            'Допустимы только значения: {values}'.format(values=cls.__get_allow_params())
        )
