from pkg_resources import iter_entry_points


def __init__():
    """
    Импортирует дочерние модули, затем регистрирует классы в реестре
    """
    import logging
    import os.path
    import pkgutil
    import sys
    from importlib import import_module

    from termidesk.core.policies.BasePolicy import BasePolicy
    from termidesk.core.policies.utils import registry

    logger = logging.getLogger(__name__)
    logger.debug("Searching for policy in plugins...")
    for entry_point in iter_entry_points('termidesk.policies'):
        logger.debug("Found policy plugin: {}".format(entry_point.name))
        plugin_class = entry_point.load()
        logger.debug("Loaded plugin: {}".format(plugin_class))
        logger.debug("Plugin location: {}".format(sys.modules[plugin_class.__module__].__file__))
        registry().insert(plugin_class)
        logger.debug('Registered {} class with service factory'.format(str(plugin_class)))

    # Динамически импортируем реализации политик
    # При импорте, необходимо зарегистрировать модуль политики
    # в общем реестре (PoliciesFactory)
    pkgpath = os.path.dirname(sys.modules[__name__].__file__)
    for _, name, _ in pkgutil.iter_modules([pkgpath]):
        import_module(".{}".format(name), __package__)
        logger.debug("Imported {} module from {}".format(name, __package__))

    parent_class = BasePolicy

    for cls in parent_class.__subclasses__():
        registry().insert(cls)


__init__()
