# -*- coding: utf-8 -*-
'''
Created on 14 апр. 2020 г.

@author: dvd
'''
from __future__ import unicode_literals

from uds.core import jobs

from uds.models import Provider

from .client.v2 import VM_NOT_FOUND

import logging
import json

logger = logging.getLogger(__name__)

REMOVE_JOB_FILTER_ATTR = 'job.vm-deferred-removal'
REMOVE_MAX_ATTEMPTS = 30

class VAirDeferredRemoval(jobs.Job):
    # Суммарный интервал freq*attempts должен быть меньше значения Config.KEEP_INFO_TIME
    # Иначе система может переиспользовать имя ВМ и будет удалена не та ВМ
    frecuency = 60 * 5  # Once every NN minutes
    friendly_name = 'vAir VM deferred removal'
    
    @staticmethod
    def get_job_key(vm_id):
        return '{}.{}'.format(REMOVE_JOB_FILTER_ATTR, vm_id)
    
    @staticmethod
    def remove(provider_instance, vm_id):
        logger.debug('Schedule VM {} from {} for deferred removal'.format(vm_id, provider_instance.typeType))

        try:
            data = {
                'vm_id': vm_id,
                'attempts': 0
            }
            key = VAirDeferredRemoval.get_job_key(vm_id)
            provider_instance.storage.saveData(key, json.dumps(data), attr1=REMOVE_JOB_FILTER_ATTR)
        except Exception as e:
            logger.exception('Error during scheduling removal of VM {} from {}: {}'.format(vm_id, provider_instance.typeType, e))

    def run(self):
        from .VAirProvider import Provider as VAirProvider

        logger.debug('Deferred vAir VM removal job started')

        # Look for Providers of correct type
        for provider in Provider.objects.filter(maintenance_mode=False, data_type=VAirProvider.typeType):
            storage = provider.getEnvironment().storage
            instance = provider.getInstance()

            for hash_key, encoded_data, _ in storage.filter(REMOVE_JOB_FILTER_ATTR):
                data = json.loads(encoded_data)
                vm_id = data['vm_id']
                attempt = data['attempts'] + 1
                key = VAirDeferredRemoval.get_job_key(vm_id)
                try:
                    logger.debug('Found {} for removal {}. Attempt: {} '.format(vm_id, key, attempt))
                    if attempt > REMOVE_MAX_ATTEMPTS:
                        logger.warn('Max removal attempts exceeded for VM {}. Giving up.'.format(vm_id))
                        storage.remove(key)
                        continue
                    
                    state = instance.get_vm_state(vm_id)
                    logger.debug('VM {} state: {}'.format(vm_id, state))
                    state_code = state['code']
                    if state_code != VM_NOT_FOUND:
                        # ВМ найдена, пробуем удалить и продолжить в следующей итерации
                        instance.request_delete_vm(vm_id)
                        logger.debug("Requested VM {} removal".format(vm_id))
                        continue

                    # ВМ не найдена, завершаем задачу
                    logger.debug("VM {} not found. Task finished.".format(vm_id))
                    storage.remove(key)
                except Exception as e:
                    logger.exception('Error during job {} processing: {}. Will retry later.'.format(key, e))

                    try:
                        data['attempts'] = attempt
                        storage.saveData(key, json.dumps(data), attr1=REMOVE_JOB_FILTER_ATTR)
                    except Exception as e:
                        logger.exception('Failed to update data for job: {}'.format(key, e))
                    
        logger.debug('Deferred vAir VM removal job finished')