# -*- coding: utf-8 -*-
'''
Created on Mar 3, 2020

@author: dvd
'''
from __future__ import unicode_literals

from django.utils.translation import ugettext_lazy as _
from uds.core import services
from uds.core.util.State import State
import logging

from .client.v2 import VM_NOT_FOUND, VM_DOWN, VM_UP

logger = logging.getLogger(__name__)
import json

class VAirStaticDeployment(services.UserDeployment):
    suggestedTime = 5

    def initialize(self):
        self._ip = self.service().getHostname()
        self._vmid = self.service().vmId.value
        self._state = State.FINISHED
        self._reason = ''
    
    # Serializable needed methods
    def marshal(self):
        data = {
            'version': 2,
            'ip': self._ip,
            'vm_id': self._vmid,
            'state': self._state,
            'reason': self._reason,
        }
        
        return json.dumps(data)
        

    def unmarshal(self, str_):
        if isinstance(str_, bytes):
            str_ = str_.decode('utf-8')

        data = json.loads(str_)
        if data['version']==2:
            self._ip = data.get('ip','')
            self._vmid = data['vm_id']
            self._reason = data['reason']
            self._state = data['state']
        else:
            raise Exception("Unsupported serialized data version {}".format(data['version']))
    
    def setIp(self, ip):
        logger.debug('Setting IP to %s (ignored)' % ip)

    def getIp(self):
        return self._ip

    def getName(self):
        return self._vmid

    def getUniqueId(self):
        return self._vmid

    def setReady(self):
        logger.debug('setReady Checking vm {} state'.format(self._vmid))
        try:
            state = self.service().get_vm_state(self._vmid)
            logger.debug('setReady Vm {} state {}'.format(self._vmid, state))
            code = state['code']
            if code == VM_NOT_FOUND:
                self._reason = "Machine is not found."
                return State.ERROR
            
            if code == VM_DOWN:
                logger.debug('setReady VM {} needs power on'.format(self._vmid))
                self.service().request_poweron_vm(self._vmid)
                logger.debug('setReady Power on VM {}'.format(self._vmid))
                
                return State.RUNNING
                
        except Exception as e:
            logger.exception(e)
            self._reason = "Error checking state: {}".format(str(e))
            return State.ERROR
        
        self._state = State.FINISHED
        return self._state

    def deployForUser(self, user):
        logger.debug("Starting deploy of {0} for user {1}".format(self._ip, user))
        self.dbservice().setInUse(True)
        self.dbservice().save()
        self._state = State.FINISHED
        return self._state

    def checkState(self):
        
        def is_up():
            state = self.service().get_vm_state(self._vmid)
            code = state['code']
            if code == VM_UP:
                return True
            return False
        
        try:
            if is_up():
                return State.FINISHED
        except Exception as e:
            logger.exception("Error {} while waiting for VM {} to power up".format(str(e), self._vmid))
            self._reason = "Error checking VM state"
            return State.ERROR
        
        return State.RUNNING

    def finish(self):
        pass

    def reasonOfError(self):
        '''
        If a publication produces an error, here we must notify the reason why it happened. This will be called just after
        publish or checkPublishingState if they return State.ERROR
        '''
        return self._reason

    def cancel(self):
        return self.destroy()

    def destroy(self):
        self._state = State.FINISHED
        return self._state
    
    def getConsoleConnection(self):
        return self.service().get_console_connection(self._vmid)