# -*- coding: utf-8 -*-
'''
Created on Mar 3, 2020

@author: dvd
'''
from __future__ import unicode_literals

from django.utils.translation import ugettext_lazy as _
from uds.core import services
from uds.core.services import types as serviceTypes
from uds.core.ui.UserInterface import gui
from .VAirStaticDeployment import VAirStaticDeployment
import logging


logger = logging.getLogger(__name__)


class VAirStaticService(services.Service):

    # Gui
    vmId = gui.ChoiceField(
        label=_("Виртуальная машина"),
        order=1,
        tooltip=_('Уникальный идентификатор ВМ'),
        tab=_('Machine'),
        required=True
    )

    ov = gui.HiddenField(value=None)
    ev = gui.HiddenField(value=None)  # We need to keep the env so we can instantiate the Provider

    typeName = _('Статичная ВМ VAir')
    typeType = 'VAirStaticService'
    typeDescription = _('Предоставляет доступ к статичным включенным ВМ по Spice протоколу')
    iconFile = 'service.png'

    maxDeployed = -1  # If the service provides more than 1 "provided service" (-1 = no limit, 0 = ???? (do not use it!!!), N = max number to deploy
    usesCache = False  # Cache are running machine awaiting to be assigned
    usesCache_L2 = False  # L2 Cache are running machines in suspended state
    needsManager = False  # If the service needs a s.o. manager (managers are related to agents provided by services itselfs, i.e. virtual machines with agent)
    mustAssignManually = False  # If true, the system can't do an automatic assignation of a deployed user service from this service

    deployedType = VAirStaticDeployment

    servicesTypeProvided = (serviceTypes.VDI,)

    def initGui(self):
        '''
        Loads required values inside
        '''

        # Here we have to use "default values", cause values aren't used at form initialization
        # This is that value is always '', so if we want to change something, we have to do it
        # at defValue
        self.ov.defValue = self.parent().serialize()
        self.ev.defValue = self.parent().env.key

        machines = self.parent().get_vm_list()
        logger.info("Machines: %s", machines)
        vals = []
        for m in machines:
            vals.append(gui.choiceItem(m['id'], m['name']))
        self.vmId.setValues(vals)

    def initialize(self, values):
        pass
    
    def get_console_connection(self, machineId):
        return self.parent().get_console_connection(machineId)
    
    def get_vm_state(self, vm_name):
        return self.parent().get_vm_state(vm_name)
    
    def request_poweron_vm(self, vm_name):
        '''
        Invokes request_poweron_vm from parent provider
        '''
        return self.parent().request_poweron_vm(vm_name)
    
    def getHostname(self):
        return self.parent().host.value