# -*- coding: utf-8 -*-
'''
Created on Jan 28, 2020

@author: dvd
'''
from __future__ import unicode_literals

from uds.core import jobs

from uds.models import Provider


import logging
import json

logger = logging.getLogger(__name__)

REMOVE_JOB_FILTER_ATTR = 'dfrm'
REMOVE_MAX_ATTEMPTS = 30

class VMwareDeferredRemoval(jobs.Job):
    frecuency = 60 * 5  # Once every NN minutes
    friendly_name = 'VMware deferred removal'
    
    @staticmethod
    def get_job_key(vm_id):
        return 'job.dfrmv.{}'.format(vm_id)
    
    @staticmethod
    def remove(provider_instance, vm_id):
        logger.debug('Adding {} from {} to deferred removal process'.format(vm_id, provider_instance))

        try:
            data = {
                'vm_id': vm_id,
                'attempts': 0
            }
            key = VMwareDeferredRemoval.get_job_key(vm_id)
            provider_instance.storage.saveData(key, json.dumps(data), attr1=REMOVE_JOB_FILTER_ATTR)
        except Exception as e:
            logger.warn('Exception got queuing for Removal: {}'.format(e))
            logger.exception(e)

    def run(self):
        from .VMwareProvider import Provider as VMwareProvider

        logger.debug('Looking for deferred vm removals')

        # Look for Providers of correct type
        for provider in Provider.objects.filter(maintenance_mode=False, data_type=VMwareProvider.typeType):
            logger.debug('Provider {} of type {}'.format(provider, VMwareProvider.typeType))

            storage = provider.getEnvironment().storage
            instance = provider.getInstance()

            for hash_key, encoded_data, _ in storage.filter(REMOVE_JOB_FILTER_ATTR):
                data = json.loads(encoded_data)
                vm_id = data['vm_id']
                attempts = data['attempts']
                key = VMwareDeferredRemoval.get_job_key(vm_id)
                try:
                    logger.debug('Found {} for removal {}. Attempt: {} '.format(vm_id, key, attempts))
                    if attempts > REMOVE_MAX_ATTEMPTS:
                        logger.warn('Max removal attempts exceeded for vm: {}. Giving up.'.format(vm_id))
                        storage.remove(key)
                        continue
                    
                    info = instance.get_vm_info(vm_id)
                    logger.debug('Vm {} state {}'.format(vm_id, info))
                    vm_power_state = info.get('power_state','')
                    if vm_power_state != 'poweredOff':
                        # ВМ не выключена, пробуем выключить и продолжить в следующей итерации
                        instance.request_poweroff_vm(vm_id)
                        logger.debug("Requested vm {} power off".format(vm_id))
                        return

                    if vm_power_state == 'poweredOff':
                        instance.request_destroy_vm(vm_id)
                        logger.debug("Requested vm {} removal".format(vm_id))

                    # Не дожидаемся подтверждения удаления ВМ
                    storage.remove(key)
                except Exception as e:
                    logger.error('Delayed removal of {} failed: {}'.format(key, e))
                    logger.exception(e)

                    try:
                        data['attempts'] = data['attempts'] + 1
                        storage.saveData(key, json.dumps(data), attr1=REMOVE_JOB_FILTER_ATTR)
                    except Exception as e:
                        logger.error('Failed to update data for: {}'.format(key, e))
                        logger.exception(e)
                    
        logger.debug('Deferred removal finished')