# -*- coding: utf-8 -*-
'''
Created on Sep 25, 2019

@author: dvd
'''
from __future__ import unicode_literals

import logging

logger = logging.getLogger(__name__)

def append_children(fmap, folder_id, level):
    '''
    Вспомогательный метод. 
    Рекурсивно подготовливает список дочерних элементов.
    '''
    
    folder = fmap[folder_id]
    res = []
    pad = ''
    prefix = ''
    if level > 0:
        pad = "&nbsp;" * int(4+8*(level-1))
        prefix = "\\" + "-" * 3
    res.append({'id': folder['id'], 'text': '{}{}{}'.format(pad, prefix, folder['name'])})
    
    child_folders = [fmap[child_id] for child_id in folder['children']]
    child_folders = sorted(child_folders, key=lambda item: item['name'])
    for child in child_folders:
        res.extend(append_children(fmap, child['id'], level+1))
        
    return res

def prepare_resources(folders):
    '''
    Подготавливает список ресурсов (папки, ресурс пулы) к отображению в вебе.
    Сортирует и строит список элементов согласно их иерархии
    '''
    try:
        fmap = { f['id']:{'id':f['id'], 'name': f['name'], 'parent': f['parent'], 'children': []} for f in folders}
        
        # Заполняем список дочерних элементов
        for folder in folders:
            parent_id = folder['parent']
            # Могут быть ссылки на системную родительскую папку, 
            # которой нет в списке
            if parent_id and parent_id in fmap.keys():
                parent_folder = fmap[parent_id] 
                parent_folder['children'].append(folder['id'])
        
        root_folders = [f for f in fmap.values() if f['parent'] not in fmap]
        root_folders = sorted(root_folders, key=lambda item: item['name'])
        res = []
        for folder in root_folders:
            res.extend(append_children(fmap, folder['id'], 0))
        return res    
    except Exception as e:
        logger.exception(e)
        raise

class VMwareHelpers(object):
    
    @staticmethod
    def get_datacenter_resources(parameters):
        
        from uds.core.Environment import Environment
        from .VMwareProvider import Provider
         
        logger.debug('Parameters received by get_datastore_clusters Helper: {0}'.format(parameters))
        env = Environment(parameters['ev'])
        provider = Provider(env)
        provider.unserialize(parameters['ov'])
         
        res = []
        compute_clusters = []
        vms = []
        folders=[]
        
        # Получаем список кластеров Datastore
        for cluster in provider.get_datastore_clusters(datacenter_id=parameters['datacenter']):
            capacity = cluster['capacity']/1024/1024/1024 # Gb
            free_space = cluster['free_space']/1024/1024/1024 #Gb
            
            label = "{name} ({avail} Гб / {size} Гб)".format(name=cluster['name'], avail=free_space, size=capacity)
            res.append({'id': cluster['id'], 'text': label})
        
        # Получаем список ClusterComputeResource'ов
        for cluster in provider.get_compute_clusters(datacenter_id=parameters['datacenter']):
            compute_clusters.append({'id': cluster['id'], 'text': cluster['name']})
        
        # Получаем список шаблонов ВМ
        for vm in provider.get_templates(datacenter_id=parameters['datacenter']):
            vms.append({'id': vm['id'], 'text': vm['name']})
            
        # Получаем список папок
        vm_folders = provider.get_folders(datacenter_id=parameters['datacenter'])
        folders.extend(prepare_resources(vm_folders))
        
        data = [
            {
                'name': 'datapool',
                'values': res
            },
            {
                'name': 'computepool',
                'values': compute_clusters
            },
            {
                'name': 'machine',
                'values': vms
            },
            {
                'name': 'folder',
                'values': folders
            }
        ]
 
        logger.debug('return data: {0}'.format(data))
        return data
    
    @staticmethod
    def get_resource_pools(parameters):
        
        from uds.core.Environment import Environment
        from .VMwareProvider import Provider
         
        logger.debug('Parameters received by get_resource_pools Helper: {0}'.format(parameters))
        env = Environment(parameters['ev'])
        provider = Provider(env)
        provider.unserialize(parameters['ov'])
         
        res = []
        
        cluster_id = parameters.get('computepool', '').strip()
        
        if cluster_id in ['', 'null']:
            # Некорректный id
            return []
        
        # Получаем список ResourcePool'ов
        pools = provider.get_resource_pools(cluster_id=parameters['computepool'])
        res.extend(prepare_resources(pools))
      
        data = [
            {
                'name': 'resourcepool',
                'values': res
            },
        ]
 
        logger.debug('return data: {0}'.format(data))
        return data
