(function() {
  class TableSearch {
    constructor(options) {
      this.dummyLogger = {
        log: function(msg) {},
        debug: function(msg) {},
        info: function(msg) {},
        warn: function(msg) {},
        error: function(msg) {},
      };

      this.searchFn = options.searchFn;
      this.fillFn = options.fillFn;
      this.wrapper = options.wrapper;
      this.searchBy = options.searchBy;
      this.logger = options.logger || this.dummyLogger;

      this.init(this.wrapper, TableSearch.COMPONENT_MARKUP, this.searchBy);

      const that = this;

      this.wrapper.on( 'keyup', 'input[type="search"]', function() {
        const inputVal = $(this).val();
        $(this).next('.clear').toggle( Boolean(inputVal) );
      } );

      // search
      this.wrapper.on( 'click', '.btn-search', function() {
        const $input = $(this).parents('form').find('input');
        const inputVal = $input.val();
        
        if ( Boolean(inputVal) ) {
          that.search( {
            input: $input,
            val: inputVal,
          } );
        }
      } );

      // search by 'Enter'
      this.wrapper.on( 'keydown', 'input[type="search"]', function(e) {
        const $input = $(this);
        const inputVal = $input.val();

        if ( e.key === 'Enter' ) {
          if ( Boolean(inputVal) ) {
            that.search( {
              input: $input,
              val: inputVal,
            } );
          }

          return false;
        }
      } );

      // reset
      this.wrapper.on( 'click', '.clear', function() {
        const $input = $(this).prev('input[type="search"]');
        const $clearBtn = $(this);

        that.reset( $input, $clearBtn );
      } );

      // reset (if the search request was erased)
      this.wrapper.on( 'input', 'input[type="search"]', function() {
        const inputVal = $(this).val();
        
        that.resetByInput( inputVal );
      } );
    }

    isSearching = false;
    searchReq = '';

    static COMPONENT_MARKUP = `
      <form role="form" class="search-pf has-button">
        <div class="form-group has-clear">
          <div class="search-pf-input-group">
            <input type="search" class="form-control" placeholder="Поиск">
            <button type="button" class="clear" aria-hidden="true">
              <span class="pficon pficon-close"></span>
            </button>
          </div>
        </div>
        <div class="form-group">
          <button class="btn btn-default btn-search" type="button">
            <span class="fa fa-search"></span>
          </button>
        </div>
      </form>
    `;

    init(wrapper, markup, searchBy) {
      const searchByBlock = `<p class="text-center form-text text-muted small mb-0">${searchBy}</p>`;
      const html = `
        <div class="component-table-search">
          ${markup}
          ${searchByBlock}
        </div>
      `;

      wrapper.append(html);
      wrapper.find('.clear').hide();
    }

    search( opts = {} ) {
      const $input = opts.input || this.wrapper.find('input[type="search"]');
      const inputVal = opts.val || this.searchReq;

      this.isSearching = true;
      this.searchReq = inputVal;
      this.searchFn( this.searchReq );
      $input.focus();
    }

    reset( $input, $clear ) {
      const $searchInput = $input || this.wrapper.find('input[type="search"]');
      const $clearBtn = $clear || this.wrapper.find('.clear');

      $searchInput.val('').focus();
      $clearBtn.hide();

      // usual filling
      if ( this.isSearching ) {
        this.isSearching = false;
        this.fillFn();
      }
    }
    
    resetByInput( val ) {
      // prevent unnecessary request when reset
      if ( ! Boolean(val) && this.isSearching ) {
        this.isSearching = false;
        this.fillFn();
      }
    }
  }

  termidesk.ui.components.TableSearch = TableSearch;
})();
