(function() {
  class TableUpdate {
    constructor(options) {
      this.dummyLogger = {
        log: function(msg) {},
        debug: function(msg) {},
        info: function(msg) {},
        warn: function(msg) {},
        error: function(msg) {},
      };

      this.scope = options.scope;
      this.entity = options.entity;
      this.fnc = options.updFn;
      this.wrapper = options.wrapper;
      this.logger = options.logger || this.dummyLogger;

      this.wrapper.append(TableUpdate.COMPONENT_MARKUP);
      this.select = this.wrapper.find('.selectpicker');
      this.wrapper.find('[data-toggle="tooltip"]').tooltip();

      this.initLocalStorage();
      this.init(this.scope, this.entity, this.fnc);

      const that = this;

      // update manually
      this.wrapper.on('click', function(e) {
        that.update(that.fnc, e);
      });

      // update by select
      this.wrapper.on('change', this.select, function() {
        that.updateAtInterval({
          scope: that.scope,
          entity: that.entity,
          fnc: that.fnc,
          interval: that.select.val(),
          select: that.select,
        }, 'select');
        that.logger.info('UPD interval by select');
      });
    }

    static TBL_UPD_LOC_STORAGE_KEY = 'termidesk.ui.components.TableUpdate.intervals';
    static DEFAULT_INTERVAL = 10;
    static COMPONENT_MARKUP = `
      <div class="component-table-update">
        <button type="button" class="btn btn-default btn-update" data-toggle="tooltip" data-placement="top" title="Обновить">
          <span class="fa fa-repeat"></span>
        </button>
        <div class="select-wrapper" data-toggle="tooltip" data-placement="top" title="Задать интервал обновления">
          <select class="selectpicker">
            <option value="5">5 сек</option>
            <option value="10">10 сек</option>
            <option value="20">20 сек</option>
            <option value="30">30 сек</option>
            <option value="60">60 сек</option>
          </select>
        </div>
      </div>
    `;

    initLocalStorage() {
      if ( localStorage.getItem(TableUpdate.TBL_UPD_LOC_STORAGE_KEY) === null ) {
        const updIntervals = {};
        localStorage.setItem( TableUpdate.TBL_UPD_LOC_STORAGE_KEY, JSON.stringify(updIntervals) );

        this.logger.info('The 1st time');
      }
    }

    // set default / get existing val
    init(scope, entity, fnc) {
      const updIntervals = JSON.parse( localStorage.getItem(TableUpdate.TBL_UPD_LOC_STORAGE_KEY) );
      let interval = null;

      if ( ! updIntervals.hasOwnProperty(scope) ) {
        updIntervals[scope] = {};
      }

      if ( ! updIntervals[scope].hasOwnProperty(entity) ) {
        interval = TableUpdate.DEFAULT_INTERVAL;

        updIntervals[scope][entity] = {
          interval: interval,
          timerID: null,
        };

        localStorage.setItem( TableUpdate.TBL_UPD_LOC_STORAGE_KEY, JSON.stringify(updIntervals) );

        this.updateAtInterval({
          scope: scope,
          entity: entity,
          fnc: fnc,
          interval: interval,
          select: this.select,
        });
        this.logger.info('1st time setup interval');
      } else {
        interval = updIntervals[scope][entity].interval;

        this.updateAtInterval({
          scope: scope,
          entity: entity,
          fnc: fnc,
          interval: interval,
          select: this.select,
        });
        this.logger.debug(`Interval ${interval} exists in localStorage`);
      }

      this.select.selectpicker('val', interval);
    }

    // update manually
    update(fn, e) {
      const btn = $( e.target.closest('button') );

      if ( btn.hasClass('btn-update') ) {
        fn();
        this.logger.info('UPD manually');
      }
    }

    updateAtInterval(options, type = null) {
      let updInterval = options.interval;
      const logger = this.logger;
      logger.log(`UPD at interval: ${updInterval}`);

      if ( typeof updInterval == 'string' ) {
        updInterval = Number(updInterval);
      }

      const updIntervalMs = updInterval * 1000;
      const updIntervals = JSON.parse( localStorage.getItem(TableUpdate.TBL_UPD_LOC_STORAGE_KEY) );

      options.select.selectpicker('val', options.interval);

      // if change by select
      if (type === 'select') {
        logger.log('timerID to clean: ' + updIntervals[options.scope][options.entity].timerID);
        clearInterval( updIntervals[options.scope][options.entity].timerID );
      }

      updIntervals[options.scope][options.entity].interval = options.interval;
      updIntervals[options.scope][options.entity].timerID = setInterval(function() {
        options.fnc();
        logger.log(`UPD for entity: ${options.entity}`);
      }, updIntervalMs);

      localStorage.setItem( TableUpdate.TBL_UPD_LOC_STORAGE_KEY, JSON.stringify(updIntervals) );

      this.logger.debug('cur timerID: ' + updIntervals[options.scope][options.entity].timerID);
    }
  }

  termidesk.ui.components.TableUpdate = TableUpdate;
})();
