(function() {
	"use strict"
	
	var WorkspaceStatusIcon = {
		props: ['type', 'title'],
		template: `
		<span class="workspace-status-icon d-inline-block align-top text-center" data-toggle="tooltip" data-placement="top" :title="title">
	   		<i  :class="'fa fa-' + type + ' align-text-top'" 
	   			aria-hidden="true" 
	   			style="vertical-align: baseline;"></i>
	   	</span>
		`
	}
	
	var WorkspaceStatusIconLink = {
		props: ['type', 'title', 'url'],
		template: `
		<span class="workspace-status-icon-link d-inline-block align-top text-center" data-toggle="tooltip" data-placement="top" :title="title">
        		<a  :href="url" 
                	    :target="url"
                	><i  :class="'fa fa-' + type + ' align-text-top'" 
	   			aria-hidden="true" 
	   			style="vertical-align: baseline;"></a>
	   		</i></a>
	   	</span>
		`
	}
	
	var WorkspaceTransportsModal = {
		props: ['ser'],
		template:`
		<div class="modal">
			<div class="modal-dialog modal-sm">
				<div class="modal-content">
					<div class="modal-header">
						<h4 class="modal-title text-center">Подключения</h4>
						<button type="button" class="close" data-dismiss="modal"
							aria-hidden="true">
							<span aria-hidden="true">&times;</span>
						</button>
					</div>
					<div class="modal-body">
						<ul class="transports">
							<template v-for="trans in ser.transports">
							<li>
								<a class="vdi-service-transport" data-href-alt="/"	:href="trans.link">
									<img class="transport" :src="trans.icon_url" :alt="trans.name"> {{ trans.name }}
								</a>
							</li>
							</template>
						</ul>
					</div>
				</div>
				<!-- /.modal-content -->
			</div>
			<!-- /.modal-dialog -->
		</div>
		<!-- /.modal -->
		`
	}
	
	var WorkspaceCard = {
		props: ['ser'],
		components: {
		  	'workspace-transports-modal': WorkspaceTransportsModal,
		  	'workspace-status-icon': WorkspaceStatusIcon,
		  	'workspace-status-link': WorkspaceStatusIconLink,
	    },
		computed: {
			isShowTransports: function() {
				this.ser.show_transports;
				this.ser.transports.len;
				return ( this.ser.show_transports && ( this.ser.transports.length > 1) );
			},
			serviceComment: function() {
				this.ser.comments;
				console.log(this.ser.comments);
				if (this.ser.comments === '') {
					return '&nbsp;'
				} else {
					return this.ser.comments;
				}
			},
			
			workspaceState: function() {
				const classes = [];
				this.ser.maintenance;
				this.ser.not_accesible;
				this.ser.in_use;
				this.ser.to_be_replaced;
				
				if ( this.ser.maintenance ) {
					classes.push('text-secondary maintenance');
				}
				
				if ( this.ser.in_use ) {
					classes.push('text-primary inuse');
				}
				
				if ( this.ser.to_be_replaced) {
					classes.push('text-danger to_be_replaced');
				}
				
				if ( this.ser.not_accesible) {
					classes.push('text-danger notaccesible');
				}
				
				return classes.join(' ');
			},
			defaultTransport: function() {
				this.ser.transports;
				if ( this.ser.transports.length > 0 ) {
					return this.ser.transports[0];
				} else {
					return { link: '/'}
				}
				
			},
			isNameTooltipRequired: function() {
				this.ser.name;
				if (this.ser.name.length > 12) {
					return true;
				} else {
					return false;
				}
			}
			
		},
		template:`
			<div :class="'card mx-auto service '+ workspaceState" v-bind:data-href="defaultTransport.link" data-href-alt="/">
				<div class="card-header">
		        	<div class="d-flex">
		            	<span class="service-name d-inline-block flex-grow-1" 
		            		  style="width:100%;" 
		            		  :title="isNameTooltipRequired ? ser.name : false"
		            		  :data-toggle="isNameTooltipRequired ? 'tooltip' : false"
		            		  :data-placement="isNameTooltipRequired ? 'top' : false">
		            		{{ ser.name }}
		            	</span>
		            	<workspace-status-icon v-if="ser.not_accesible" type="calendar" title="Календарные ограничения"></workspace-status-icon>
		           		<workspace-status-icon v-if="ser.maintenance" type="wrench"  title="Тех. обслуживание"></workspace-status-icon>
		           		<workspace-status-icon v-if="ser.to_be_replaced" type="wrench"  title="Готовится к замене"></workspace-status-icon>
		           		<workspace-status-icon v-if="ser.in_use" type="lock"  title="Используется"></workspace-status-icon>
		           		<workspace-status-link v-if="ser.help_url" type="users"  :title="ser.help_url_label" :url="ser.help_url"></workspace-status-link>
		           		
		           		<template v-if="isShowTransports">
		                	<span class="workspace-connections d-inline-block align-top text-center" data-toggle="tooltip" data-placement="top" title="Выбор подключения">
		                		<span class="fa fa-exchange align-text-top"></span>
		                	</span>
		            	</template>
		        	</div> <!-- end for d-flex -->
		        </div><!-- end for card-header -->
		        <div class="service-image">
		            <img :src="ser.img_url" />
		        </div>
		        <template v-if="isShowTransports">
		        	<workspace-transports-modal v-bind:ser="ser"></workspace-transports-modal>
		        </template>
		        <div class="card-body text-secondary">
					<p class="card-text" style="min-height:24px;">{{ ser.comments }}</p>
				</div>
			</div><!-- end for card -->
		`
	}
	
	var WorkspacesPane = {
		data: function() { return termidesk.web.page.context },
		props: {
			grp: Object,
			workspacesList: Array,
		    index: Number,
		},
		computed: {
			paneState: function() {
				this.index;
				if ( this.index === 0 ) {
					return 'active';
				} else {
					return 'fade';
				}
			}
		},
		components: {
		  	'workspace-card': WorkspaceCard,
	    },
		filters: {
		},
		template:`
			<div :class="'tab-pane '+paneState" v-bind:id="'tab-services-' + (index + 1)">
				<div class="row">
				<template v-for="ser in workspacesList">
					<template v-if="ser.group.name === grp.name">
					<div class="col-12 col-sm-6 col-md-6 col-lg-4 col-xl-3">
						<workspace-card v-bind:ser="ser"></workspace-card>
					</div>
					</template>
				</template>
				</div>
			</div>
		`
	}
	

	var app;
	
	function ready(event) {
		app=new Vue({
		  el: '#vue-content',
		  data: termidesk.web.page.context,
		  components: {
			  	'workspaces-pane': WorkspacesPane,
		  },
		  filters: {},
		  template: `
		  <div class="tab-content">
		    <template v-for="(grp, index) in groups">
				<workspaces-pane v-bind:grp="grp" v-bind:workspacesList="workspaces" v-bind:index="index"></workspaces-pane>
			</template>
		  </div>`
		})
	}
	
	document.addEventListener("DOMContentLoaded", ready);
	
})();