# -*- encoding: utf-8 -*-
"""
Патч модуля sys, добавляющий возможность обработки аудита событий

Патч может быть импортирован вместе с другими модулями в общей секции,
а также его можно импортировать локально.

Если модуль sys был импортирован глобально для модуля, то локальный импорт
модуля sys вместе с патчем не требуется

Если по какой-то причине импорт патча не добавляет функциональность в модуль sys,
то можно локально импортировать функцию и вызывать ее.

def some_action():
    from termidesk.sys_audit_patch import add_audit_to_sys
    add_audit_to_sys()

    sys.audit()

Но в большинстве случаев достаточно обычного импорта

# -*- coding: utf-8 -*-
import sys
import termidesk.sys_audit_patch
import ...

def some_usefull_code():
    sys.audit("Target.Event", additional_argument)
    pass

"""


import sys


def add_audit_to_sys():
    """
    Добавляет во встроенную библиотеку sys вызовы audit и addaudithook
    """
    # Если sys уже содержит audit и addaudithook, то повторно добавлять их не надо
    if not hasattr(sys, "audit") and not hasattr(sys, "addaudithook"):
        import sysaudit
        sys.audit = sysaudit.audit
        sys.addaudithook = sysaudit.addaudithook


# При импорте данного модуля audit и addaudithook добавляются автоматически
add_audit_to_sys()
