# -*- coding: utf-8 -*-

from __future__ import unicode_literals

import logging

from django.http import HttpResponseRedirect
from django.urls import reverse
from django.utils.translation import ugettext_noop as _
from uds.core.transports import protocols
from uds.core.transports.BaseTransport import TUNNELED_GROUP, Transport
from uds.core.ui.UserInterface import gui
from uds.core.util import OsDetector
from uds.models import TicketStore

logger = logging.getLogger(__name__)


class HTML5VNCTransport(Transport):
    '''
    Provides access via RFB to service.
    This transport can use an domain. If username processed by authenticator contains '@',
    it will split it and left-@-part will be username, and right password
    '''
    typeName = _('VNC (HTML5, через локальный прокси)')
    typeType = 'HTML5VNCTransport'
    typeDescription = 'Протокол доставки на основе VNC/HTML5 через встроенный вебсокет прокси сервер'
    iconFile = 'vnc.png'

    ownLink = True
    supportedOss = OsDetector.allOss
    protocol = protocols.VNC
    group = TUNNELED_GROUP

    tunnelWait = gui.NumericField(
        length=3,
        label=_('Время ожидания соединения'),
        defvalue='20', minValue=1, maxValue=1800, order=2,
        tooltip=_('Максимальное время ожидание установления соединения'),
        required=True, tab=gui.TUNNEL_TAB)

    def isAvailableFor(self, userService, ip):
        '''
        Checks if the transport is available for the requested destination ip
        Override this in yours transports
        '''
        logger.debug('Checking availability for {0}'.format(ip))
        return True  # VNC is available, no matter what IP machine has (even if it does not have one)

    def getLink(self, userService, transport, ip, os, user, request):
        userServiceInstance = userService.getInstance()

        con = userServiceInstance.getConsoleConnection()

        logger.debug('Connection data: {}'.format(con))

        port, secure_port = con['port'], con['secure_port']
        port = -1 if port is None else port
        secure_port = -1 if secure_port is None else secure_port

        # Build params dict
        params = {
            'workplace_name': userService.deployed_service.name,
            'wsproxy': '/websockify',
            'host': con['address'],
            'port': port,
            'tls-port': secure_port,
            'vnc_password': con['ticket']['value'],
            'tunnelWait': self.tunnelWait.num()
        }

        logger.debug('VNC Params: {0}'.format(params))

        ticket = TicketStore.create(params)

        return HttpResponseRedirect(
            reverse('Html5VNCClient', kwargs={'ticketId': ticket}))
