# -*- coding: utf-8 -*-
'''
Created on 12 февр. 2019 г.

@author: dvd
'''
from __future__ import unicode_literals
from django.utils.translation import ugettext_noop as _
from uds.core.managers.UserPrefsManager import CommonPrefs
from uds.core.ui.UserInterface import gui
from uds.core.transports.BaseTransport import TUNNELED_GROUP
from uds.core.transports import protocols
from uds.core.util import OsDetector
from uds.core.util import tools

from uds.transports.RDP.BaseRDPTransport import BaseRDPTransport
from uds.transports.RDP.RDPFile import RDPFile

from ..utils import check_connection_to_web_socket_server

import logging
from termidesk.core.util import wsptoken
import config

logger = logging.getLogger(__name__)

READY_CACHE_TIMEOUT = 30


class WSTRDPTransport(BaseRDPTransport):
    '''
    Обеспечивает доступ к рабочему месту через RDP протокл
    This transport can use an domain. If username processed by authenticator contains '@', it will split it and left-@-part will be username, and right password
    '''
    typeName = _('RDP (через вебсокет шлюз)')
    typeType = 'WSTRDPTransport'
    typeDescription = _('RDP протокол с туннелированным подключением')
    needsJava = True  # If this transport needs java for rendering
    protocol = protocols.RDP
    group = TUNNELED_GROUP

    gatewayUrl = gui.TextField(label='URL шлюза', order=1, tooltip=_('Базовый URL вебсокет шлюза. (Формат: ws(s)://<хост>[:порт][/путь])'), required=True, tab=gui.TUNNEL_TAB)

    tunnelWait = gui.NumericField(length=3, label=_('Время ожидания соединения'), defvalue='20', minValue=1, maxValue=1800, order=2, tooltip=_('Максимальное время ожидание установления соединения'), required=True, tab=gui.TUNNEL_TAB)


    useEmptyCreds = BaseRDPTransport.useEmptyCreds
    fixedName = BaseRDPTransport.fixedName
    fixedPassword = BaseRDPTransport.fixedPassword
    withoutDomain = BaseRDPTransport.withoutDomain
    fixedDomain = BaseRDPTransport.fixedDomain
    port = BaseRDPTransport.port
    allowSmartcards = BaseRDPTransport.allowSmartcards
    allowPrinters = BaseRDPTransport.allowPrinters
    allowDrives = BaseRDPTransport.allowDrives
    allowSerials = BaseRDPTransport.allowSerials
    wallpaper = BaseRDPTransport.wallpaper
    multimon = BaseRDPTransport.multimon
    aero = BaseRDPTransport.aero
    smooth = BaseRDPTransport.smooth
    credssp = BaseRDPTransport.credssp
    multimedia = BaseRDPTransport.multimedia
    alsa = BaseRDPTransport.alsa
    printerString = BaseRDPTransport.printerString
    smartcardString = BaseRDPTransport.smartcardString

    def initialize(self, values):
        if values is not None:
            pass
#             if values['tunnelServer'].count(':') != 1:
#                 raise Transport.ValidationException(_('Must use HOST:PORT in Tunnel Server Field'))

    def getUDSTransportScript(self, userService, transport, ip, os, user, password, request):
        # We use helper to keep this clean
        prefs = user.prefs('rdp')

        ci = self.getConnectionInfo(userService, user, password)
        username, password, domain = ci['username'], ci['password'], ci['domain']

        width, height = CommonPrefs.getWidthHeight(prefs)
        depth = CommonPrefs.getDepth(prefs)

        with open(config.WSPROXY_PRIV_KEY_FILE) as f:
            sign_key = f.read()
        
        tun_url = ''
        target_host = ip

        wstoken_data = {
            'host': target_host,
            'port': self.port.value, # RDP port
            'ssl_target': False,
        }
        wstoken = wsptoken.TokenEncoder(sign_key, lifetime=self.tunnelWait.num()).encode(wstoken_data)
        tun_url = '{}/{}'.format(self.gatewayUrl.value, wstoken)

        #logger.debug('Username generated: {0}, password: {1}'.format(tunuser, tunpass))

        r = RDPFile(width == -1 or height == -1, width, height, depth, target=os['OS'])
        r.address = '{address}'
        r.username = username
        r.password = password
        r.domain = domain
        r.redirectPrinters = self.allowPrinters.isTrue()
        r.redirectSmartcards = self.allowSmartcards.isTrue()
        r.redirectDrives = self.allowDrives.isTrue()
        r.redirectSerials = self.allowSerials.isTrue()
        r.showWallpaper = self.wallpaper.isTrue()
        r.multimon = self.multimon.isTrue()
        r.desktopComposition = self.aero.isTrue()
        r.smoothFonts = self.smooth.isTrue()
        r.enablecredsspsupport = self.credssp.isTrue()
        r.multimedia = self.multimedia.isTrue()
        r.alsa = self.alsa.isTrue()
        r.smartcardString = self.smartcardString.value
        r.printerString = self.printerString.value

        # data
        data = {
            'os': os['OS'],
            'ip': ip,
            'port': self.port.value,
            'tun_url': tun_url,
            'tun_lifetime': self.tunnelWait.num(),
            'username': username,
            'password': password,
            'hasCredentials': username != '' and password != '',
            'domain': domain,
            'width': width,
            'height': height,
            'depth': depth,
            'printers': self.allowPrinters.isTrue(),
            'smartcards': self.allowSmartcards.isTrue(),
            'drives': self.allowDrives.isTrue(),
            'serials': self.allowSerials.isTrue(),
            'compression': True,
            'wallpaper': self.wallpaper.isTrue(),
            'multimon': self.multimon.isTrue(),
            'fullScreen': width == -1 or height == -1,
            'this_server': request.build_absolute_uri('/'),
            'r': r,
            'client_filename': self.client_filename,
        }

        m = tools.DictAsObj(data)

        if m.domain != '':
            m.usernameWithDomain = '{}\\\\{}'.format(m.domain, m.username)
        else:
            m.usernameWithDomain = m.username

        if m.os == OsDetector.Windows:
            r.password = '{password}'

        os = {
            OsDetector.Windows: 'windows',
            OsDetector.Linux: 'linux',
            OsDetector.Macintosh: 'macosx',
            OsDetector.FreeBSD: 'linux',
        }.get(m.os)

        if os is None:
            return super(WSTRDPTransport, self).getUDSTransportScript(userService, transport, ip, os, user, password, request)
        
        script = self.getScript('scripts/{}/wstunnel.py'.format(os))
        logger.debug(script)
        return script.format(m=m)

    @staticmethod
    def test(env, data):
        ws_uri = data.get('gatewayUrl', '')

        if ws_uri is None or len(ws_uri) == 0:
            result = [False, 'Не указан URL шлюза']
        else:
            result = check_connection_to_web_socket_server(ws_uri)

        return result
