# -*- coding: utf-8 -*-
'''
Created on 5 февр. 2019 г.

@author: dvd
'''
from __future__ import unicode_literals
from django.utils.translation import ugettext_noop as _
from uds.core.ui.UserInterface import gui
from uds.core.transports.BaseTransport import TUNNELED_GROUP
from uds.core.transports import protocols
from uds.core.util import OsDetector
from uds.core.util import tools

from uds.transports.SPICE.BaseSPICETransport import BaseSpiceTransport
from .RemoteViewerFile import RemoteViewerFile

from ..utils import check_connection_to_web_socket_server

import logging

from termidesk.core.util import wsptoken
import config

logger = logging.getLogger(__name__)


class WSTSPICETransport(BaseSpiceTransport):
    '''
    Обеспечивает доступ к рабочему месту через SPICE проткол
    '''
    typeName = _('SPICE (через вебсокет шлюз)')
    typeType = 'WSTSPICETransport'
    #typeDescription = _('SPICE Transport for tunneled connection  (EXPERIMENTAL)')
    typeDescription = _('SPICE протокол с туннелированным подключением')
    #needsJava = True  # If this transport needs java for rendering
    protocol = protocols.SPICE
    group = TUNNELED_GROUP

    gatewayUrl = gui.TextField(label='URL шлюза', order=1, tooltip=_('Базовый URL вебсокет шлюза. (Формат: ws(s)://<хост>[:порт][/путь])'), required=True, tab=gui.TUNNEL_TAB)
    #tunnelServer = gui.TextField(label=_('Туннельный сервер'), order=1, tooltip=_('IP или доменное имя туннельного сервера и порт, передаваемые клиентскому устройству. (Формат: HOST:PORT)'), tab=gui.TUNNEL_TAB)
    tunnelWait = gui.NumericField(length=3, label=_('Время ожидания соединения'), defvalue='20', minValue=1, maxValue=1800, order=2, tooltip=_('Максимальное время ожидание установления соединения'), required=True, tab=gui.TUNNEL_TAB)
    
    serverCertificate = BaseSpiceTransport.serverCertificate
    fullScreen = BaseSpiceTransport.fullScreen

    def initialize(self, values):
        if values is not None:
            pass
#             if values['tunnelServer'].count(':') != 1:
#                 raise Transport.ValidationException(_('Must use HOST:PORT in Tunnel Server Field'))

    def getUDSTransportScript(self, userService, transport, ip, os, user, password, request):
        userServiceInstance = userService.getInstance()

        # Spice connection
        con = userServiceInstance.getConsoleConnection()
        port, secure_port = con['port'], con['secure_port']
        port = -1 if port is None else port
        secure_port = -1 if secure_port is None else secure_port

        with open(config.WSPROXY_PRIV_KEY_FILE) as f:
            sign_key = f.read()
        
        tun_url = ''
        tun_secure_url = ''
        tun_lifetime = self.tunnelWait.num()
        target_host = con['address']
        
        if port != -1:
            wstoken_data = {
                'host': target_host,
                'port': port,
                'ssl_target': False,
            }
            wstoken = wsptoken.TokenEncoder(sign_key, lifetime=tun_lifetime).encode(wstoken_data)
            tun_url = '{}/{}'.format(self.gatewayUrl.value, wstoken)
        
        
        if secure_port != -1:
            wsstoken_data = {
                'host': target_host,
                'port': secure_port,
                'ssl_target': True,
            }
            wsstoken = wsptoken.TokenEncoder(sign_key, lifetime=tun_lifetime).encode(wsstoken_data)
            
            # Вебсокет шлюз поглощает TLS
            # На стороне клиента будет использоваться незашифрованный SPICE вариант
            # Шифрование, при необходимости, будет обеспечиваться HTTPS
            port=secure_port
            secure_port = -1 
            tun_url = '{}/{}'.format(self.gatewayUrl.value, wsstoken)
            tun_secure_url = '{}/{}'.format(self.gatewayUrl.value, wsstoken)
        
        # Убираем символ переноса каретки для корректного представления сертификата в скрипте
        ca = self.serverCertificate.value.replace('\r','')
        
        r = RemoteViewerFile('127.0.0.1', '{port}', secure_port, con['ticket']['value'], ca, con['cert_subject'], fullscreen=self.fullScreen.isTrue())

        m = tools.DictAsObj({
            'r': r,
            'tun_url': tun_url,
            'tun_secure_url': tun_secure_url,
            'tun_lifetime': tun_lifetime,
            'ip': con['address'],
            'port': port,
            'secure_port': secure_port,
            'client_filename': self.client_filename,
        })

        os = {
            OsDetector.Windows: 'windows',
            OsDetector.Linux: 'linux',
            OsDetector.Macintosh: 'macosx',
            OsDetector.FreeBSD: 'linux',
        }.get(os.OS)

        if os is None:
            return super(WSTSPICETransport, self).getUDSTransportScript(userService, transport, ip, os, user, password, request)

        return self.getScript('scripts/{}/wstunnel.py'.format(os)).format(m=m)

    @staticmethod
    def test(env, data):
        ws_uri = data.get('gatewayUrl', '')

        if ws_uri is None or len(ws_uri) == 0:
            result = [False, 'Не указан URL шлюза']
        else:
            result = check_connection_to_web_socket_server(ws_uri)

        return result
