"""Experimental realisation of SPICE protocol"""
# -*- coding: utf-8 -*-
#
# Copyright (c) 2012 Virtual Cable S.L.
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without modification,
# are permitted provided that the following conditions are met:
#
#    * Redistributions of source code must retain the above copyright notice,
#      this list of conditions and the following disclaimer.
#    * Redistributions in binary form must reproduce the above copyright notice,
#      this list of conditions and the following disclaimer in the documentation
#      and/or other materials provided with the distribution.
#    * Neither the name of Virtual Cable S.L. nor the names of its contributors
#      may be used to endorse or promote products derived from this software
#      without specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
# AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
# IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
# DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
# FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
# DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
# SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
# CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
# OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
# OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

# @author: Adolfo Gómez, dkmaster at dkmon dot com


# Modifications
# Copyright (c) 2017 Termilab, Dmitriy Dvoeglazov
# All rights reserved.
#
# Added proxy option
# @author: Dmitriy Dvoeglazov

from __future__ import unicode_literals

import logging

from django.utils.translation import ugettext_noop as _

from uds.core.util import OsDetector
from uds.core.util import tools
from uds.core.ui.UserInterface import gui
from uds.transports.SPICE.BaseSPICETransport import BaseSpiceTransport
from .RemoteViewerFile import RemoteViewerFile

__updated__ = '2021-07-21'

logger = logging.getLogger(__name__)


class TDSKSPICETransport(BaseSpiceTransport):
    """
    Экспериментальный протокол на базе SPICE для поддержки нового клиента подключений `vdi-viewer`
    """
    typeName = _('SPICE (vdi-viewer, эксперим.)')
    typeType = 'TDSKSPICETransport'
    typeDescription = _('"Экспериментальный протокол на базе SPICE для нового клиента vdi-viewer')

    serverCertificate = BaseSpiceTransport.serverCertificate
    fullScreen = BaseSpiceTransport.fullScreen

    proxyUrl = gui.TextField(
        length=255,
        order=6,
        label=_('URL прокси'),
        tooltip=_('URL прокси сервера'),
        tab=gui.ADVANCED_TAB
    )

    # Имя запускаемого клиента подключений
    client_filename = 'vdi-viewer'

    def getUDSTransportScript(self, user_service, transport, ip, os, user, password, request):
        user_service_instance = user_service.getInstance()

        con = user_service_instance.getConsoleConnection()

        logger.debug('Connection data: {}'.format(con))

        port, secure_port = con['port'], con['secure_port']
        port = -1 if port is None else port
        secure_port = -1 if secure_port is None else secure_port

        # Убираем символ переноса каретки для корректного представления сертификата в скрипте
        ca = self.serverCertificate.value.replace('\r', '')

        r = RemoteViewerFile(
            con['address'],
            port,
            secure_port,
            con['ticket']['value'],
            ca,
            con['cert_subject'],
            fullscreen=self.fullScreen.isTrue(),
            proxy=self.proxyUrl.value,
            termidesk_proxy=self.proxyUrl.value
        )

        m = tools.DictAsObj({
            'r': r,
            'client_filename': self.client_filename,
        })

        os = {
            OsDetector.Windows: 'windows',
            OsDetector.Linux: 'linux',
            OsDetector.Macintosh: 'macosx',
            OsDetector.FreeBSD: 'linux',
        }.get(os.OS)

        if os is None:
            return super().getUDSTransportScript(user_service, transport, ip, os, user, password, request)

        return self.getScript('scripts/{}/direct.py'.format(os)).format(m=m)
