# -*- coding: utf-8 -*-

'''
@author: Dmitry Dvoeglazov
'''
from pkg_resources import iter_entry_points

def __init__():
    '''
    Импортирует дочерние модули и затем регистрирует классы в реестре
    '''
    import os.path
    import pkgutil
    import sys
    import logging
    from importlib import import_module
    from uds.core import transports

    logger = logging.getLogger(__name__)
    
    logger.debug("Searching for transport plugins...")
    for entry_point in iter_entry_points('termidesk.transports'):
        logger.debug("Found transport plugin: {}".format(entry_point.name))
        plugin_class = entry_point.load()
        logger.debug("Loaded plugin: {}".format(plugin_class))
        logger.debug("Plugin location: {}".format(sys.modules[plugin_class.__module__].__file__))
        transports.factory().insert(plugin_class)
        logger.debug('Registered {} class with transport factory'.format(str(plugin_class)))
    
    # Динамически импортируем реализации реализации транспорт-провайдеров
    # из дочерних пакетов
    # При импорте пакеты должны регистрировать транспорт провайдеров
    # в общем реестре (TransportsFactory)
    pkgpath = os.path.dirname(sys.modules[__name__].__file__)
    for _, name, _ in pkgutil.iter_modules([pkgpath]):
        import_module('.{}'.format(name), __package__)
        logger.debug("Imported {} module from {}".format(name, __package__))

    base_transport_cls = transports.Transport
    for sub_transport_class in base_transport_cls.__subclasses__(): # pylint: disable=maybe-no-member
        sub_sub_transport_classes = sub_transport_class.__subclasses__()
        if len(sub_sub_transport_classes) == 0:
            is_local_pkg_child = \
                str(sub_transport_class.__module__) \
                    .startswith('{}.'.format(__package__))
            if not is_local_pkg_child:
                continue
            transports.factory().insert(sub_transport_class)
            logger.debug(
                'Registered {} class with transport factory'.format(
                    str(sub_transport_class)
                )
            )
        else:
            for s2_transport_class in sub_sub_transport_classes:
                is_local_pkg_child = \
                str(s2_transport_class.__module__) \
                    .startswith('{}.'.format(__package__))
                if not is_local_pkg_child:
                    continue
                transports.factory().insert(s2_transport_class)
                logger.debug(
                    'Registered {} class with transport factory'.format(
                        str(s2_transport_class)
                    )
                )


__init__()
del __init__
