"""Протокол доставки рабочего места для взаимодействия с Loudplay клиент/сервером"""
# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.utils.translation import ugettext_noop as _

from termidesk.transports.loudplay.base import get_script_template
from termidesk.transports.loudplay.base import LOUDPLAY_CLIENT_CONFIG_LINUX
from termidesk.transports.loudplay.base import LOUDPLAY_CLIENT_CONFIG_WINDOWS
from termidesk.transports.loudplay.base import LoudplayBaseTransport

# Шаблон стартового скрипта для запуска Loudplay-клиента на клиентской ВМ
DIRECT_SCRIPT_TEMPLATE = get_script_template('scripts/direct.py')


class LoudplayDirectTransport(LoudplayBaseTransport):
    """
    Обеспечивает прямой доступ Loudplay-клиента к Loudplay-серверу
    """
    typeName = _('Loudplay (напрямую, эксперим.)')
    typeType = 'LoudplayDirectTransport'
    typeDescription = _('Протокол для организации доступа Loudplay-клиента '
                        'и Loudplay-сервера через сервер Термидеск')

    connection_port = LoudplayBaseTransport.connection_port
    api_path = LoudplayBaseTransport.api_path
    control_port = LoudplayBaseTransport.control_port
    bbr_port = LoudplayBaseTransport.bbr_port
    video_port = LoudplayBaseTransport.video_port
    audio_port = LoudplayBaseTransport.audio_port

    def get_windows_script(self, ip):
        """Получение стартового скрипта для запуска Loudplay-клиента под ОС Windows"""
        client_config = self.get_config(LOUDPLAY_CLIENT_CONFIG_WINDOWS, ip)
        script_filename = 'streaming.exe'
        script_params = {
            'loudplay_client_filename': script_filename,
            'loudplay_client_config_template': client_config,
        }
        windows_script = DIRECT_SCRIPT_TEMPLATE.format(**script_params)
        return windows_script

    def get_linux_script(self, ip):
        """Получение стартового скрипта для запуска Loudplay-клиента под ОС Linux"""
        client_config = self.get_config(LOUDPLAY_CLIENT_CONFIG_LINUX, ip)
        script_filename = 'streaming'
        script_params = {
            'loudplay_client_filename': script_filename,
            'loudplay_client_config_template': client_config,
        }
        linux_script = DIRECT_SCRIPT_TEMPLATE.format(**script_params)
        return linux_script
