# This is a template
# Saved as .py for easier editing
from __future__ import unicode_literals

import json
import os
import subprocess
import logging

from client import tools
from client.wstunnel import wstunnel
from client.log import logger

logger.setLevel(logging.DEBUG)

loudplay_client_executable = tools.findApp('{loudplay_client_filename}')

if loudplay_client_executable is None:
    raise Exception('''<p>File "{loudplay_client_filename}" does not exist</p>''')

loudplay_config_dict = {loudplay_client_config_template}

loudplay_server_url = loudplay_config_dict['server_url']
loudplay_server_address = loudplay_config_dict.pop('loudplay_server_address')
loudplay_connection_port = loudplay_config_dict.pop('loudplay_connection_port')
loudplay_control_port = loudplay_config_dict['control_port']
loudplay_bbr_port = loudplay_config_dict['bbr_port']
loudplay_video_port = loudplay_config_dict['rtp_video_port']
loudplay_audio_port = loudplay_config_dict['rtp_audio_port']

# Ограничение времени на попытку открытия туннеля в секундах
tunnel_timeout = 20
# Пробрасываем порт для соединения
connection_thread, local_connection_port = wstunnel(loudplay_server_address, loudplay_connection_port,
                                                     timeout=tunnel_timeout)
# Проброс порта для отправки сигналов клавиатуры/мыши
controlling_thread, local_control_port = wstunnel(loudplay_server_address, loudplay_control_port,
                                                  timeout=tunnel_timeout)

# Проброс порта для служебного пользования
bbr_thread, local_bbr_port = wstunnel(loudplay_server_address, loudplay_bbr_port,
                                              timeout=tunnel_timeout)

# Проброс видео-порта
video_thread, local_video_port = wstunnel(loudplay_server_address, loudplay_video_port,
                                          timeout=tunnel_timeout)

# Проброс аудио-порта
audio_thread, local_audio_port = wstunnel(loudplay_server_address, loudplay_audio_port,
                                          timeout=tunnel_timeout)

if connection_thread.status == 2:
    raise Exception('Unable to open tunnel for connection port %s' % str(loudplay_connection_port))

if controlling_thread.status == 2:
    raise Exception('Unable to open tunnel for controlling port %s' % str(loudplay_control_port))

if bbr_thread.status == 2:
    raise Exception('Unable to open tunnel for bbr port %s' % str(loudplay_bbr_port))

if video_thread.status == 2:
    raise Exception('Unable to open tunnel for video port %s' % str(loudplay_video_port))

if audio_thread.status == 2:
    raise Exception('Unable to open tunnel for audio port %s' % str(loudplay_audio_port))

new_server_url = "rtsp://127.0.0.1:%s/desktop" % str(local_connection_port)
print("Server url is '%s'" % new_server_url)
loudplay_config_dict['server_url'] = new_server_url
loudplay_config_dict['control_port'] = local_control_port
loudplay_config_dict['bbr_port'] = local_bbr_port
loudplay_config_dict['rtp_video_port'] = local_video_port
loudplay_config_dict['rtp_audio_port'] = local_audio_port

loudplay_client_work_directory = os.path.dirname(os.path.dirname(loudplay_client_executable))

loudplay_config_content = json.dumps(loudplay_config_dict)

loudplay_config_filename = tools.saveTempFile(loudplay_config_content)

logger.debug('Path to working directory: %s' % str(loudplay_client_work_directory))
logger.debug('Path to loudplay client: %s' % str(loudplay_client_executable))
logger.debug('Path to loudplay config: %s' % str(loudplay_config_filename))
logger.debug('loudplay config content:\n %s\n' % str(loudplay_config_content))

subprocess.Popen([loudplay_client_executable, loudplay_config_filename],
                 cwd=loudplay_client_work_directory)
