# -*- coding: utf-8 -*-

from __future__ import unicode_literals

import logging

import config
from django.shortcuts import render
from django.views.decorators.cache import never_cache
from termidesk import __version__ as static_revision
from termidesk.core.util import wsptoken
from uds.core.auths.auth import webLoginRequired
from uds.models import TicketStore

logger = logging.getLogger(__name__)


@webLoginRequired(admin=False)
@never_cache
def index(request, ticketId):
    context = {}
    params = TicketStore.get(ticketId, invalidate=False)
    context['params'] = params

    secure = True
    target_host = params['host']
    target_port = params['tls-port']
    tun_lifetime = params['tunnelWait']

    if params['tls-port'] == -1:
        secure = False
        target_port = params['port']

    wstoken_data = {
        'host': target_host,
        'port': target_port,
        'ssl_target': secure,
    }

    with open(config.WSPROXY_PRIV_KEY_FILE) as f:
        sign_key = f.read()

    wstoken = wsptoken.TokenEncoder(sign_key, lifetime=tun_lifetime).encode(wstoken_data)
    context['wstoken'] = wstoken
    context['static_revision'] = static_revision

    return render(request, 'termidesk/clients/html5vnc/index.html',
                  context=context)
