# -*- coding: utf-8 -*-

#
# Copyright (c) 2012 Virtual Cable S.L.
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without modification,
# are permitted provided that the following conditions are met:
#
#    * Redistributions of source code must retain the above copyright notice,
#      this list of conditions and the following disclaimer.
#    * Redistributions in binary form must reproduce the above copyright notice,
#      this list of conditions and the following disclaimer in the documentation
#      and/or other materials provided with the distribution.
#    * Neither the name of Virtual Cable S.L. nor the names of its contributors
#      may be used to endorse or promote products derived from this software
#      without specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
# AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
# IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
# DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
# FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
# DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
# SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
# CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
# OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
# OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

'''
@author: Adolfo Gómez, dkmaster at dkmon dot com
'''
from __future__ import unicode_literals

import os.path
import pkgutil
import sys
import logging
import uds.dispatchers  # @UnusedImport

logger = logging.getLogger(__name__)

patterns = []


def loadModulesUrls():
    logger.debug('Looking for dispatching modules')
    global patterns
    if len(patterns) == 0:
        try:
            modName = 'uds.dispatchers'
            pkgpath = os.path.dirname(sys.modules[modName].__file__)
            for _, name, _ in pkgutil.iter_modules([pkgpath]):
                fullModName = '%s.%s.urls' % (modName, name)
                if sys.version_info.major == 3:
                    # Python 3 removes negative 'level' parameter in __import__ function
                    mod = __import__(fullModName, globals(), locals(), ['urlpatterns'], 1)
                else:
                    mod = __import__(fullModName, globals(), locals(), ['urlpatterns'], -1)
                try:
                    patterns += mod.urlpatterns
                except:
                    logger.info('Module {0} has no url patterns'.format(mod))
        except Exception as e:
            logger.debug(e)
            pass

    return patterns
