# Generated by Django 2.2.17 on 2021-06-15 10:42

from django.db import migrations


def rename_config_section_and_key_names(apps, schema_editor):
    # We can't import the Person model directly as it may be a newer
    # version than this migration expects. We use the historical version.
    section_old_name = "UDS"
    section_new_name = "Global"
    theme_key = "UDS Theme"
    enhaced_theme_key = "UDS Theme Enhaced"
    pattern_to_remove = "UDS "

    configuration = apps.get_model('uds', 'Config')

    # Переименование секции `UDS` -> `Global`
    target_sections = configuration.objects.filter(section=section_old_name)

    # Если до применения миграции случайно был произведен перезапуск сервиса,
    # то таблица заполнится значениями по умолчанию и применение миграции завершится `IntegrityError`.
    # Чтобы предотвратить `IntegrityError` необходимо удалить дублирующие записи.
    duplicate_section = configuration.objects.filter(section=section_new_name)

    if duplicate_section.count() != 0 and target_sections.count() != 0:
        # Примечание. Удалять можно только если есть и старые и новые секции,
        # чтобы исключить потерю данных при повторном применении миграции.
        number_of_duplicate_records = duplicate_section.count()
        duplicate_section.delete()
        print('\n\n{number} duplicate records was removed.'.format(number=number_of_duplicate_records))

    for fixing_record in target_sections:
        fixing_record.section = section_new_name
        fixing_record.save()

    # Переименование `UDS Theme` -> `Theme`
    target_keys = configuration.objects.filter(key=theme_key).all()
    for fixing_record in target_keys:
        fixing_record.key = fixing_record.key.replace(pattern_to_remove, '')
        fixing_record.save()

    # Переименование `UDS Theme Enhaced` -> `Theme Enhaced`
    target_keys = configuration.objects.filter(key=enhaced_theme_key).all()
    for fixing_record in target_keys:
        fixing_record.key = fixing_record.key.replace(pattern_to_remove, '')
        fixing_record.save()


class Migration(migrations.Migration):

    dependencies = [
        ('uds', '0035_user_api_permissions'),
    ]

    operations = [
        migrations.RunPython(rename_config_section_and_key_names),
    ]
