# -*- coding: utf-8 -*-
#
# Copyright (c) 2012 Virtual Cable S.L.
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without modification,
# are permitted provided that the following conditions are met:
#
#    * Redistributions of source code must retain the above copyright notice,
#      this list of conditions and the following disclaimer.
#    * Redistributions in binary form must reproduce the above copyright notice,
#      this list of conditions and the following disclaimer in the documentation
#      and/or other materials provided with the distribution.
#    * Neither the name of Virtual Cable S.L. nor the names of its contributors
#      may be used to endorse or promote products derived from this software
#      without specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
# AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
# IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
# DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
# FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
# DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
# SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
# CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
# OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
# OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

'''
@author: Adolfo Gómez, dkmaster at dkmon dot com
'''

from django.conf.urls import include, url
from uds.core.util.modfinder import loadModulesUrls
from uds import REST
from django.views.i18n import JavaScriptCatalog
from .web import views

js_info_dict = {
    'domain': 'djangojs',
    'packages': ('uds',),
}

urlpatterns = [
    url(r'^$', views.index, name='index'),
    url(r'^index.json$', views.index_json, name='indexJson'),
    url(r'^login/$', views.login, name='login'),
    url(r'^login/(?P<tag>.+)$', views.login),
    url(r'^logout$', views.logout, name='logout'),
    # Icons
    url(r'^transicon/(?P<idTrans>.+)$', views.transportIcon, name='transportIcon'),
    # Images
    url(r'^srvimg/(?P<idImage>.+)$', views.serviceImage, name='serviceImage'),
    url(r'^galimg/(?P<idImage>.+)$', views.image, name='galleryImage'),
    # Error URL
    url(r'^error/(?P<idError>.+)$', views.error, name='errorView'),
    # Transport own link processor
    url(r'^trans/(?P<idService>.+)/(?P<idTransport>.+)$', views.transportOwnLink, name='TransportOwnLink'),
    # Authenticators custom html
    url(r'^customAuth/(?P<idAuth>.*)$', views.customAuth, name="customAuth"),
    # 2FA
    url(r'^customAuthMethod/(?P<idAuth>.*)/(?P<method>.+)$', views.customAuthMethod, name="customAuthMethod"),
    # Change Language
    url(r'^i18n/', include('django.conf.urls.i18n')),

    # Custom authentication callback
    url(r'^auth/(?P<authName>.+)', views.authCallback),
    url(r'^authinfo/(?P<authName>.+)', views.authInfo),
    #(r'^about', 'web.views.about'),
    # Ticket authentication
    url(r'^tkauth/(?P<ticketId>.+)$', views.ticketAuth, name='TicketAuth'),

    # REST Api
    url(r'^rest/(?P<arguments>.*)$', REST.Dispatcher.as_view(), name="REST"),

    # Web admin GUI
    #url(r'^adm/', include('uds.admin.urls')),

    # Files
    url(r'^files/(?P<uuid>.+)', views.file_storage),

    # Internacionalization in javascript
    # Javascript catalog
    url(r'^jsi18n/(?P<lang>[a-z]*)$', JavaScriptCatalog.as_view(**js_info_dict), name="js_catalog"),
    # url(r'^jsi18n/(?P<lang>[a-z]*)$', views.jsCatalog, js_info_dict, name="js_catalog"),

]

# Append urls from special dispatchers
urlpatterns += loadModulesUrls()
